Class: Privy::Models::AccountBalanceResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/privy/models/account_balance_response.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(assets:, total:, assets_by_chain: nil) ⇒ Object

The balance of a digital asset account, aggregated across all wallets and supported chains.

Parameters:



# File 'lib/privy/models/account_balance_response.rb', line 24

Instance Attribute Details

#assetsArray<Privy::Models::BalanceAsset>

The individual asset balances, each computed across all supported chains.

Returns:



10
# File 'lib/privy/models/account_balance_response.rb', line 10

required :assets, -> { Privy::Internal::Type::ArrayOf[Privy::BalanceAsset] }

#assets_by_chainArray<Privy::Models::BalanceAssetByChain>?

Individual asset balances per chain.

Returns:



22
# File 'lib/privy/models/account_balance_response.rb', line 22

optional :assets_by_chain, -> { Privy::Internal::Type::ArrayOf[Privy::BalanceAssetByChain] }

#totalPrivy::Models::CurrencyAmount

A monetary value with its currency denomination.



16
# File 'lib/privy/models/account_balance_response.rb', line 16

required :total, -> { Privy::CurrencyAmount }