Class: Privy::Models::AccountWalletConfigurationItem

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/privy/models/account_wallet_configuration_item.rb,
sig/privy/models/account_wallet_configuration_item.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(chain_type:, custody: nil) ⇒ Object

Configuration for a wallet to create within an account.

Parameters:



# File 'lib/privy/models/account_wallet_configuration_item.rb', line 18

Instance Attribute Details

#chain_typeSymbol, Privy::Models::FirstClassChainType

The wallet chain types that offer first class support.

Parameters:

  • value (Privy::Models::first_class_chain_type)

Returns:



10
# File 'lib/privy/models/account_wallet_configuration_item.rb', line 10

required :chain_type, enum: -> { Privy::FirstClassChainType }

#custodyPrivy::Models::WalletCustodian?

Information about the custodian managing this wallet.



16
# File 'lib/privy/models/account_wallet_configuration_item.rb', line 16

optional :custody, -> { Privy::WalletCustodian }

Instance Method Details

#to_hash{

Returns:

  • ({)


21
# File 'sig/privy/models/account_wallet_configuration_item.rbs', line 21

def to_hash: -> {