Class: Privy::Models::AggregationInput
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::AggregationInput
- Defined in:
- lib/privy/models/aggregation_input.rb
Instance Attribute Summary collapse
-
#conditions ⇒ Array<Privy::Models::EthereumTransactionCondition, Privy::Models::EthereumCalldataCondition, Privy::Models::EthereumTypedDataDomainCondition, Privy::Models::EthereumTypedDataMessageCondition, Privy::Models::Ethereum7702AuthorizationCondition, Privy::Models::TempoTransactionCondition, Privy::Models::SolanaProgramInstructionCondition, Privy::Models::SolanaSystemProgramInstructionCondition, Privy::Models::SolanaTokenProgramInstructionCondition, Privy::Models::SystemCondition, Privy::Models::TronTransactionCondition, Privy::Models::TronCalldataCondition, Privy::Models::SuiTransactionCommandCondition, Privy::Models::SuiTransferObjectsCommandCondition, Privy::Models::ActionRequestBodyCondition, Privy::Models::AggregationCondition>?
Optional conditions to filter events before aggregation.
-
#group_by ⇒ Array<Privy::Models::AggregationGroupBy>?
Optional grouping configuration for bucketing metrics.
-
#method_ ⇒ Symbol, Privy::Models::AggregationMethod
The RPC method this aggregation applies to.
-
#metric ⇒ Privy::Models::AggregationMetric
The metric configuration for an aggregation, defining what field/field_source to measure and the aggregation function to apply.
-
#name ⇒ String
The name of the aggregation.
-
#owner ⇒ Privy::Models::OwnerInputUser, ...
The owner of the resource, specified as a Privy user ID, a P-256 public key, or null to remove the current owner.
-
#owner_id ⇒ String?
The key quorum ID to set as the owner of the resource.
-
#window ⇒ Privy::Models::AggregationWindow
The time window configuration for an aggregation.
Instance Method Summary collapse
-
#initialize(method_:, metric:, name:, window:, conditions: nil, group_by: nil, owner: nil, owner_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see AggregationInput for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(method_:, metric:, name:, window:, conditions: nil, group_by: nil, owner: nil, owner_id: nil) ⇒ Object
Some parameter documentations has been truncated, see Privy::Models::AggregationInput for more details.
Input for creating an aggregation.
|
|
# File 'lib/privy/models/aggregation_input.rb', line 57
|
Instance Attribute Details
#conditions ⇒ Array<Privy::Models::EthereumTransactionCondition, Privy::Models::EthereumCalldataCondition, Privy::Models::EthereumTypedDataDomainCondition, Privy::Models::EthereumTypedDataMessageCondition, Privy::Models::Ethereum7702AuthorizationCondition, Privy::Models::TempoTransactionCondition, Privy::Models::SolanaProgramInstructionCondition, Privy::Models::SolanaSystemProgramInstructionCondition, Privy::Models::SolanaTokenProgramInstructionCondition, Privy::Models::SystemCondition, Privy::Models::TronTransactionCondition, Privy::Models::TronCalldataCondition, Privy::Models::SuiTransactionCommandCondition, Privy::Models::SuiTransferObjectsCommandCondition, Privy::Models::ActionRequestBodyCondition, Privy::Models::AggregationCondition>?
Optional conditions to filter events before aggregation.
35 |
# File 'lib/privy/models/aggregation_input.rb', line 35 optional :conditions, -> { Privy::Internal::Type::ArrayOf[union: Privy::PolicyCondition] } |
#group_by ⇒ Array<Privy::Models::AggregationGroupBy>?
Optional grouping configuration for bucketing metrics.
41 |
# File 'lib/privy/models/aggregation_input.rb', line 41 optional :group_by, -> { Privy::Internal::Type::ArrayOf[Privy::AggregationGroupBy] } |
#method_ ⇒ Symbol, Privy::Models::AggregationMethod
The RPC method this aggregation applies to.
10 |
# File 'lib/privy/models/aggregation_input.rb', line 10 required :method_, enum: -> { Privy::AggregationMethod }, api_name: :method |
#metric ⇒ Privy::Models::AggregationMetric
The metric configuration for an aggregation, defining what field/field_source to measure and the aggregation function to apply.
17 |
# File 'lib/privy/models/aggregation_input.rb', line 17 required :metric, -> { Privy::AggregationMetric } |
#name ⇒ String
The name of the aggregation.
23 |
# File 'lib/privy/models/aggregation_input.rb', line 23 required :name, String |
#owner ⇒ Privy::Models::OwnerInputUser, ...
The owner of the resource, specified as a Privy user ID, a P-256 public key, or null to remove the current owner.
48 |
# File 'lib/privy/models/aggregation_input.rb', line 48 optional :owner, union: -> { Privy::OwnerInput }, nil?: true |
#owner_id ⇒ String?
The key quorum ID to set as the owner of the resource. If you provide this, do not specify an owner.
55 |
# File 'lib/privy/models/aggregation_input.rb', line 55 optional :owner_id, String, nil?: true |
#window ⇒ Privy::Models::AggregationWindow
The time window configuration for an aggregation.
29 |
# File 'lib/privy/models/aggregation_input.rb', line 29 required :window, -> { Privy::AggregationWindow } |