Class: Privy::Models::AppResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::AppResponse
- Defined in:
- lib/privy/models/app_response.rb
Overview
Defined Under Namespace
Modules: DataClassification, EnabledCaptchaProvider, MfaMethod Classes: AllowlistConfig, CustomOAuthProvider
Instance Attribute Summary collapse
- #accent_color ⇒ String?
- #allowed_domains ⇒ Array<String>
- #allowed_native_app_ids ⇒ Array<String>
- #allowed_native_app_url_schemes ⇒ Array<String>
- #allowlist_config ⇒ Privy::Models::AppResponse::AllowlistConfig
- #allowlist_enabled ⇒ Boolean
- #apple_oauth ⇒ Boolean
- #captcha_enabled ⇒ Boolean
- #captcha_site_key ⇒ String?
- #custom_api_url ⇒ String?
- #custom_jwt_auth ⇒ Boolean
- #custom_oauth_providers ⇒ Array<Privy::Models::AppResponse::CustomOAuthProvider>
-
#data_classification ⇒ Symbol, Privy::Models::AppResponse::DataClassification
Indicates that this response contains only publicly accessible data, not a privileged resource.
- #disable_plus_emails ⇒ Boolean
- #discord_oauth ⇒ Boolean
- #email_auth ⇒ Boolean
-
#embedded_wallet_config ⇒ Privy::Models::EmbeddedWalletConfigSchema
Configuration for embedded wallets including the mode.
- #enabled_captcha_provider ⇒ Symbol, ...
- #enforce_wallet_uis ⇒ Boolean
- #farcaster_auth ⇒ Boolean
- #farcaster_link_wallets_enabled ⇒ Boolean
- #fiat_on_ramp_enabled ⇒ Boolean
-
#funding_config ⇒ Privy::Models::FundingConfigResponseSchema?
Configuration for funding and on-ramp options.
- #github_oauth ⇒ Boolean
- #google_oauth ⇒ Boolean
- #guest_auth ⇒ Boolean
- #icon_url ⇒ String?
- #id ⇒ String
- #instagram_oauth ⇒ Boolean
- #legacy_wallet_ui_config ⇒ Boolean
- #line_oauth ⇒ Boolean
- #linkedin_oauth ⇒ Boolean
- #logo_url ⇒ String?
- #max_linked_wallets_per_user ⇒ Float?
- #mfa_methods ⇒ Array<Symbol, Privy::Models::AppResponse::MfaMethod>
- #name ⇒ String
- #passkey_auth ⇒ Boolean
- #passkeys_for_signup_enabled ⇒ Boolean
- #privacy_policy_url ⇒ String?
- #require_users_accept_terms ⇒ Boolean?
- #show_wallet_login_first ⇒ Boolean
-
#smart_wallet_config ⇒ Privy::Models::SmartWalletConfigurationDisabled, Privy::Models::SmartWalletConfigurationEnabled
The configuration object for smart wallets.
- #sms_auth ⇒ Boolean
- #solana_wallet_auth ⇒ Boolean
- #spotify_oauth ⇒ Boolean
- #telegram_auth ⇒ Boolean
-
#telegram_auth_config ⇒ Privy::Models::TelegramAuthConfigSchema?
Configuration for Telegram authentication.
- #telegram_oauth ⇒ Boolean
- #terms_and_conditions_url ⇒ String?
- #theme ⇒ String
- #tiktok_oauth ⇒ Boolean
- #twitch_oauth ⇒ Boolean
- #twitter_oauth ⇒ Boolean
- #twitter_oauth_on_mobile_enabled ⇒ Boolean
- #verification_key ⇒ String
- #wallet_auth ⇒ Boolean
- #wallet_connect_cloud_project_id ⇒ String?
- #whatsapp_enabled ⇒ Boolean
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(enabled:, provider:, provider_display_name:, provider_icon_url:) ⇒ Object
constructor
Some parameter documentations has been truncated, see CustomOAuthProvider for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(enabled:, provider:, provider_display_name:, provider_icon_url:) ⇒ Object
Some parameter documentations has been truncated, see CustomOAuthProvider for more details.
|
|
# File 'lib/privy/models/app_response.rb', line 304
|
Instance Attribute Details
#accent_color ⇒ String?
15 |
# File 'lib/privy/models/app_response.rb', line 15 required :accent_color, String, nil?: true |
#allowed_domains ⇒ Array<String>
20 |
# File 'lib/privy/models/app_response.rb', line 20 required :allowed_domains, Privy::Internal::Type::ArrayOf[String] |
#allowed_native_app_ids ⇒ Array<String>
25 |
# File 'lib/privy/models/app_response.rb', line 25 required :allowed_native_app_ids, Privy::Internal::Type::ArrayOf[String] |
#allowed_native_app_url_schemes ⇒ Array<String>
30 |
# File 'lib/privy/models/app_response.rb', line 30 required :allowed_native_app_url_schemes, Privy::Internal::Type::ArrayOf[String] |
#allowlist_config ⇒ Privy::Models::AppResponse::AllowlistConfig
35 |
# File 'lib/privy/models/app_response.rb', line 35 required :allowlist_config, -> { Privy::AppResponse::AllowlistConfig } |
#allowlist_enabled ⇒ Boolean
40 |
# File 'lib/privy/models/app_response.rb', line 40 required :allowlist_enabled, Privy::Internal::Type::Boolean |
#apple_oauth ⇒ Boolean
45 |
# File 'lib/privy/models/app_response.rb', line 45 required :apple_oauth, Privy::Internal::Type::Boolean |
#captcha_enabled ⇒ Boolean
50 |
# File 'lib/privy/models/app_response.rb', line 50 required :captcha_enabled, Privy::Internal::Type::Boolean |
#captcha_site_key ⇒ String?
290 |
# File 'lib/privy/models/app_response.rb', line 290 optional :captcha_site_key, String |
#custom_api_url ⇒ String?
55 |
# File 'lib/privy/models/app_response.rb', line 55 required :custom_api_url, String, nil?: true |
#custom_jwt_auth ⇒ Boolean
60 |
# File 'lib/privy/models/app_response.rb', line 60 required :custom_jwt_auth, Privy::Internal::Type::Boolean |
#custom_oauth_providers ⇒ Array<Privy::Models::AppResponse::CustomOAuthProvider>
65 66 |
# File 'lib/privy/models/app_response.rb', line 65 required :custom_oauth_providers, -> { Privy::Internal::Type::ArrayOf[Privy::AppResponse::CustomOAuthProvider] } |
#data_classification ⇒ Symbol, Privy::Models::AppResponse::DataClassification
Indicates that this response contains only publicly accessible data, not a privileged resource
73 |
# File 'lib/privy/models/app_response.rb', line 73 required :data_classification, enum: -> { Privy::AppResponse::DataClassification } |
#disable_plus_emails ⇒ Boolean
78 |
# File 'lib/privy/models/app_response.rb', line 78 required :disable_plus_emails, Privy::Internal::Type::Boolean |
#discord_oauth ⇒ Boolean
83 |
# File 'lib/privy/models/app_response.rb', line 83 required :discord_oauth, Privy::Internal::Type::Boolean |
#email_auth ⇒ Boolean
88 |
# File 'lib/privy/models/app_response.rb', line 88 required :email_auth, Privy::Internal::Type::Boolean |
#embedded_wallet_config ⇒ Privy::Models::EmbeddedWalletConfigSchema
Configuration for embedded wallets including the mode.
94 |
# File 'lib/privy/models/app_response.rb', line 94 required :embedded_wallet_config, -> { Privy::EmbeddedWalletConfigSchema } |
#enabled_captcha_provider ⇒ Symbol, ...
99 |
# File 'lib/privy/models/app_response.rb', line 99 required :enabled_captcha_provider, enum: -> { Privy::AppResponse::EnabledCaptchaProvider }, nil?: true |
#enforce_wallet_uis ⇒ Boolean
104 |
# File 'lib/privy/models/app_response.rb', line 104 required :enforce_wallet_uis, Privy::Internal::Type::Boolean |
#farcaster_auth ⇒ Boolean
109 |
# File 'lib/privy/models/app_response.rb', line 109 required :farcaster_auth, Privy::Internal::Type::Boolean |
#farcaster_link_wallets_enabled ⇒ Boolean
114 |
# File 'lib/privy/models/app_response.rb', line 114 required :farcaster_link_wallets_enabled, Privy::Internal::Type::Boolean |
#fiat_on_ramp_enabled ⇒ Boolean
119 |
# File 'lib/privy/models/app_response.rb', line 119 required :fiat_on_ramp_enabled, Privy::Internal::Type::Boolean |
#funding_config ⇒ Privy::Models::FundingConfigResponseSchema?
Configuration for funding and on-ramp options.
296 |
# File 'lib/privy/models/app_response.rb', line 296 optional :funding_config, -> { Privy::FundingConfigResponseSchema } |
#github_oauth ⇒ Boolean
124 |
# File 'lib/privy/models/app_response.rb', line 124 required :github_oauth, Privy::Internal::Type::Boolean |
#google_oauth ⇒ Boolean
129 |
# File 'lib/privy/models/app_response.rb', line 129 required :google_oauth, Privy::Internal::Type::Boolean |
#guest_auth ⇒ Boolean
134 |
# File 'lib/privy/models/app_response.rb', line 134 required :guest_auth, Privy::Internal::Type::Boolean |
#icon_url ⇒ String?
139 |
# File 'lib/privy/models/app_response.rb', line 139 required :icon_url, String, nil?: true |
#id ⇒ String
10 |
# File 'lib/privy/models/app_response.rb', line 10 required :id, String |
#instagram_oauth ⇒ Boolean
144 |
# File 'lib/privy/models/app_response.rb', line 144 required :instagram_oauth, Privy::Internal::Type::Boolean |
#legacy_wallet_ui_config ⇒ Boolean
149 |
# File 'lib/privy/models/app_response.rb', line 149 required :legacy_wallet_ui_config, Privy::Internal::Type::Boolean |
#line_oauth ⇒ Boolean
154 |
# File 'lib/privy/models/app_response.rb', line 154 required :line_oauth, Privy::Internal::Type::Boolean |
#linkedin_oauth ⇒ Boolean
159 |
# File 'lib/privy/models/app_response.rb', line 159 required :linkedin_oauth, Privy::Internal::Type::Boolean |
#logo_url ⇒ String?
164 |
# File 'lib/privy/models/app_response.rb', line 164 required :logo_url, String, nil?: true |
#max_linked_wallets_per_user ⇒ Float?
169 |
# File 'lib/privy/models/app_response.rb', line 169 required :max_linked_wallets_per_user, Float, nil?: true |
#mfa_methods ⇒ Array<Symbol, Privy::Models::AppResponse::MfaMethod>
174 |
# File 'lib/privy/models/app_response.rb', line 174 required :mfa_methods, -> { Privy::Internal::Type::ArrayOf[enum: Privy::AppResponse::MfaMethod] } |
#name ⇒ String
179 |
# File 'lib/privy/models/app_response.rb', line 179 required :name, String |
#passkey_auth ⇒ Boolean
184 |
# File 'lib/privy/models/app_response.rb', line 184 required :passkey_auth, Privy::Internal::Type::Boolean |
#passkeys_for_signup_enabled ⇒ Boolean
189 |
# File 'lib/privy/models/app_response.rb', line 189 required :passkeys_for_signup_enabled, Privy::Internal::Type::Boolean |
#privacy_policy_url ⇒ String?
194 |
# File 'lib/privy/models/app_response.rb', line 194 required :privacy_policy_url, String, nil?: true |
#require_users_accept_terms ⇒ Boolean?
199 |
# File 'lib/privy/models/app_response.rb', line 199 required :require_users_accept_terms, Privy::Internal::Type::Boolean, nil?: true |
#show_wallet_login_first ⇒ Boolean
204 |
# File 'lib/privy/models/app_response.rb', line 204 required :show_wallet_login_first, Privy::Internal::Type::Boolean |
#smart_wallet_config ⇒ Privy::Models::SmartWalletConfigurationDisabled, Privy::Models::SmartWalletConfigurationEnabled
The configuration object for smart wallets.
210 |
# File 'lib/privy/models/app_response.rb', line 210 required :smart_wallet_config, union: -> { Privy::SmartWalletConfiguration } |
#sms_auth ⇒ Boolean
215 |
# File 'lib/privy/models/app_response.rb', line 215 required :sms_auth, Privy::Internal::Type::Boolean |
#solana_wallet_auth ⇒ Boolean
220 |
# File 'lib/privy/models/app_response.rb', line 220 required :solana_wallet_auth, Privy::Internal::Type::Boolean |
#spotify_oauth ⇒ Boolean
225 |
# File 'lib/privy/models/app_response.rb', line 225 required :spotify_oauth, Privy::Internal::Type::Boolean |
#telegram_auth ⇒ Boolean
230 |
# File 'lib/privy/models/app_response.rb', line 230 required :telegram_auth, Privy::Internal::Type::Boolean |
#telegram_auth_config ⇒ Privy::Models::TelegramAuthConfigSchema?
Configuration for Telegram authentication.
302 |
# File 'lib/privy/models/app_response.rb', line 302 optional :telegram_auth_config, -> { Privy::TelegramAuthConfigSchema } |
#telegram_oauth ⇒ Boolean
235 |
# File 'lib/privy/models/app_response.rb', line 235 required :telegram_oauth, Privy::Internal::Type::Boolean |
#terms_and_conditions_url ⇒ String?
240 |
# File 'lib/privy/models/app_response.rb', line 240 required :terms_and_conditions_url, String, nil?: true |
#theme ⇒ String
245 |
# File 'lib/privy/models/app_response.rb', line 245 required :theme, String |
#tiktok_oauth ⇒ Boolean
250 |
# File 'lib/privy/models/app_response.rb', line 250 required :tiktok_oauth, Privy::Internal::Type::Boolean |
#twitch_oauth ⇒ Boolean
255 |
# File 'lib/privy/models/app_response.rb', line 255 required :twitch_oauth, Privy::Internal::Type::Boolean |
#twitter_oauth ⇒ Boolean
260 |
# File 'lib/privy/models/app_response.rb', line 260 required :twitter_oauth, Privy::Internal::Type::Boolean |
#twitter_oauth_on_mobile_enabled ⇒ Boolean
265 |
# File 'lib/privy/models/app_response.rb', line 265 required :twitter_oauth_on_mobile_enabled, Privy::Internal::Type::Boolean |
#verification_key ⇒ String
270 |
# File 'lib/privy/models/app_response.rb', line 270 required :verification_key, String |
#wallet_auth ⇒ Boolean
275 |
# File 'lib/privy/models/app_response.rb', line 275 required :wallet_auth, Privy::Internal::Type::Boolean |
#wallet_connect_cloud_project_id ⇒ String?
280 |
# File 'lib/privy/models/app_response.rb', line 280 required :wallet_connect_cloud_project_id, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/privy/models/app_response.rb', line 500
|