Class: Privy::Models::AssetAccountWithBalance
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::AssetAccountWithBalance
- Defined in:
- lib/privy/models/asset_account_with_balance.rb
Instance Attribute Summary collapse
-
#balance ⇒ Privy::Models::BalanceResponse
Balances for an asset account or wallet.
-
#display_name ⇒ String?
An optional display name for the account.
-
#id ⇒ String
The account ID.
-
#wallets ⇒ Array<Privy::Models::AccountWallet>
The wallets belonging to this account.
Instance Method Summary collapse
-
#initialize(id:, balance:, display_name:, wallets:) ⇒ Object
constructor
A digital asset account with its aggregated balance across all wallets and chains.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, balance:, display_name:, wallets:) ⇒ Object
A digital asset account with its aggregated balance across all wallets and chains.
|
|
# File 'lib/privy/models/asset_account_with_balance.rb', line 30
|
Instance Attribute Details
#balance ⇒ Privy::Models::BalanceResponse
Balances for an asset account or wallet
16 |
# File 'lib/privy/models/asset_account_with_balance.rb', line 16 required :balance, -> { Privy::BalanceResponse } |
#display_name ⇒ String?
An optional display name for the account.
22 |
# File 'lib/privy/models/asset_account_with_balance.rb', line 22 required :display_name, String, nil?: true |
#id ⇒ String
The account ID.
10 |
# File 'lib/privy/models/asset_account_with_balance.rb', line 10 required :id, String |
#wallets ⇒ Array<Privy::Models::AccountWallet>
The wallets belonging to this account.
28 |
# File 'lib/privy/models/asset_account_with_balance.rb', line 28 required :wallets, -> { Privy::Internal::Type::ArrayOf[Privy::AccountWallet] } |