Class: Privy::Models::AuthenticatedUser
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::AuthenticatedUser
- Defined in:
- lib/privy/models/authenticated_user.rb
Defined Under Namespace
Modules: SessionUpdateAction
Instance Attribute Summary collapse
- #identity_token ⇒ String?
- #is_new_user ⇒ Boolean?
-
#oauth_tokens ⇒ Privy::Models::OAuthTokens?
OAuth tokens associated with the user.
- #privy_access_token ⇒ String?
- #refresh_token ⇒ String?
-
#session_update_action ⇒ Symbol, Privy::Models::AuthenticatedUser::SessionUpdateAction
Instructs the client on how to handle tokens received.
- #token ⇒ String?
-
#user ⇒ Privy::Models::User
A Privy user object.
Instance Method Summary collapse
-
#initialize(token:, privy_access_token:, refresh_token:, session_update_action:, user:, identity_token: nil, is_new_user: nil, oauth_tokens: nil) ⇒ Object
constructor
The authenticated user.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(token:, privy_access_token:, refresh_token:, session_update_action:, user:, identity_token: nil, is_new_user: nil, oauth_tokens: nil) ⇒ Object
The authenticated user.
|
|
# File 'lib/privy/models/authenticated_user.rb', line 49
|
Instance Attribute Details
#identity_token ⇒ String?
36 |
# File 'lib/privy/models/authenticated_user.rb', line 36 optional :identity_token, String |
#is_new_user ⇒ Boolean?
41 |
# File 'lib/privy/models/authenticated_user.rb', line 41 optional :is_new_user, Privy::Internal::Type::Boolean |
#oauth_tokens ⇒ Privy::Models::OAuthTokens?
OAuth tokens associated with the user.
47 |
# File 'lib/privy/models/authenticated_user.rb', line 47 optional :oauth_tokens, -> { Privy::OAuthTokens } |
#privy_access_token ⇒ String?
14 |
# File 'lib/privy/models/authenticated_user.rb', line 14 required :privy_access_token, String, nil?: true |
#refresh_token ⇒ String?
19 |
# File 'lib/privy/models/authenticated_user.rb', line 19 required :refresh_token, String, nil?: true |
#session_update_action ⇒ Symbol, Privy::Models::AuthenticatedUser::SessionUpdateAction
Instructs the client on how to handle tokens received
25 |
# File 'lib/privy/models/authenticated_user.rb', line 25 required :session_update_action, enum: -> { Privy::AuthenticatedUser::SessionUpdateAction } |
#token ⇒ String?
9 |
# File 'lib/privy/models/authenticated_user.rb', line 9 required :token, String, nil?: true |
#user ⇒ Privy::Models::User
A Privy user object.
31 |
# File 'lib/privy/models/authenticated_user.rb', line 31 required :user, -> { Privy::User } |