Class: Privy::Models::AuthorizationKeyDashboardResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/privy/models/authorization_key_dashboard_response.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, created_at:, display_name:, public_key:, role:) ⇒ Object

Some parameter documentations has been truncated, see Privy::Models::AuthorizationKeyDashboardResponse for more details.

Dashboard response for a wallet authorization key (includes role, which is an internal-only concept).

Parameters:

  • id (String)
  • created_at (Float)
  • display_name (String, nil)
  • public_key (String)
  • role (Symbol, Privy::Models::AuthorizationKeyRole, nil)

    The role of an authorization key, controlling what actions it can authorize on a



# File 'lib/privy/models/authorization_key_dashboard_response.rb', line 33

Instance Attribute Details

#created_atFloat

Returns:

  • (Float)


14
# File 'lib/privy/models/authorization_key_dashboard_response.rb', line 14

required :created_at, Float

#display_nameString?

Returns:

  • (String, nil)


19
# File 'lib/privy/models/authorization_key_dashboard_response.rb', line 19

required :display_name, String, nil?: true

#idString

Returns:

  • (String)


9
# File 'lib/privy/models/authorization_key_dashboard_response.rb', line 9

required :id, String

#public_keyString

Returns:

  • (String)


24
# File 'lib/privy/models/authorization_key_dashboard_response.rb', line 24

required :public_key, String

#roleSymbol, ...

The role of an authorization key, controlling what actions it can authorize on a wallet.

Returns:



31
# File 'lib/privy/models/authorization_key_dashboard_response.rb', line 31

required :role, enum: -> { Privy::AuthorizationKeyRole }, nil?: true