Class: Privy::Models::BalanceAssetByChain

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/privy/models/balance_asset_by_chain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount:, chain_id:, price:, symbol:) ⇒ Object

Some parameter documentations has been truncated, see Privy::Models::BalanceAssetByChain for more details.

A single asset entry scoped to a specific chain.

Parameters:

  • amount (String)

    The amount of the asset held on this chain, denominated in the unit of the asset

  • chain_id (String)

    The CAIP-2 chain identifier (e.g. eip155:8453).

  • price (Privy::Models::CurrencyAmount)

    A monetary value with its currency denomination.

  • symbol (String)

    The symbol of the asset (e.g. USDC, ETH).



# File 'lib/privy/models/balance_asset_by_chain.rb', line 31

Instance Attribute Details

#amountString

The amount of the asset held on this chain, denominated in the unit of the asset itself.

Returns:

  • (String)


11
# File 'lib/privy/models/balance_asset_by_chain.rb', line 11

required :amount, String

#chain_idString

The CAIP-2 chain identifier (e.g. eip155:8453).

Returns:

  • (String)


17
# File 'lib/privy/models/balance_asset_by_chain.rb', line 17

required :chain_id, String

#pricePrivy::Models::CurrencyAmount

A monetary value with its currency denomination.



23
# File 'lib/privy/models/balance_asset_by_chain.rb', line 23

required :price, -> { Privy::CurrencyAmount }

#symbolString

The symbol of the asset (e.g. USDC, ETH).

Returns:

  • (String)


29
# File 'lib/privy/models/balance_asset_by_chain.rb', line 29

required :symbol, String