Class: Privy::Models::BaseActionResult

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/privy/models/base_action_result.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(executed_at:, status_code:, authorized_by_display_name: nil, authorized_by_id: nil) ⇒ Object

Common fields for intent action execution results.

Parameters:

  • executed_at (Float)

    Unix timestamp when the action was executed

  • status_code (Float)

    HTTP status code from the action execution

  • authorized_by_display_name (String) (defaults to: nil)

    Display name of the key quorum that authorized execution

  • authorized_by_id (String) (defaults to: nil)

    ID of the key quorum that authorized execution



# File 'lib/privy/models/base_action_result.rb', line 30

Instance Attribute Details

#authorized_by_display_nameString?

Display name of the key quorum that authorized execution

Returns:

  • (String, nil)


22
# File 'lib/privy/models/base_action_result.rb', line 22

optional :authorized_by_display_name, String

#authorized_by_idString?

ID of the key quorum that authorized execution

Returns:

  • (String, nil)


28
# File 'lib/privy/models/base_action_result.rb', line 28

optional :authorized_by_id, String

#executed_atFloat

Unix timestamp when the action was executed

Returns:

  • (Float)


10
# File 'lib/privy/models/base_action_result.rb', line 10

required :executed_at, Float

#status_codeFloat

HTTP status code from the action execution

Returns:

  • (Float)


16
# File 'lib/privy/models/base_action_result.rb', line 16

required :status_code, Float