Class: Privy::Models::CrossAppConnectionsResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::CrossAppConnectionsResponse
- Defined in:
- lib/privy/models/cross_app_connections_response.rb
Defined Under Namespace
Modules: DataClassification
Instance Attribute Summary collapse
- #connections ⇒ Array<Privy::Models::CrossAppConnection>
-
#data_classification ⇒ Symbol, Privy::Models::CrossAppConnectionsResponse::DataClassification
Indicates that this response contains only publicly accessible data, not a privileged resource.
Instance Method Summary collapse
-
#initialize(connections:, data_classification:) ⇒ Object
constructor
Some parameter documentations has been truncated, see CrossAppConnectionsResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(connections:, data_classification:) ⇒ Object
Some parameter documentations has been truncated, see Privy::Models::CrossAppConnectionsResponse for more details.
The response for getting the list of cross-app connections.
|
|
# File 'lib/privy/models/cross_app_connections_response.rb', line 18
|
Instance Attribute Details
#connections ⇒ Array<Privy::Models::CrossAppConnection>
9 |
# File 'lib/privy/models/cross_app_connections_response.rb', line 9 required :connections, -> { Privy::Internal::Type::ArrayOf[Privy::CrossAppConnection] } |
#data_classification ⇒ Symbol, Privy::Models::CrossAppConnectionsResponse::DataClassification
Indicates that this response contains only publicly accessible data, not a privileged resource
16 |
# File 'lib/privy/models/cross_app_connections_response.rb', line 16 required :data_classification, enum: -> { Privy::CrossAppConnectionsResponse::DataClassification } |