Class: Privy::Models::CustomTokenTransferSource
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::CustomTokenTransferSource
- Defined in:
- lib/privy/models/custom_token_transfer_source.rb,
sig/privy/models/custom_token_transfer_source.rbs
Instance Attribute Summary collapse
- #amount ⇒ String? deprecated Deprecated.
-
#asset_address ⇒ String
The token contract address (EVM) or mint address (Solana) of the asset to transfer.
-
#chain ⇒ String
The blockchain network on which to perform the transfer.
Instance Method Summary collapse
-
#initialize(asset_address:, chain:, amount: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see CustomTokenTransferSource for more details.
- #to_hash ⇒ { asset_address: String, chain: String, amount: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(asset_address:, chain:, amount: nil) ⇒ Object
Some parameter documentations has been truncated, see Privy::Models::CustomTokenTransferSource for more details.
Source for a transfer identified by a token contract address (EVM) or mint address (Solana). Use this variant for tokens that are not first-class assets.
|
|
# File 'lib/privy/models/custom_token_transfer_source.rb', line 32
|
Instance Attribute Details
#amount ⇒ String?
Amount as a decimal string in the token's standard unit (e.g. "1.5" for 1.5
USDC, "0.01" for 0.01 ETH). For exact_input, specifies the amount to send. Not
in the smallest on-chain unit (wei, lamports, etc.). Maximum 100 characters.
Deprecated: use the top-level amount field instead.
30 |
# File 'lib/privy/models/custom_token_transfer_source.rb', line 30 optional :amount, String |
#asset_address ⇒ String
The token contract address (EVM) or mint address (Solana) of the asset to transfer.
11 |
# File 'lib/privy/models/custom_token_transfer_source.rb', line 11 required :asset_address, String |
#chain ⇒ String
The blockchain network on which to perform the transfer. Supported chains include: 'ethereum', 'base', 'arbitrum', 'polygon', 'solana', and their respective testnets.
19 |
# File 'lib/privy/models/custom_token_transfer_source.rb', line 19 required :chain, String |
Instance Method Details
#to_hash ⇒ { asset_address: String, chain: String, amount: String }
21 |
# File 'sig/privy/models/custom_token_transfer_source.rbs', line 21
def to_hash: -> { asset_address: String, chain: String, amount: String }
|