Class: Privy::Models::EarnIncentiveClaimRequestBody
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::EarnIncentiveClaimRequestBody
- Defined in:
- lib/privy/models/earn_incentive_claim_request_body.rb
Direct Known Subclasses
Instance Attribute Summary collapse
-
#chain ⇒ String
The blockchain network on which to perform the incentive claim.
Instance Method Summary collapse
-
#initialize(chain:) ⇒ Object
constructor
Some parameter documentations has been truncated, see EarnIncentiveClaimRequestBody for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(chain:) ⇒ Object
Some parameter documentations has been truncated, see Privy::Models::EarnIncentiveClaimRequestBody for more details.
Input for claiming incentive rewards.
|
|
# File 'lib/privy/models/earn_incentive_claim_request_body.rb', line 14
|
Instance Attribute Details
#chain ⇒ String
The blockchain network on which to perform the incentive claim. Supported chains include: ‘ethereum’, ‘base’, ‘arbitrum’, ‘polygon’, ‘solana’, and more, along with their respective testnets.
12 |
# File 'lib/privy/models/earn_incentive_claim_request_body.rb', line 12 required :chain, String |