Class: Privy::Models::EarnIncetiveClaimRewardEntry
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::EarnIncetiveClaimRewardEntry
- Defined in:
- lib/privy/models/earn_incetive_claim_reward_entry.rb
Instance Attribute Summary collapse
-
#amount ⇒ String
Claimable amount in base units.
-
#token_address ⇒ String
Address of the reward token.
-
#token_decimals ⇒ Integer?
Number of decimal places for the reward token.
-
#token_symbol ⇒ String
Symbol of the reward token (e.g. “MORPHO”).
Instance Method Summary collapse
-
#initialize(amount:, token_address:, token_symbol:, token_decimals: nil) ⇒ Object
constructor
A specific reward token and amount associated with an earn incentive claim.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, token_address:, token_symbol:, token_decimals: nil) ⇒ Object
A specific reward token and amount associated with an earn incentive claim.
|
|
# File 'lib/privy/models/earn_incetive_claim_reward_entry.rb', line 30
|
Instance Attribute Details
#amount ⇒ String
Claimable amount in base units.
10 |
# File 'lib/privy/models/earn_incetive_claim_reward_entry.rb', line 10 required :amount, String |
#token_address ⇒ String
Address of the reward token.
16 |
# File 'lib/privy/models/earn_incetive_claim_reward_entry.rb', line 16 required :token_address, String |
#token_decimals ⇒ Integer?
Number of decimal places for the reward token.
28 |
# File 'lib/privy/models/earn_incetive_claim_reward_entry.rb', line 28 optional :token_decimals, Integer |
#token_symbol ⇒ String
Symbol of the reward token (e.g. “MORPHO”).
22 |
# File 'lib/privy/models/earn_incetive_claim_reward_entry.rb', line 22 required :token_symbol, String |