Class: Privy::Models::EncryptedWalletAuthenticateResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::EncryptedWalletAuthenticateResponse
- Defined in:
- lib/privy/models/encrypted_wallet_authenticate_response.rb,
sig/privy/models/encrypted_wallet_authenticate_response.rbs
Instance Attribute Summary collapse
-
#encrypted_authorization_key ⇒ Privy::Models::EncryptedAuthorizationKey
HPKE-encrypted authorization key with encapsulated key and ciphertext.
-
#expires_at ⇒ Float
The expiration time of the authorization key in milliseconds since the epoch.
- #wallets ⇒ Array<Privy::Models::Wallet>
Instance Method Summary collapse
-
#initialize(encrypted_authorization_key:, expires_at:, wallets:) ⇒ Object
constructor
The response from authenticating a wallet with HPKE encryption, containing an encrypted authorization key and wallet data.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(encrypted_authorization_key:, expires_at:, wallets:) ⇒ Object
The response from authenticating a wallet with HPKE encryption, containing an encrypted authorization key and wallet data.
|
|
# File 'lib/privy/models/encrypted_wallet_authenticate_response.rb', line 23
|
Instance Attribute Details
#encrypted_authorization_key ⇒ Privy::Models::EncryptedAuthorizationKey
HPKE-encrypted authorization key with encapsulated key and ciphertext.
10 |
# File 'lib/privy/models/encrypted_wallet_authenticate_response.rb', line 10 required :encrypted_authorization_key, -> { Privy::EncryptedAuthorizationKey } |
#expires_at ⇒ Float
The expiration time of the authorization key in milliseconds since the epoch.
16 |
# File 'lib/privy/models/encrypted_wallet_authenticate_response.rb', line 16 required :expires_at, Float |
#wallets ⇒ Array<Privy::Models::Wallet>
21 |
# File 'lib/privy/models/encrypted_wallet_authenticate_response.rb', line 21 required :wallets, -> { Privy::Internal::Type::ArrayOf[Privy::Wallet] } |
Instance Method Details
#to_hash ⇒ {
23 |
# File 'sig/privy/models/encrypted_wallet_authenticate_response.rbs', line 23
def to_hash: -> {
|