Class: Privy::Models::EthereumSign7702Authorization

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/privy/models/ethereum_sign_7702_authorization.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(chain_id:, contract:, nonce:, r:, s:, y_parity:) ⇒ Object

Some parameter documentations has been truncated, see Privy::Models::EthereumSign7702Authorization for more details.

A signed EIP-7702 authorization that delegates code execution to a contract address.

Parameters:

  • chain_id (String, Integer)

    A quantity value that can be either a hex string starting with ‘0x’ or a non-neg

  • contract (String)
  • nonce (String, Integer)

    A quantity value that can be either a hex string starting with ‘0x’ or a non-neg

  • r (String)

    A hex-encoded string prefixed with ‘0x’, capped at 100002 characters (50,000 byt

  • s (String)

    A hex-encoded string prefixed with ‘0x’, capped at 100002 characters (50,000 byt

  • y_parity (Float)


# File 'lib/privy/models/ethereum_sign_7702_authorization.rb', line 44

Instance Attribute Details

#chain_idString, Integer

A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.

Returns:

  • (String, Integer)


11
# File 'lib/privy/models/ethereum_sign_7702_authorization.rb', line 11

required :chain_id, union: -> { Privy::Quantity }

#contractString

Returns:

  • (String)


16
# File 'lib/privy/models/ethereum_sign_7702_authorization.rb', line 16

required :contract, String

#nonceString, Integer

A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.

Returns:

  • (String, Integer)


23
# File 'lib/privy/models/ethereum_sign_7702_authorization.rb', line 23

required :nonce, union: -> { Privy::Quantity }

#rString

A hex-encoded string prefixed with ‘0x’, capped at 100002 characters (50,000 bytes).

Returns:

  • (String)


30
# File 'lib/privy/models/ethereum_sign_7702_authorization.rb', line 30

required :r, String

#sString

A hex-encoded string prefixed with ‘0x’, capped at 100002 characters (50,000 bytes).

Returns:

  • (String)


37
# File 'lib/privy/models/ethereum_sign_7702_authorization.rb', line 37

required :s, String

#y_parityFloat

Returns:

  • (Float)


42
# File 'lib/privy/models/ethereum_sign_7702_authorization.rb', line 42

required :y_parity, Float