Class: Privy::Models::EthereumSign7702AuthorizationRpcInputParams

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/privy/models/ethereum_sign_7702_authorization_rpc_input_params.rb

Defined Under Namespace

Modules: Executor

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(chain_id:, contract:, executor: nil, nonce: nil) ⇒ Object

Some parameter documentations has been truncated, see Privy::Models::EthereumSign7702AuthorizationRpcInputParams for more details.

Parameters for the EVM ‘eth_sign7702Authorization` RPC.

Parameters:

  • chain_id (String, Integer)

    A quantity value that can be either a hex string starting with ‘0x’ or a non-neg

  • contract (String)
  • executor (Symbol, Privy::Models::EthereumSign7702AuthorizationRpcInputParams::Executor) (defaults to: nil)
  • nonce (String, Integer) (defaults to: nil)

    A quantity value that can be either a hex string starting with ‘0x’ or a non-neg



# File 'lib/privy/models/ethereum_sign_7702_authorization_rpc_input_params.rb', line 30

Instance Attribute Details

#chain_idString, Integer

A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.

Returns:

  • (String, Integer)


11
# File 'lib/privy/models/ethereum_sign_7702_authorization_rpc_input_params.rb', line 11

required :chain_id, union: -> { Privy::Quantity }

#contractString

Returns:

  • (String)


16
# File 'lib/privy/models/ethereum_sign_7702_authorization_rpc_input_params.rb', line 16

required :contract, String

#executorSymbol, ...



21
# File 'lib/privy/models/ethereum_sign_7702_authorization_rpc_input_params.rb', line 21

optional :executor, enum: -> { Privy::EthereumSign7702AuthorizationRpcInputParams::Executor }

#nonceString, ...

A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.

Returns:

  • (String, Integer, nil)


28
# File 'lib/privy/models/ethereum_sign_7702_authorization_rpc_input_params.rb', line 28

optional :nonce, union: -> { Privy::Quantity }