Class: Privy::Models::EthereumSign7702AuthorizationRpcResponseData
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::EthereumSign7702AuthorizationRpcResponseData
- Defined in:
- lib/privy/models/ethereum_sign_7702_authorization_rpc_response_data.rb
Instance Attribute Summary collapse
-
#authorization ⇒ Privy::Models::EthereumSign7702Authorization
A signed EIP-7702 authorization that delegates code execution to a contract address.
Instance Method Summary collapse
-
#initialize(authorization:) ⇒ Object
constructor
Some parameter documentations has been truncated, see EthereumSign7702AuthorizationRpcResponseData for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(authorization:) ⇒ Object
Some parameter documentations has been truncated, see Privy::Models::EthereumSign7702AuthorizationRpcResponseData for more details.
Data returned by the EVM ‘eth_sign7702Authorization` RPC.
|
|
# File 'lib/privy/models/ethereum_sign_7702_authorization_rpc_response_data.rb', line 13
|
Instance Attribute Details
#authorization ⇒ Privy::Models::EthereumSign7702Authorization
A signed EIP-7702 authorization that delegates code execution to a contract address.
11 |
# File 'lib/privy/models/ethereum_sign_7702_authorization_rpc_response_data.rb', line 11 required :authorization, -> { Privy::EthereumSign7702Authorization } |