Class: Privy::Models::EthereumSignUserOperationRpcInputParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::EthereumSignUserOperationRpcInputParams
- Defined in:
- lib/privy/models/ethereum_sign_user_operation_rpc_input_params.rb
Instance Attribute Summary collapse
-
#chain_id ⇒ String, Integer
A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.
- #contract ⇒ String
-
#user_operation ⇒ Privy::Models::UserOperationInput
An ERC-4337 user operation.
Instance Method Summary collapse
-
#initialize(chain_id:, contract:, user_operation:) ⇒ Object
constructor
Some parameter documentations has been truncated, see EthereumSignUserOperationRpcInputParams for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(chain_id:, contract:, user_operation:) ⇒ Object
Some parameter documentations has been truncated, see Privy::Models::EthereumSignUserOperationRpcInputParams for more details.
Parameters for the EVM ‘eth_signUserOperation` RPC.
|
|
# File 'lib/privy/models/ethereum_sign_user_operation_rpc_input_params.rb', line 24
|
Instance Attribute Details
#chain_id ⇒ String, Integer
A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.
11 |
# File 'lib/privy/models/ethereum_sign_user_operation_rpc_input_params.rb', line 11 required :chain_id, union: -> { Privy::Quantity } |
#contract ⇒ String
16 |
# File 'lib/privy/models/ethereum_sign_user_operation_rpc_input_params.rb', line 16 required :contract, String |
#user_operation ⇒ Privy::Models::UserOperationInput
An ERC-4337 user operation.
22 |
# File 'lib/privy/models/ethereum_sign_user_operation_rpc_input_params.rb', line 22 required :user_operation, -> { Privy::UserOperationInput } |