Class: Privy::Models::EthereumVaultDetailsResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::EthereumVaultDetailsResponse
- Defined in:
- lib/privy/models/ethereum_vault_details_response.rb
Instance Attribute Summary collapse
-
#app_apy ⇒ Float?
Annual percentage yield earned by the app from fee wrapper fees, in basis points.
-
#asset_address ⇒ String
Underlying asset token address.
-
#available_liquidity_usd ⇒ Float?
Assets available for instant withdrawal in USD.
-
#caip2 ⇒ String
Chain identifier (e.g., eip155:8453).
-
#id ⇒ String
Vault identifier.
-
#name ⇒ String
Human-readable vault name from the yield provider.
-
#provider ⇒ Symbol, Privy::Models::EthereumYieldProvider
Supported yield/lending protocol providers.
-
#tvl_usd ⇒ Float?
Total value locked in USD.
-
#user_apy ⇒ Float?
Current annual percentage yield in basis points (e.g., 500 for 5%).
-
#vault_address ⇒ String
On-chain vault contract address.
Instance Method Summary collapse
-
#initialize(id:, app_apy:, asset_address:, available_liquidity_usd:, caip2:, name:, provider:, tvl_usd:, user_apy:, vault_address:) ⇒ Object
constructor
Some parameter documentations has been truncated, see EthereumVaultDetailsResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, app_apy:, asset_address:, available_liquidity_usd:, caip2:, name:, provider:, tvl_usd:, user_apy:, vault_address:) ⇒ Object
Some parameter documentations has been truncated, see Privy::Models::EthereumVaultDetailsResponse for more details.
Detailed vault information including current APY and liquidity.
|
|
# File 'lib/privy/models/ethereum_vault_details_response.rb', line 68
|
Instance Attribute Details
#app_apy ⇒ Float?
Annual percentage yield earned by the app from fee wrapper fees, in basis points. Null when APY data is unavailable.
17 |
# File 'lib/privy/models/ethereum_vault_details_response.rb', line 17 required :app_apy, Float, nil?: true |
#asset_address ⇒ String
Underlying asset token address.
23 |
# File 'lib/privy/models/ethereum_vault_details_response.rb', line 23 required :asset_address, String |
#available_liquidity_usd ⇒ Float?
Assets available for instant withdrawal in USD.
29 |
# File 'lib/privy/models/ethereum_vault_details_response.rb', line 29 required :available_liquidity_usd, Float, nil?: true |
#caip2 ⇒ String
Chain identifier (e.g., eip155:8453).
35 |
# File 'lib/privy/models/ethereum_vault_details_response.rb', line 35 required :caip2, String |
#id ⇒ String
Vault identifier.
10 |
# File 'lib/privy/models/ethereum_vault_details_response.rb', line 10 required :id, String |
#name ⇒ String
Human-readable vault name from the yield provider.
41 |
# File 'lib/privy/models/ethereum_vault_details_response.rb', line 41 required :name, String |
#provider ⇒ Symbol, Privy::Models::EthereumYieldProvider
Supported yield/lending protocol providers.
47 |
# File 'lib/privy/models/ethereum_vault_details_response.rb', line 47 required :provider, enum: -> { Privy::EthereumYieldProvider } |
#tvl_usd ⇒ Float?
Total value locked in USD.
53 |
# File 'lib/privy/models/ethereum_vault_details_response.rb', line 53 required :tvl_usd, Float, nil?: true |
#user_apy ⇒ Float?
Current annual percentage yield in basis points (e.g., 500 for 5%). 1 basis point = 0.01%.
60 |
# File 'lib/privy/models/ethereum_vault_details_response.rb', line 60 required :user_apy, Float, nil?: true |
#vault_address ⇒ String
On-chain vault contract address.
66 |
# File 'lib/privy/models/ethereum_vault_details_response.rb', line 66 required :vault_address, String |