Class: Privy::Models::EthereumYieldClaimResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/privy/models/ethereum_yield_claim_response.rb

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, caip2:, created_at:, rewards:, status:, updated_at:) ⇒ Object

Response from a yield reward claim operation.

Parameters:

  • id (String)

    Privy transaction record ID for the claim operation.

  • caip2 (String)

    An EVM CAIP-2 chain identifier (e.g., “eip155:8453” for Base).

  • created_at (Float)

    Unix timestamp of when the claim was created, in milliseconds.

  • rewards (Array<Privy::Models::EthereumYieldClaimReward>)

    List of reward tokens claimed.

  • status (Symbol, Privy::Models::EthereumYieldClaimResponse::Status)

    The current status of the claim transaction.

  • updated_at (Float)

    Unix timestamp of when the claim was last updated, in milliseconds.



# File 'lib/privy/models/ethereum_yield_claim_response.rb', line 42

Instance Attribute Details

#caip2String

An EVM CAIP-2 chain identifier (e.g., “eip155:8453” for Base).

Returns:

  • (String)


16
# File 'lib/privy/models/ethereum_yield_claim_response.rb', line 16

required :caip2, String

#created_atFloat

Unix timestamp of when the claim was created, in milliseconds.

Returns:

  • (Float)


22
# File 'lib/privy/models/ethereum_yield_claim_response.rb', line 22

required :created_at, Float

#idString

Privy transaction record ID for the claim operation.

Returns:

  • (String)


10
# File 'lib/privy/models/ethereum_yield_claim_response.rb', line 10

required :id, String

#rewardsArray<Privy::Models::EthereumYieldClaimReward>

List of reward tokens claimed.



28
# File 'lib/privy/models/ethereum_yield_claim_response.rb', line 28

required :rewards, -> { Privy::Internal::Type::ArrayOf[Privy::EthereumYieldClaimReward] }

#statusSymbol, Privy::Models::EthereumYieldClaimResponse::Status

The current status of the claim transaction.



34
# File 'lib/privy/models/ethereum_yield_claim_response.rb', line 34

required :status, enum: -> { Privy::EthereumYieldClaimResponse::Status }

#updated_atFloat

Unix timestamp of when the claim was last updated, in milliseconds.

Returns:

  • (Float)


40
# File 'lib/privy/models/ethereum_yield_claim_response.rb', line 40

required :updated_at, Float