Class: Privy::Models::EthereumYieldSweepResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/privy/models/ethereum_yield_sweep_response.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, asset_amount:, created_at:, share_amount:, status:, type:, updated_at:, vault_id:, wallet_id:) ⇒ Object

Some parameter documentations has been truncated, see Privy::Models::EthereumYieldSweepResponse for more details.

A yield sweep record representing a deposit or withdrawal.

Parameters:

  • id (String)

    Unique identifier for the yield sweep.

  • asset_amount (String, nil)

    The amount of underlying assets involved. Set after the sweep is confirmed on-ch

  • created_at (Float)

    Unix timestamp of when the sweep was created, in milliseconds.

  • share_amount (String, nil)

    The amount of vault shares involved. Set after the sweep is confirmed on-chain.

  • status (Symbol, Privy::Models::EthereumYieldSweepStatus)

    Status of a yield sweep.

  • type (Symbol, Privy::Models::EthereumYieldSweepType)

    Type of yield sweep.

  • updated_at (Float)

    Unix timestamp of when the sweep was last updated, in milliseconds.

  • vault_id (String)

    The ID of the vault involved in the sweep.

  • wallet_id (String)

    The ID of the wallet involved in the sweep.



# File 'lib/privy/models/ethereum_yield_sweep_response.rb', line 61

Instance Attribute Details

#asset_amountString?

The amount of underlying assets involved. Set after the sweep is confirmed on-chain.

Returns:

  • (String, nil)


17
# File 'lib/privy/models/ethereum_yield_sweep_response.rb', line 17

required :asset_amount, String, nil?: true

#created_atFloat

Unix timestamp of when the sweep was created, in milliseconds.

Returns:

  • (Float)


23
# File 'lib/privy/models/ethereum_yield_sweep_response.rb', line 23

required :created_at, Float

#idString

Unique identifier for the yield sweep.

Returns:

  • (String)


10
# File 'lib/privy/models/ethereum_yield_sweep_response.rb', line 10

required :id, String

#share_amountString?

The amount of vault shares involved. Set after the sweep is confirmed on-chain.

Returns:

  • (String, nil)


29
# File 'lib/privy/models/ethereum_yield_sweep_response.rb', line 29

required :share_amount, String, nil?: true

#statusSymbol, Privy::Models::EthereumYieldSweepStatus

Status of a yield sweep.



35
# File 'lib/privy/models/ethereum_yield_sweep_response.rb', line 35

required :status, enum: -> { Privy::EthereumYieldSweepStatus }

#typeSymbol, Privy::Models::EthereumYieldSweepType

Type of yield sweep.



41
# File 'lib/privy/models/ethereum_yield_sweep_response.rb', line 41

required :type, enum: -> { Privy::EthereumYieldSweepType }

#updated_atFloat

Unix timestamp of when the sweep was last updated, in milliseconds.

Returns:

  • (Float)


47
# File 'lib/privy/models/ethereum_yield_sweep_response.rb', line 47

required :updated_at, Float

#vault_idString

The ID of the vault involved in the sweep.

Returns:

  • (String)


53
# File 'lib/privy/models/ethereum_yield_sweep_response.rb', line 53

required :vault_id, String

#wallet_idString

The ID of the wallet involved in the sweep.

Returns:

  • (String)


59
# File 'lib/privy/models/ethereum_yield_sweep_response.rb', line 59

required :wallet_id, String