Class: Privy::Models::EthereumYieldWithdrawInput

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/privy/models/ethereum_yield_withdraw_input.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(asset_amount:, vault_id:) ⇒ Object

Some parameter documentations has been truncated, see Privy::Models::EthereumYieldWithdrawInput for more details.

Input for withdrawing assets from an ERC-4626 vault.

Parameters:

  • asset_amount (String)

    The amount of the underlying asset to withdraw, in the smallest unit (e.g., wei

  • vault_id (String)

    The ID of the vault to withdraw from.



# File 'lib/privy/models/ethereum_yield_withdraw_input.rb', line 19

Instance Attribute Details

#asset_amountString

The amount of the underlying asset to withdraw, in the smallest unit (e.g., wei for ETH, 6 decimals for USDC). Must be a non-negative integer string.

Returns:

  • (String)


11
# File 'lib/privy/models/ethereum_yield_withdraw_input.rb', line 11

required :asset_amount, String

#vault_idString

The ID of the vault to withdraw from.

Returns:

  • (String)


17
# File 'lib/privy/models/ethereum_yield_withdraw_input.rb', line 17

required :vault_id, String