Class: Privy::Models::EvmTransactionWalletActionStep
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::EvmTransactionWalletActionStep
- Defined in:
- lib/privy/models/evm_transaction_wallet_action_step.rb
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#caip2 ⇒ String
CAIP-2 chain identifier of the transaction, containing the chain ID.
-
#failure_reason ⇒ Privy::Models::FailureReason?
A description of why a wallet action (or a step within a wallet action) failed.
-
#status ⇒ Symbol, Privy::Models::EvmWalletActionStepStatus
Status of an EVM step in a wallet action.
-
#transaction_hash ⇒ String?
The transaction hash for this step.
- #type ⇒ Symbol, Privy::Models::EvmTransactionWalletActionStep::Type
Instance Method Summary collapse
-
#initialize(caip2:, status:, transaction_hash:, type:, failure_reason: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see EvmTransactionWalletActionStep for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(caip2:, status:, transaction_hash:, type:, failure_reason: nil) ⇒ Object
Some parameter documentations has been truncated, see Privy::Models::EvmTransactionWalletActionStep for more details.
A wallet action step consisting of an EVM transaction.
|
|
# File 'lib/privy/models/evm_transaction_wallet_action_step.rb', line 36
|
Instance Attribute Details
#caip2 ⇒ String
CAIP-2 chain identifier of the transaction, containing the chain ID.
10 |
# File 'lib/privy/models/evm_transaction_wallet_action_step.rb', line 10 required :caip2, String |
#failure_reason ⇒ Privy::Models::FailureReason?
A description of why a wallet action (or a step within a wallet action) failed.
34 |
# File 'lib/privy/models/evm_transaction_wallet_action_step.rb', line 34 optional :failure_reason, -> { Privy::FailureReason } |
#status ⇒ Symbol, Privy::Models::EvmWalletActionStepStatus
Status of an EVM step in a wallet action.
16 |
# File 'lib/privy/models/evm_transaction_wallet_action_step.rb', line 16 required :status, enum: -> { Privy::EvmWalletActionStepStatus } |
#transaction_hash ⇒ String?
The transaction hash for this step. May change while the step status is non-terminal.
23 |
# File 'lib/privy/models/evm_transaction_wallet_action_step.rb', line 23 required :transaction_hash, String, nil?: true |
#type ⇒ Symbol, Privy::Models::EvmTransactionWalletActionStep::Type
28 |
# File 'lib/privy/models/evm_transaction_wallet_action_step.rb', line 28 required :type, enum: -> { Privy::EvmTransactionWalletActionStep::Type } |