Class: Privy::Models::EvmUserOperationWalletActionStep
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::EvmUserOperationWalletActionStep
- Defined in:
- lib/privy/models/evm_user_operation_wallet_action_step.rb
Defined Under Namespace
Modules: EntrypointVersion, Type
Instance Attribute Summary collapse
-
#bundle_transaction_hash ⇒ String?
Transaction hash of the bundle in which this user operation was included.
-
#caip2 ⇒ String
CAIP-2 network identifier, containing the chain ID of the user operation.
-
#entrypoint_version ⇒ Symbol, Privy::Models::EvmUserOperationWalletActionStep::EntrypointVersion
The entrypoint version of the user operation.
-
#failure_reason ⇒ Privy::Models::FailureReason?
A description of why a wallet action (or a step within a wallet action) failed.
-
#status ⇒ Symbol, Privy::Models::EvmWalletActionStepStatus
Status of an EVM step in a wallet action.
- #type ⇒ Symbol, Privy::Models::EvmUserOperationWalletActionStep::Type
-
#user_operation_hash ⇒ String?
The user operation hash for this step.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(bundle_transaction_hash:, caip2:, entrypoint_version:, status:, type:, user_operation_hash:, failure_reason: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see EvmUserOperationWalletActionStep for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(bundle_transaction_hash:, caip2:, entrypoint_version:, status:, type:, user_operation_hash:, failure_reason: nil) ⇒ Object
Some parameter documentations has been truncated, see Privy::Models::EvmUserOperationWalletActionStep for more details.
A wallet action step consisting of an EVM user operation.
|
|
# File 'lib/privy/models/evm_user_operation_wallet_action_step.rb', line 49
|
Instance Attribute Details
#bundle_transaction_hash ⇒ String?
Transaction hash of the bundle in which this user operation was included. Null until included by a bundler.
11 |
# File 'lib/privy/models/evm_user_operation_wallet_action_step.rb', line 11 required :bundle_transaction_hash, String, nil?: true |
#caip2 ⇒ String
CAIP-2 network identifier, containing the chain ID of the user operation.
17 |
# File 'lib/privy/models/evm_user_operation_wallet_action_step.rb', line 17 required :caip2, String |
#entrypoint_version ⇒ Symbol, Privy::Models::EvmUserOperationWalletActionStep::EntrypointVersion
The entrypoint version of the user operation.
23 |
# File 'lib/privy/models/evm_user_operation_wallet_action_step.rb', line 23 required :entrypoint_version, enum: -> { Privy::EvmUserOperationWalletActionStep::EntrypointVersion } |
#failure_reason ⇒ Privy::Models::FailureReason?
A description of why a wallet action (or a step within a wallet action) failed.
47 |
# File 'lib/privy/models/evm_user_operation_wallet_action_step.rb', line 47 optional :failure_reason, -> { Privy::FailureReason } |
#status ⇒ Symbol, Privy::Models::EvmWalletActionStepStatus
Status of an EVM step in a wallet action.
29 |
# File 'lib/privy/models/evm_user_operation_wallet_action_step.rb', line 29 required :status, enum: -> { Privy::EvmWalletActionStepStatus } |
#type ⇒ Symbol, Privy::Models::EvmUserOperationWalletActionStep::Type
34 |
# File 'lib/privy/models/evm_user_operation_wallet_action_step.rb', line 34 required :type, enum: -> { Privy::EvmUserOperationWalletActionStep::Type } |
#user_operation_hash ⇒ String?
The user operation hash for this step. May change while the step status is non-terminal.
41 |
# File 'lib/privy/models/evm_user_operation_wallet_action_step.rb', line 41 required :user_operation_hash, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/privy/models/evm_user_operation_wallet_action_step.rb', line 80
|