Class: Privy::Models::ExchangeStripeTokensInput

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/privy/models/exchange_stripe_tokens_input.rb,
sig/privy/models/exchange_stripe_tokens_input.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(auth_intent_id:, crypto_customer_id:, environment: nil) ⇒ Object

Input for exchanging a Link auth intent for OAuth tokens.

Parameters:

  • auth_intent_id (String)
  • crypto_customer_id (String)
  • environment (Symbol, Privy::Models::FiatOnrampEnvironment) (defaults to: nil)

    Whether to use the sandbox or production environment for fiat onramp.



# File 'lib/privy/models/exchange_stripe_tokens_input.rb', line 22

Instance Attribute Details

#auth_intent_idString

Parameters:

  • value (String)

Returns:

  • (String)


9
# File 'lib/privy/models/exchange_stripe_tokens_input.rb', line 9

required :auth_intent_id, String

#crypto_customer_idString

Parameters:

  • value (String)

Returns:

  • (String)


14
# File 'lib/privy/models/exchange_stripe_tokens_input.rb', line 14

required :crypto_customer_id, String

#environmentSymbol, ...

Whether to use the sandbox or production environment for fiat onramp.

Returns:



20
# File 'lib/privy/models/exchange_stripe_tokens_input.rb', line 20

optional :environment, enum: -> { Privy::FiatOnrampEnvironment }

Instance Method Details

#to_hash{

Returns:

  • ({)


27
# File 'sig/privy/models/exchange_stripe_tokens_input.rbs', line 27

def to_hash: -> {