Class: Privy::Models::FarcasterSignerStatusPendingApproval
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::FarcasterSignerStatusPendingApproval
- Defined in:
- lib/privy/models/farcaster_signer_status_pending_approval.rb
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(public_key:, status:) ⇒ Object
constructor
A Farcaster signer status response when the signer is pending approval.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(public_key:, status:) ⇒ Object
A Farcaster signer status response when the signer is pending approval.
|
|
# File 'lib/privy/models/farcaster_signer_status_pending_approval.rb', line 16
|
Instance Attribute Details
#public_key ⇒ String
9 |
# File 'lib/privy/models/farcaster_signer_status_pending_approval.rb', line 9 required :public_key, String |
#status ⇒ Symbol, Privy::Models::FarcasterSignerStatusPendingApproval::Status
14 |
# File 'lib/privy/models/farcaster_signer_status_pending_approval.rb', line 14 required :status, enum: -> { Privy::FarcasterSignerStatusPendingApproval::Status } |