Class: Privy::Models::FiatOnrampDestination

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/privy/models/fiat_onramp_destination.rb,
sig/privy/models/fiat_onramp_destination.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(address:, asset:, chain:) ⇒ FiatOnrampDestination

Some parameter documentations has been truncated, see Privy::Models::FiatOnrampDestination for more details.

Destination cryptocurrency details for a fiat onramp quote request.

Parameters:

  • address (String)
  • asset (String)

    Token identifier string. EVM-shaped 40-hex token addresses normalize to checksum

  • chain (String)

    A CAIP-2 chain identifier in namespace:reference format (e.g. "eip155:1" for Eth

  • address: (String)
  • asset: (String)
  • chain: (String)


# File 'lib/privy/models/fiat_onramp_destination.rb', line 26

Instance Attribute Details

#addressString

Parameters:

  • value (String)

Returns:

  • (String)


9
# File 'lib/privy/models/fiat_onramp_destination.rb', line 9

required :address, String

#assetString

Token identifier string. EVM-shaped 40-hex token addresses normalize to checksum case, 16-byte Hyperliquid token IDs normalize to lowercase, and all other identifiers pass through unchanged.

Parameters:

  • value (String)

Returns:

  • (String)


17
# File 'lib/privy/models/fiat_onramp_destination.rb', line 17

required :asset, String

#chainString

A CAIP-2 chain identifier in namespace:reference format (e.g. "eip155:1" for Ethereum mainnet, "solana:5eykt4UsFv8P8NJdTREpY1vzqKqZKvdp" for Solana mainnet).

Parameters:

  • value (String)

Returns:

  • (String)


24
# File 'lib/privy/models/fiat_onramp_destination.rb', line 24

required :chain, String

Instance Method Details

#to_hash{ address: String, asset: String, chain: String }

Returns:

  • ({ address: String, asset: String, chain: String })


15
# File 'sig/privy/models/fiat_onramp_destination.rbs', line 15

def to_hash: -> { address: String, asset: String, chain: String }