Class: Privy::Models::FiatOnrampSource
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::FiatOnrampSource
- Defined in:
- lib/privy/models/fiat_onramp_source.rb
Instance Attribute Summary collapse
-
#amount ⇒ String
A positive decimal amount as a string (e.g. “100”, “50.25”, “0.001”).
-
#asset ⇒ String
ISO 4217 fiat currency code.
Instance Method Summary collapse
-
#initialize(amount:, asset:) ⇒ Object
constructor
Source currency details for a fiat onramp quote request.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, asset:) ⇒ Object
Source currency details for a fiat onramp quote request.
|
|
# File 'lib/privy/models/fiat_onramp_source.rb', line 18
|
Instance Attribute Details
#amount ⇒ String
A positive decimal amount as a string (e.g. “100”, “50.25”, “0.001”).
10 |
# File 'lib/privy/models/fiat_onramp_source.rb', line 10 required :amount, String |
#asset ⇒ String
ISO 4217 fiat currency code. Three uppercase ASCII letters.
16 |
# File 'lib/privy/models/fiat_onramp_source.rb', line 16 required :asset, String |