Class: Privy::Models::FundsDepositedWebhookPayload

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/privy/models/funds_deposited_webhook_payload.rb,
sig/privy/models/funds_deposited_webhook_payload.rbs

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount:, asset:, block:, caip2:, idempotency_key:, recipient:, sender:, transaction_hash:, type:, wallet_id:, bridge_metadata: nil, transaction_fee: nil) ⇒ Object

Payload for the wallet.funds_deposited webhook event.

Parameters:



# File 'lib/privy/models/funds_deposited_webhook_payload.rb', line 78

Instance Attribute Details

#amountString

The amount transferred, as a stringified bigint.

Parameters:

  • value (String)

Returns:

  • (String)


10
# File 'lib/privy/models/funds_deposited_webhook_payload.rb', line 10

required :amount, String

#assetPrivy::Models::WalletFundsNativeTokenAsset, ...

An asset involved in a wallet transfer.



16
# File 'lib/privy/models/funds_deposited_webhook_payload.rb', line 16

required :asset, union: -> { Privy::WalletFundsAsset }

#blockPrivy::Models::BlockInfo

Block metadata for a wallet transfer event.

Parameters:

Returns:



22
# File 'lib/privy/models/funds_deposited_webhook_payload.rb', line 22

required :block, -> { Privy::BlockInfo }

#bridge_metadataPrivy::Models::BridgeCryptoDepositMetadata, ...

Metadata about a Bridge transaction associated with a wallet event.



70
# File 'lib/privy/models/funds_deposited_webhook_payload.rb', line 70

optional :bridge_metadata, union: -> { Privy::BridgeMetadata }

#caip2String

The CAIP-2 chain identifier.

Parameters:

  • value (String)

Returns:

  • (String)


28
# File 'lib/privy/models/funds_deposited_webhook_payload.rb', line 28

required :caip2, String

#idempotency_keyString

A unique key for this event.

Parameters:

  • value (String)

Returns:

  • (String)


34
# File 'lib/privy/models/funds_deposited_webhook_payload.rb', line 34

required :idempotency_key, String

#recipientString

The recipient address.

Parameters:

  • value (String)

Returns:

  • (String)


40
# File 'lib/privy/models/funds_deposited_webhook_payload.rb', line 40

required :recipient, String

#senderString

The sender address.

Parameters:

  • value (String)

Returns:

  • (String)


46
# File 'lib/privy/models/funds_deposited_webhook_payload.rb', line 46

required :sender, String

#transaction_feeString?

The transaction fee paid, as a stringified bigint in the chain's native token.

Parameters:

  • (String)

Returns:

  • (String, nil)


76
# File 'lib/privy/models/funds_deposited_webhook_payload.rb', line 76

optional :transaction_fee, String

#transaction_hashString

The blockchain transaction hash.

Parameters:

  • value (String)

Returns:

  • (String)


52
# File 'lib/privy/models/funds_deposited_webhook_payload.rb', line 52

required :transaction_hash, String

#typeSymbol, Privy::Models::FundsDepositedWebhookPayload::Type

The type of webhook event.

Parameters:

  • value (Privy::Models::FundsDepositedWebhookPayload::type_)

Returns:



58
# File 'lib/privy/models/funds_deposited_webhook_payload.rb', line 58

required :type, enum: -> { Privy::FundsDepositedWebhookPayload::Type }

#wallet_idString

The ID of the wallet.

Parameters:

  • value (String)

Returns:

  • (String)


64
# File 'lib/privy/models/funds_deposited_webhook_payload.rb', line 64

required :wallet_id, String

Instance Method Details

#to_hash{

Returns:

  • ({)


65
# File 'sig/privy/models/funds_deposited_webhook_payload.rbs', line 65

def to_hash: -> {