Class: Privy::Models::GasSpendResponseBody
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::GasSpendResponseBody
- Defined in:
- lib/privy/models/gas_spend_response_body.rb
Overview
Instance Attribute Summary collapse
-
#currency ⇒ Symbol, Privy::Models::GasSpendCurrency
Currency for gas spend values.
-
#value ⇒ String
Total Privy credits charged as a decimal string.
Instance Method Summary collapse
-
#initialize(currency:, value:) ⇒ Object
constructor
Aggregated Privy gas credits charged for a set of wallets over a time range.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(currency:, value:) ⇒ Object
Aggregated Privy gas credits charged for a set of wallets over a time range.
|
|
# File 'lib/privy/models/gas_spend_response_body.rb', line 19
|
Instance Attribute Details
#currency ⇒ Symbol, Privy::Models::GasSpendCurrency
Currency for gas spend values.
11 |
# File 'lib/privy/models/gas_spend_response_body.rb', line 11 required :currency, enum: -> { Privy::GasSpendCurrency } |
#value ⇒ String
Total Privy credits charged as a decimal string.
17 |
# File 'lib/privy/models/gas_spend_response_body.rb', line 17 required :value, String |