Class: Privy::Models::HDSubmitInput

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/privy/models/hd_submit_input.rb

Defined Under Namespace

Modules: EntropyType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(address:, chain_type:, ciphertext:, encapsulated_key:, encryption_type:, entropy_type:, index:, hpke_config: nil) ⇒ Object

Some parameter documentations has been truncated, see Privy::Models::HDSubmitInput for more details.

The submission input for importing an HD wallet.

Parameters:

  • address (String)

    The address of the wallet to import.

  • chain_type (Symbol, Privy::Models::WalletImportSupportedChains)

    The chain type of the wallet to import. Currently supports ‘ethereum` and `solan

  • ciphertext (String)

    The encrypted entropy of the wallet to import.

  • encapsulated_key (String)

    The base64-encoded encapsulated key that was generated during encryption, for us

  • encryption_type (Symbol, Privy::Models::HpkeEncryption)

    The encryption type of the wallet to import. Currently only supports ‘HPKE`.

  • entropy_type (Symbol, Privy::Models::HDSubmitInput::EntropyType)

    The entropy type of the wallet to import.

  • index (Integer)

    The index of the wallet to import.

  • hpke_config (Privy::Models::HpkeImportConfig) (defaults to: nil)

    Optional HPKE configuration for wallet import decryption. These parameters allow



# File 'lib/privy/models/hd_submit_input.rb', line 58

Instance Attribute Details

#addressString

The address of the wallet to import.

Returns:

  • (String)


10
# File 'lib/privy/models/hd_submit_input.rb', line 10

required :address, String

#chain_typeSymbol, Privy::Models::WalletImportSupportedChains

The chain type of the wallet to import. Currently supports ‘ethereum` and `solana`.



17
# File 'lib/privy/models/hd_submit_input.rb', line 17

required :chain_type, enum: -> { Privy::WalletImportSupportedChains }

#ciphertextString

The encrypted entropy of the wallet to import.

Returns:

  • (String)


23
# File 'lib/privy/models/hd_submit_input.rb', line 23

required :ciphertext, String

#encapsulated_keyString

The base64-encoded encapsulated key that was generated during encryption, for use during decryption inside the TEE.

Returns:

  • (String)


30
# File 'lib/privy/models/hd_submit_input.rb', line 30

required :encapsulated_key, String

#encryption_typeSymbol, Privy::Models::HpkeEncryption

The encryption type of the wallet to import. Currently only supports ‘HPKE`.

Returns:



36
# File 'lib/privy/models/hd_submit_input.rb', line 36

required :encryption_type, enum: -> { Privy::HpkeEncryption }

#entropy_typeSymbol, Privy::Models::HDSubmitInput::EntropyType

The entropy type of the wallet to import.



42
# File 'lib/privy/models/hd_submit_input.rb', line 42

required :entropy_type, enum: -> { Privy::HDSubmitInput::EntropyType }

#hpke_configPrivy::Models::HpkeImportConfig?

Optional HPKE configuration for wallet import decryption. These parameters allow importing wallets encrypted by external providers that use different HPKE configurations.



56
# File 'lib/privy/models/hd_submit_input.rb', line 56

optional :hpke_config, -> { Privy::HpkeImportConfig }

#indexInteger

The index of the wallet to import.

Returns:

  • (Integer)


48
# File 'lib/privy/models/hd_submit_input.rb', line 48

required :index, Integer