Class: Privy::Models::IntentAuthorizationKeyQuorum
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::IntentAuthorizationKeyQuorum
- Defined in:
- lib/privy/models/intent_authorization_key_quorum.rb,
sig/privy/models/intent_authorization_key_quorum.rbs
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#display_name ⇒ String?
Display name for the child key quorum (if any).
-
#key_quorum_id ⇒ String
ID of the child key quorum member.
-
#members ⇒ Array<Privy::Models::IntentAuthorizationUserMember, Privy::Models::IntentAuthorizationKeyMember>
Members of this child quorum.
-
#threshold ⇒ Float
Number of signatures required from this child quorum.
-
#threshold_met ⇒ Boolean
Whether this child key quorum has met its signature threshold.
- #type ⇒ Symbol, Privy::Models::IntentAuthorizationKeyQuorum::Type
Instance Method Summary collapse
-
#initialize(key_quorum_id:, members:, threshold:, threshold_met:, type:, display_name: nil) ⇒ Object
constructor
A nested key quorum member of an intent authorization quorum.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(key_quorum_id:, members:, threshold:, threshold_met:, type:, display_name: nil) ⇒ Object
A nested key quorum member of an intent authorization quorum.
|
|
# File 'lib/privy/models/intent_authorization_key_quorum.rb', line 41
|
Instance Attribute Details
#display_name ⇒ String?
Display name for the child key quorum (if any)
39 |
# File 'lib/privy/models/intent_authorization_key_quorum.rb', line 39 optional :display_name, String |
#key_quorum_id ⇒ String
ID of the child key quorum member
10 |
# File 'lib/privy/models/intent_authorization_key_quorum.rb', line 10 required :key_quorum_id, String |
#members ⇒ Array<Privy::Models::IntentAuthorizationUserMember, Privy::Models::IntentAuthorizationKeyMember>
Members of this child quorum
16 |
# File 'lib/privy/models/intent_authorization_key_quorum.rb', line 16 required :members, -> { Privy::Internal::Type::ArrayOf[union: Privy::IntentAuthorizationKeyQuorumMember] } |
#threshold ⇒ Float
Number of signatures required from this child quorum
22 |
# File 'lib/privy/models/intent_authorization_key_quorum.rb', line 22 required :threshold, Float |
#threshold_met ⇒ Boolean
Whether this child key quorum has met its signature threshold
28 |
# File 'lib/privy/models/intent_authorization_key_quorum.rb', line 28 required :threshold_met, Privy::Internal::Type::Boolean |
#type ⇒ Symbol, Privy::Models::IntentAuthorizationKeyQuorum::Type
33 |
# File 'lib/privy/models/intent_authorization_key_quorum.rb', line 33 required :type, enum: -> { Privy::IntentAuthorizationKeyQuorum::Type } |
Instance Method Details
#to_hash ⇒ {
37 |
# File 'sig/privy/models/intent_authorization_key_quorum.rbs', line 37
def to_hash: -> {
|