Class: Privy::Models::IntentAuthorizationMember::KeyQuorumMember
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::IntentAuthorizationMember::KeyQuorumMember
- Defined in:
- lib/privy/models/intent_authorization_member.rb
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#display_name ⇒ String?
Display name for the child key quorum (if any).
-
#key_quorum_id ⇒ String
ID of the child key quorum member.
-
#members ⇒ Array<Privy::Models::IntentAuthorizationKeyQuorumMember::UserMember, Privy::Models::IntentAuthorizationKeyQuorumMember::KeyMember>
Members of this child quorum.
-
#threshold ⇒ Float
Number of signatures required from this child quorum.
-
#threshold_met ⇒ Boolean
Whether this child key quorum has met its signature threshold.
- #type ⇒ Symbol, Privy::Models::IntentAuthorizationMember::KeyQuorumMember::Type
Instance Method Summary collapse
- #initialize(key_quorum_id:, members:, threshold:, threshold_met:, type:, display_name: nil) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(key_quorum_id:, members:, threshold:, threshold_met:, type:, display_name: nil) ⇒ Object
|
|
# File 'lib/privy/models/intent_authorization_member.rb', line 124
|
Instance Attribute Details
#display_name ⇒ String?
Display name for the child key quorum (if any)
122 |
# File 'lib/privy/models/intent_authorization_member.rb', line 122 optional :display_name, String |
#key_quorum_id ⇒ String
ID of the child key quorum member
93 |
# File 'lib/privy/models/intent_authorization_member.rb', line 93 required :key_quorum_id, String |
#members ⇒ Array<Privy::Models::IntentAuthorizationKeyQuorumMember::UserMember, Privy::Models::IntentAuthorizationKeyQuorumMember::KeyMember>
Members of this child quorum
99 |
# File 'lib/privy/models/intent_authorization_member.rb', line 99 required :members, -> { Privy::Internal::Type::ArrayOf[union: Privy::IntentAuthorizationKeyQuorumMember] } |
#threshold ⇒ Float
Number of signatures required from this child quorum
105 |
# File 'lib/privy/models/intent_authorization_member.rb', line 105 required :threshold, Float |
#threshold_met ⇒ Boolean
Whether this child key quorum has met its signature threshold
111 |
# File 'lib/privy/models/intent_authorization_member.rb', line 111 required :threshold_met, Privy::Internal::Type::Boolean |
#type ⇒ Symbol, Privy::Models::IntentAuthorizationMember::KeyQuorumMember::Type
116 |
# File 'lib/privy/models/intent_authorization_member.rb', line 116 required :type, enum: -> { Privy::IntentAuthorizationMember::KeyQuorumMember::Type } |