Class: Privy::Models::IntentAuthorizationMember::UserMember
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::IntentAuthorizationMember::UserMember
- Defined in:
- lib/privy/models/intent_authorization_member.rb
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#signed_at ⇒ Float?
Unix timestamp when this member signed, or null if not yet signed.
- #type ⇒ Symbol, Privy::Models::IntentAuthorizationMember::UserMember::Type
-
#user_id ⇒ String
User ID of the key quorum member.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(signed_at:, type:, user_id:) ⇒ Object
|
|
# File 'lib/privy/models/intent_authorization_member.rb', line 34
|
Instance Attribute Details
#signed_at ⇒ Float?
Unix timestamp when this member signed, or null if not yet signed.
21 |
# File 'lib/privy/models/intent_authorization_member.rb', line 21 required :signed_at, Float, nil?: true |
#type ⇒ Symbol, Privy::Models::IntentAuthorizationMember::UserMember::Type
26 |
# File 'lib/privy/models/intent_authorization_member.rb', line 26 required :type, enum: -> { Privy::IntentAuthorizationMember::UserMember::Type } |
#user_id ⇒ String
User ID of the key quorum member
32 |
# File 'lib/privy/models/intent_authorization_member.rb', line 32 required :user_id, String |