Class: Privy::Models::IntentAuthorizedWebhookPayload

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/privy/models/intent_authorized_webhook_payload.rb,
sig/privy/models/intent_authorized_webhook_payload.rbs

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(authorized_at:, created_at:, expires_at:, intent_id:, intent_type:, member:, status:, type:, created_by_display_name: nil, created_by_id: nil) ⇒ Object

Payload for the intent.authorized webhook event.

Parameters:

  • authorized_at (Float)

    Unix timestamp when the authorization was recorded.

  • created_at (Float)

    Unix timestamp when the intent was created.

  • expires_at (Float)

    Unix timestamp when the intent expires.

  • intent_id (String)

    The unique ID of the intent.

  • intent_type (Symbol, Privy::Models::IntentType)

    Type of intent.

  • member (Privy::Models::IntentAuthorizationUserMember, Privy::Models::IntentAuthorizationKeyMember)

    A leaf member (user or key) of a nested key quorum in an intent authorization.

  • status (String)

    The current status of the intent.

  • type (Symbol, Privy::Models::IntentAuthorizedWebhookPayload::Type)

    The type of webhook event.

  • created_by_display_name (String) (defaults to: nil)

    Display name of the user who created the intent.

  • created_by_id (String) (defaults to: nil)

    The ID of the user who created the intent.



# File 'lib/privy/models/intent_authorized_webhook_payload.rb', line 66

Instance Attribute Details

#authorized_atFloat

Unix timestamp when the authorization was recorded.

Parameters:

  • value (Float)

Returns:

  • (Float)


10
# File 'lib/privy/models/intent_authorized_webhook_payload.rb', line 10

required :authorized_at, Float

#created_atFloat

Unix timestamp when the intent was created.

Parameters:

  • value (Float)

Returns:

  • (Float)


16
# File 'lib/privy/models/intent_authorized_webhook_payload.rb', line 16

required :created_at, Float

#created_by_display_nameString?

Display name of the user who created the intent.

Parameters:

  • (String)

Returns:

  • (String, nil)


58
# File 'lib/privy/models/intent_authorized_webhook_payload.rb', line 58

optional :created_by_display_name, String

#created_by_idString?

The ID of the user who created the intent.

Parameters:

  • (String)

Returns:

  • (String, nil)


64
# File 'lib/privy/models/intent_authorized_webhook_payload.rb', line 64

optional :created_by_id, String

#expires_atFloat

Unix timestamp when the intent expires.

Parameters:

  • value (Float)

Returns:

  • (Float)


22
# File 'lib/privy/models/intent_authorized_webhook_payload.rb', line 22

required :expires_at, Float

#intent_idString

The unique ID of the intent.

Parameters:

  • value (String)

Returns:

  • (String)


28
# File 'lib/privy/models/intent_authorized_webhook_payload.rb', line 28

required :intent_id, String

#intent_typeSymbol, Privy::Models::IntentType

Type of intent.

Parameters:

  • value (Privy::Models::intent_type)

Returns:



34
# File 'lib/privy/models/intent_authorized_webhook_payload.rb', line 34

required :intent_type, enum: -> { Privy::IntentType }

#memberPrivy::Models::IntentAuthorizationUserMember, Privy::Models::IntentAuthorizationKeyMember

A leaf member (user or key) of a nested key quorum in an intent authorization.

Parameters:

  • value (Privy::Models::intent_authorization_key_quorum_member)

Returns:



40
# File 'lib/privy/models/intent_authorized_webhook_payload.rb', line 40

required :member, union: -> { Privy::IntentAuthorizationKeyQuorumMember }

#statusString

The current status of the intent.

Parameters:

  • value (String)

Returns:

  • (String)


46
# File 'lib/privy/models/intent_authorized_webhook_payload.rb', line 46

required :status, String

#typeSymbol, Privy::Models::IntentAuthorizedWebhookPayload::Type

The type of webhook event.

Parameters:

  • value (Privy::Models::IntentAuthorizedWebhookPayload::type_)

Returns:



52
# File 'lib/privy/models/intent_authorized_webhook_payload.rb', line 52

required :type, enum: -> { Privy::IntentAuthorizedWebhookPayload::Type }

Instance Method Details

#to_hash{

Returns:

  • ({)


55
# File 'sig/privy/models/intent_authorized_webhook_payload.rbs', line 55

def to_hash: -> {