Class: Privy::Models::IntentCreationHeaders
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::IntentCreationHeaders
- Defined in:
- lib/privy/models/intent_creation_headers.rb
Instance Attribute Summary collapse
-
#privy_app_id ⇒ String
ID of your Privy app.
-
#privy_request_expiry ⇒ String?
Request expiry.
Instance Method Summary collapse
-
#initialize(privy_app_id:, privy_request_expiry: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see IntentCreationHeaders for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(privy_app_id:, privy_request_expiry: nil) ⇒ Object
Some parameter documentations has been truncated, see Privy::Models::IntentCreationHeaders for more details.
Headers required to create an intent.
|
|
# File 'lib/privy/models/intent_creation_headers.rb', line 19
|
Instance Attribute Details
#privy_app_id ⇒ String
ID of your Privy app.
10 |
# File 'lib/privy/models/intent_creation_headers.rb', line 10 required :privy_app_id, String, api_name: :"privy-app-id" |
#privy_request_expiry ⇒ String?
Request expiry. Value is a Unix timestamp in milliseconds representing the deadline by which the request must be processed.
17 |
# File 'lib/privy/models/intent_creation_headers.rb', line 17 optional :privy_request_expiry, String, api_name: :"privy-request-expiry" |