Class: Privy::Models::IntentExecutedWebhookPayload
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::IntentExecutedWebhookPayload
- Defined in:
- lib/privy/models/intent_executed_webhook_payload.rb
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#action_result ⇒ Privy::Models::BaseActionResult
Result of the successful intent execution.
-
#created_at ⇒ Float
Unix timestamp when the intent was created.
-
#created_by_display_name ⇒ String?
Display name of the user who created the intent.
-
#created_by_id ⇒ String?
The ID of the user who created the intent.
-
#expires_at ⇒ Float
Unix timestamp when the intent expires.
-
#intent_id ⇒ String
The unique ID of the intent.
-
#intent_type ⇒ Symbol, Privy::Models::IntentType
Type of intent.
-
#status ⇒ String
The current status of the intent.
-
#type ⇒ Symbol, Privy::Models::IntentExecutedWebhookPayload::Type
The type of webhook event.
Instance Method Summary collapse
-
#initialize(action_result:, created_at:, expires_at:, intent_id:, intent_type:, status:, type:, created_by_display_name: nil, created_by_id: nil) ⇒ Object
constructor
Payload for the intent.executed webhook event.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(action_result:, created_at:, expires_at:, intent_id:, intent_type:, status:, type:, created_by_display_name: nil, created_by_id: nil) ⇒ Object
Payload for the intent.executed webhook event.
|
|
# File 'lib/privy/models/intent_executed_webhook_payload.rb', line 60
|
Instance Attribute Details
#action_result ⇒ Privy::Models::BaseActionResult
Result of the successful intent execution.
10 |
# File 'lib/privy/models/intent_executed_webhook_payload.rb', line 10 required :action_result, -> { Privy::BaseActionResult } |
#created_at ⇒ Float
Unix timestamp when the intent was created.
16 |
# File 'lib/privy/models/intent_executed_webhook_payload.rb', line 16 required :created_at, Float |
#created_by_display_name ⇒ String?
Display name of the user who created the intent.
52 |
# File 'lib/privy/models/intent_executed_webhook_payload.rb', line 52 optional :created_by_display_name, String |
#created_by_id ⇒ String?
The ID of the user who created the intent.
58 |
# File 'lib/privy/models/intent_executed_webhook_payload.rb', line 58 optional :created_by_id, String |
#expires_at ⇒ Float
Unix timestamp when the intent expires.
22 |
# File 'lib/privy/models/intent_executed_webhook_payload.rb', line 22 required :expires_at, Float |
#intent_id ⇒ String
The unique ID of the intent.
28 |
# File 'lib/privy/models/intent_executed_webhook_payload.rb', line 28 required :intent_id, String |
#intent_type ⇒ Symbol, Privy::Models::IntentType
Type of intent.
34 |
# File 'lib/privy/models/intent_executed_webhook_payload.rb', line 34 required :intent_type, enum: -> { Privy::IntentType } |
#status ⇒ String
The current status of the intent.
40 |
# File 'lib/privy/models/intent_executed_webhook_payload.rb', line 40 required :status, String |
#type ⇒ Symbol, Privy::Models::IntentExecutedWebhookPayload::Type
The type of webhook event.
46 |
# File 'lib/privy/models/intent_executed_webhook_payload.rb', line 46 required :type, enum: -> { Privy::IntentExecutedWebhookPayload::Type } |