Class: Privy::Models::IntentRejectedWebhookPayload

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/privy/models/intent_rejected_webhook_payload.rb

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(created_at:, expires_at:, intent_id:, intent_type:, rejected_at:, status:, type:, created_by_display_name: nil, created_by_id: nil) ⇒ Object

Payload for the intent.rejected webhook event.

Parameters:

  • created_at (Float)

    Unix timestamp when the intent was created.

  • expires_at (Float)

    Unix timestamp when the intent expires.

  • intent_id (String)

    The unique ID of the intent.

  • intent_type (Symbol, Privy::Models::IntentType)

    Type of intent.

  • rejected_at (Float)

    Unix timestamp when the intent was rejected.

  • status (String)

    The current status of the intent.

  • type (Symbol, Privy::Models::IntentRejectedWebhookPayload::Type)

    The type of webhook event.

  • created_by_display_name (String) (defaults to: nil)

    Display name of the user who created the intent.

  • created_by_id (String) (defaults to: nil)

    The ID of the user who created the intent.



# File 'lib/privy/models/intent_rejected_webhook_payload.rb', line 60

Instance Attribute Details

#created_atFloat

Unix timestamp when the intent was created.

Returns:

  • (Float)


10
# File 'lib/privy/models/intent_rejected_webhook_payload.rb', line 10

required :created_at, Float

#created_by_display_nameString?

Display name of the user who created the intent.

Returns:

  • (String, nil)


52
# File 'lib/privy/models/intent_rejected_webhook_payload.rb', line 52

optional :created_by_display_name, String

#created_by_idString?

The ID of the user who created the intent.

Returns:

  • (String, nil)


58
# File 'lib/privy/models/intent_rejected_webhook_payload.rb', line 58

optional :created_by_id, String

#expires_atFloat

Unix timestamp when the intent expires.

Returns:

  • (Float)


16
# File 'lib/privy/models/intent_rejected_webhook_payload.rb', line 16

required :expires_at, Float

#intent_idString

The unique ID of the intent.

Returns:

  • (String)


22
# File 'lib/privy/models/intent_rejected_webhook_payload.rb', line 22

required :intent_id, String

#intent_typeSymbol, Privy::Models::IntentType

Type of intent.

Returns:



28
# File 'lib/privy/models/intent_rejected_webhook_payload.rb', line 28

required :intent_type, enum: -> { Privy::IntentType }

#rejected_atFloat

Unix timestamp when the intent was rejected.

Returns:

  • (Float)


34
# File 'lib/privy/models/intent_rejected_webhook_payload.rb', line 34

required :rejected_at, Float

#statusString

The current status of the intent.

Returns:

  • (String)


40
# File 'lib/privy/models/intent_rejected_webhook_payload.rb', line 40

required :status, String

#typeSymbol, Privy::Models::IntentRejectedWebhookPayload::Type

The type of webhook event.



46
# File 'lib/privy/models/intent_rejected_webhook_payload.rb', line 46

required :type, enum: -> { Privy::IntentRejectedWebhookPayload::Type }