Class: Privy::Models::IntentTransferParams

Inherits:
TransferRequestBody show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/privy/models/intent_transfer_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Attributes inherited from TransferRequestBody

#amount_type, #destination, #fee_configuration, #slippage_bps, #source

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(wallet_id:, privy_request_expiry: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Privy::Models::IntentTransferParams for more details.

Parameters:

  • wallet_id (String)

    ID of the wallet.

  • privy_request_expiry (String) (defaults to: nil)

    Request expiry. Value is a Unix timestamp in milliseconds representing the deadl

  • request_options (Privy::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/privy/models/intent_transfer_params.rb', line 23

Instance Attribute Details

#privy_request_expiryString?

Request expiry. Value is a Unix timestamp in milliseconds representing the deadline by which the request must be processed.

Returns:

  • (String, nil)


21
# File 'lib/privy/models/intent_transfer_params.rb', line 21

optional :privy_request_expiry, String

#wallet_idString

ID of the wallet.

Returns:

  • (String)


14
# File 'lib/privy/models/intent_transfer_params.rb', line 14

required :wallet_id, String