Class: Privy::Models::IntentUpdateKeyQuorumParams

Inherits:
KeyQuorumUpdateRequestBody show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/privy/models/intent_update_key_quorum_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Attributes inherited from KeyQuorumUpdateRequestBody

#authorization_threshold, #display_name, #key_quorum_ids, #public_keys, #user_ids

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(key_quorum_id:, privy_request_expiry: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Privy::Models::IntentUpdateKeyQuorumParams for more details.

Parameters:

  • key_quorum_id (String)

    ID of the key quorum.

  • privy_request_expiry (String) (defaults to: nil)

    Request expiry. Value is a Unix timestamp in milliseconds representing the deadl

  • request_options (Privy::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/privy/models/intent_update_key_quorum_params.rb', line 23

Instance Attribute Details

#key_quorum_idString

ID of the key quorum.

Returns:

  • (String)


14
# File 'lib/privy/models/intent_update_key_quorum_params.rb', line 14

required :key_quorum_id, String

#privy_request_expiryString?

Request expiry. Value is a Unix timestamp in milliseconds representing the deadline by which the request must be processed.

Returns:

  • (String, nil)


21
# File 'lib/privy/models/intent_update_key_quorum_params.rb', line 21

optional :privy_request_expiry, String