Class: Privy::Models::IntentUpdatePolicyParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/privy/models/intent_update_policy_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(policy_id:, name: nil, owner: nil, owner_id: nil, rules: nil, privy_request_expiry: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Privy::Models::IntentUpdatePolicyParams for more details.

Parameters:

  • policy_id (String)

    ID of the policy.

  • name (String) (defaults to: nil)

    Name to assign to policy.

  • owner (Privy::Models::OwnerInputUser, Privy::Models::OwnerInputPublicKey, nil) (defaults to: nil)

    The owner of the resource, specified as a Privy user ID, a P-256 public key, or

  • owner_id (String, nil) (defaults to: nil)

    The key quorum ID to set as the owner of the resource. If you provide this, do n

  • rules (Array<Privy::Models::PolicyRuleRequestBody>) (defaults to: nil)
  • privy_request_expiry (String) (defaults to: nil)

    Request expiry. Value is a Unix timestamp in milliseconds representing the deadl

  • request_options (Privy::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/privy/models/intent_update_policy_params.rb', line 48

Instance Attribute Details

#nameString?

Name to assign to policy.

Returns:

  • (String, nil)


20
# File 'lib/privy/models/intent_update_policy_params.rb', line 20

optional :name, String

#ownerPrivy::Models::OwnerInputUser, ...

The owner of the resource, specified as a Privy user ID, a P-256 public key, or null to remove the current owner.



27
# File 'lib/privy/models/intent_update_policy_params.rb', line 27

optional :owner, union: -> { Privy::OwnerInput }, nil?: true

#owner_idString?

The key quorum ID to set as the owner of the resource. If you provide this, do not specify an owner.

Returns:

  • (String, nil)


34
# File 'lib/privy/models/intent_update_policy_params.rb', line 34

optional :owner_id, String, nil?: true

#policy_idString

ID of the policy.

Returns:

  • (String)


14
# File 'lib/privy/models/intent_update_policy_params.rb', line 14

required :policy_id, String

#privy_request_expiryString?

Request expiry. Value is a Unix timestamp in milliseconds representing the deadline by which the request must be processed.

Returns:

  • (String, nil)


46
# File 'lib/privy/models/intent_update_policy_params.rb', line 46

optional :privy_request_expiry, String

#rulesArray<Privy::Models::PolicyRuleRequestBody>?

Returns:



39
# File 'lib/privy/models/intent_update_policy_params.rb', line 39

optional :rules, -> { Privy::Internal::Type::ArrayOf[Privy::PolicyRuleRequestBody] }