Class: Privy::Models::IntentUpdateWalletParams
- Inherits:
-
WalletUpdateRequestBody
- Object
- Internal::Type::BaseModel
- WalletUpdateRequestBody
- Privy::Models::IntentUpdateWalletParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/privy/models/intent_update_wallet_params.rb
Overview
Instance Attribute Summary collapse
-
#privy_request_expiry ⇒ String?
Request expiry.
-
#wallet_id ⇒ String
ID of the wallet.
Attributes included from Internal::Type::RequestParameters
Attributes inherited from WalletUpdateRequestBody
#additional_signers, #display_name, #owner, #owner_id, #policy_ids
Instance Method Summary collapse
-
#initialize(wallet_id:, privy_request_expiry: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see IntentUpdateWalletParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(wallet_id:, privy_request_expiry: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Privy::Models::IntentUpdateWalletParams for more details.
|
|
# File 'lib/privy/models/intent_update_wallet_params.rb', line 23
|
Instance Attribute Details
#privy_request_expiry ⇒ String?
Request expiry. Value is a Unix timestamp in milliseconds representing the deadline by which the request must be processed.
21 |
# File 'lib/privy/models/intent_update_wallet_params.rb', line 21 optional :privy_request_expiry, String |
#wallet_id ⇒ String
ID of the wallet.
14 |
# File 'lib/privy/models/intent_update_wallet_params.rb', line 14 required :wallet_id, String |