Class: Privy::Models::KeyQuorumCreateRequestBody
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::KeyQuorumCreateRequestBody
- Defined in:
- lib/privy/models/key_quorum_create_request_body.rb
Direct Known Subclasses
Instance Attribute Summary collapse
-
#authorization_threshold ⇒ Float?
The number of keys that must sign for an action to be valid.
- #display_name ⇒ String?
-
#key_quorum_ids ⇒ Array<String>?
List of key quorum IDs that should be members of this key quorum.
-
#public_keys ⇒ Array<String>?
List of P-256 public keys of the keys that should be authorized to sign on the key quorum, in base64-encoded DER format.
-
#user_ids ⇒ Array<String>?
List of user IDs of the users that should be authorized to sign on the key quorum.
Instance Method Summary collapse
-
#initialize(authorization_threshold: nil, display_name: nil, key_quorum_ids: nil, public_keys: nil, user_ids: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see KeyQuorumCreateRequestBody for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(authorization_threshold: nil, display_name: nil, key_quorum_ids: nil, public_keys: nil, user_ids: nil) ⇒ Object
Some parameter documentations has been truncated, see Privy::Models::KeyQuorumCreateRequestBody for more details.
Request input for creating a key quorum. At least one of ‘user_ids`, `public_keys`, or `key_quorum_ids` is required.
|
|
# File 'lib/privy/models/key_quorum_create_request_body.rb', line 42
|
Instance Attribute Details
#authorization_threshold ⇒ Float?
The number of keys that must sign for an action to be valid. Must be less than or equal to total number of key quorum members.
11 |
# File 'lib/privy/models/key_quorum_create_request_body.rb', line 11 optional :authorization_threshold, Float |
#display_name ⇒ String?
16 |
# File 'lib/privy/models/key_quorum_create_request_body.rb', line 16 optional :display_name, String |
#key_quorum_ids ⇒ Array<String>?
List of key quorum IDs that should be members of this key quorum. Key quorums can only be nested 1 level deep. At least one of ‘user_ids`, `public_keys`, or `key_quorum_ids` is required.
24 |
# File 'lib/privy/models/key_quorum_create_request_body.rb', line 24 optional :key_quorum_ids, Privy::Internal::Type::ArrayOf[String] |
#public_keys ⇒ Array<String>?
List of P-256 public keys of the keys that should be authorized to sign on the key quorum, in base64-encoded DER format. At least one of ‘user_ids`, `public_keys`, or `key_quorum_ids` is required.
32 |
# File 'lib/privy/models/key_quorum_create_request_body.rb', line 32 optional :public_keys, Privy::Internal::Type::ArrayOf[String] |
#user_ids ⇒ Array<String>?
List of user IDs of the users that should be authorized to sign on the key quorum. At least one of ‘user_ids`, `public_keys`, or `key_quorum_ids` is required.
40 |
# File 'lib/privy/models/key_quorum_create_request_body.rb', line 40 optional :user_ids, Privy::Internal::Type::ArrayOf[String] |