Class: Privy::Models::KeyQuorumIntentResponse
- Inherits:
-
BaseIntentResponse
- Object
- Internal::Type::BaseModel
- BaseIntentResponse
- Privy::Models::KeyQuorumIntentResponse
- Defined in:
- lib/privy/models/key_quorum_intent_response.rb
Overview
Defined Under Namespace
Modules: IntentType Classes: RequestDetails
Instance Attribute Summary collapse
-
#action_result ⇒ Privy::Models::BaseActionResult?
Result of key quorum update execution (only present if status is ‘executed’ or ‘failed’).
-
#current_resource_data ⇒ Privy::Models::KeyQuorum?
A key quorum for authorizing wallet operations.
- #intent_type ⇒ Symbol, Privy::Models::KeyQuorumIntentResponse::IntentType
-
#request_details ⇒ Privy::Models::KeyQuorumIntentResponse::RequestDetails
The original key quorum update request that would be sent to the key quorum endpoint.
Attributes inherited from BaseIntentResponse
#authorization_details, #created_at, #created_by_display_name, #created_by_id, #custom_expiry, #dismissal_reason, #dismissed_at, #expires_at, #intent_id, #rejected_at, #resource_id, #status
Class Method Summary collapse
Methods inherited from BaseIntentResponse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Privy::Models::BaseIntentResponse
Instance Attribute Details
#action_result ⇒ Privy::Models::BaseActionResult?
Result of key quorum update execution (only present if status is ‘executed’ or ‘failed’)
24 |
# File 'lib/privy/models/key_quorum_intent_response.rb', line 24 optional :action_result, -> { Privy::BaseActionResult } |
#current_resource_data ⇒ Privy::Models::KeyQuorum?
A key quorum for authorizing wallet operations.
30 |
# File 'lib/privy/models/key_quorum_intent_response.rb', line 30 optional :current_resource_data, -> { Privy::KeyQuorum } |
#intent_type ⇒ Symbol, Privy::Models::KeyQuorumIntentResponse::IntentType
10 |
# File 'lib/privy/models/key_quorum_intent_response.rb', line 10 required :intent_type, enum: -> { Privy::KeyQuorumIntentResponse::IntentType } |
#request_details ⇒ Privy::Models::KeyQuorumIntentResponse::RequestDetails
The original key quorum update request that would be sent to the key quorum endpoint
17 |
# File 'lib/privy/models/key_quorum_intent_response.rb', line 17 required :request_details, -> { Privy::KeyQuorumIntentResponse::RequestDetails } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/privy/models/key_quorum_intent_response.rb', line 51
|