Class: Privy::Models::KeyQuorumUpdateRequestBody

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/privy/models/key_quorum_update_request_body.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(authorization_threshold: nil, display_name: nil, key_quorum_ids: nil, public_keys: nil, user_ids: nil) ⇒ Object

Some parameter documentations has been truncated, see Privy::Models::KeyQuorumUpdateRequestBody for more details.

Request input for updating an existing key quorum. At least one field must be provided.

Parameters:

  • authorization_threshold (Float) (defaults to: nil)

    The number of keys that must sign for an action to be valid. Must be less than o

  • display_name (String) (defaults to: nil)
  • key_quorum_ids (Array<String>) (defaults to: nil)

    List of key quorum IDs that should be members of this key quorum. Key quorums ca

  • public_keys (Array<String>) (defaults to: nil)

    List of P-256 public keys of the keys that should be authorized to sign on the k

  • user_ids (Array<String>) (defaults to: nil)

    List of user IDs of the users that should be authorized to sign on the key quoru



# File 'lib/privy/models/key_quorum_update_request_body.rb', line 39

Instance Attribute Details

#authorization_thresholdFloat?

The number of keys that must sign for an action to be valid. Must be less than or equal to total number of key quorum members.

Returns:

  • (Float, nil)


11
# File 'lib/privy/models/key_quorum_update_request_body.rb', line 11

optional :authorization_threshold, Float

#display_nameString?

Returns:

  • (String, nil)


16
# File 'lib/privy/models/key_quorum_update_request_body.rb', line 16

optional :display_name, String

#key_quorum_idsArray<String>?

List of key quorum IDs that should be members of this key quorum. Key quorums can only be nested 1 level deep.

Returns:

  • (Array<String>, nil)


23
# File 'lib/privy/models/key_quorum_update_request_body.rb', line 23

optional :key_quorum_ids, Privy::Internal::Type::ArrayOf[String]

#public_keysArray<String>?

List of P-256 public keys of the keys that should be authorized to sign on the key quorum, in base64-encoded DER format.

Returns:

  • (Array<String>, nil)


30
# File 'lib/privy/models/key_quorum_update_request_body.rb', line 30

optional :public_keys, Privy::Internal::Type::ArrayOf[String]

#user_idsArray<String>?

List of user IDs of the users that should be authorized to sign on the key quorum.

Returns:

  • (Array<String>, nil)


37
# File 'lib/privy/models/key_quorum_update_request_body.rb', line 37

optional :user_ids, Privy::Internal::Type::ArrayOf[String]