Class: Privy::Models::KrakenEmbedCustomOrder
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::KrakenEmbedCustomOrder
- Defined in:
- lib/privy/models/kraken_embed_custom_order.rb
Instance Attribute Summary collapse
-
#action ⇒ Privy::Models::KrakenEmbedCustomOrderAction
Trade action for a custom order.
- #created_at ⇒ Time
- #id ⇒ String
- #name ⇒ String
-
#status ⇒ Privy::Models::KrakenEmbedCustomOrderStatus
Custom order status with optional reason for cancelled or paused states.
-
#trigger ⇒ Privy::Models::KrakenEmbedCustomOrderTrigger
Price trigger for a custom order.
- #updated_at ⇒ Time
Instance Method Summary collapse
-
#initialize(id:, action:, created_at:, name:, status:, trigger:, updated_at:) ⇒ Object
constructor
Some parameter documentations has been truncated, see KrakenEmbedCustomOrder for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, action:, created_at:, name:, status:, trigger:, updated_at:) ⇒ Object
Some parameter documentations has been truncated, see Privy::Models::KrakenEmbedCustomOrder for more details.
Full custom order object.
|
|
# File 'lib/privy/models/kraken_embed_custom_order.rb', line 45
|
Instance Attribute Details
#action ⇒ Privy::Models::KrakenEmbedCustomOrderAction
Trade action for a custom order.
15 |
# File 'lib/privy/models/kraken_embed_custom_order.rb', line 15 required :action, -> { Privy::KrakenEmbedCustomOrderAction } |
#created_at ⇒ Time
20 |
# File 'lib/privy/models/kraken_embed_custom_order.rb', line 20 required :created_at, Time |
#id ⇒ String
9 |
# File 'lib/privy/models/kraken_embed_custom_order.rb', line 9 required :id, String |
#name ⇒ String
25 |
# File 'lib/privy/models/kraken_embed_custom_order.rb', line 25 required :name, String |
#status ⇒ Privy::Models::KrakenEmbedCustomOrderStatus
Custom order status with optional reason for cancelled or paused states.
31 |
# File 'lib/privy/models/kraken_embed_custom_order.rb', line 31 required :status, -> { Privy::KrakenEmbedCustomOrderStatus } |
#trigger ⇒ Privy::Models::KrakenEmbedCustomOrderTrigger
Price trigger for a custom order. The order executes when base_asset/quote_asset rate meets the condition against target_price.
38 |
# File 'lib/privy/models/kraken_embed_custom_order.rb', line 38 required :trigger, -> { Privy::KrakenEmbedCustomOrderTrigger } |
#updated_at ⇒ Time
43 |
# File 'lib/privy/models/kraken_embed_custom_order.rb', line 43 required :updated_at, Time |