Class: Privy::Models::KrakenEmbedCustomOrderAction

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/privy/models/kraken_embed_custom_order_action.rb,
sig/privy/models/kraken_embed_custom_order_action.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount:, fee_bps:, quote:, spread_bps:, type:) ⇒ Object

Trade action for a custom order.

Parameters:



# File 'lib/privy/models/kraken_embed_custom_order_action.rb', line 34

Instance Attribute Details

#amountPrivy::Models::KrakenEmbedCustomOrderAmount

Asset amount for custom order actions.



10
# File 'lib/privy/models/kraken_embed_custom_order_action.rb', line 10

required :amount, -> { Privy::KrakenEmbedCustomOrderAmount }

#fee_bpsString

Parameters:

  • value (String)

Returns:

  • (String)


15
# File 'lib/privy/models/kraken_embed_custom_order_action.rb', line 15

required :fee_bps, String

#quotePrivy::Models::KrakenEmbedCustomOrderQuoteAsset

Target asset for the other side of the custom order trade.



21
# File 'lib/privy/models/kraken_embed_custom_order_action.rb', line 21

required :quote, -> { Privy::KrakenEmbedCustomOrderQuoteAsset }

#spread_bpsString

Parameters:

  • value (String)

Returns:

  • (String)


26
# File 'lib/privy/models/kraken_embed_custom_order_action.rb', line 26

required :spread_bps, String

#typeSymbol, Privy::Models::KrakenEmbedQuoteType

Whether the quote amount refers to the asset being received or spent.

Parameters:

  • value (Privy::Models::kraken_embed_quote_type)

Returns:



32
# File 'lib/privy/models/kraken_embed_custom_order_action.rb', line 32

required :type, enum: -> { Privy::KrakenEmbedQuoteType }

Instance Method Details

#to_hash{

Returns:

  • ({)


31
# File 'sig/privy/models/kraken_embed_custom_order_action.rbs', line 31

def to_hash: -> {