Class: Privy::Models::KrakenEmbedCustomOrderExecutionFailedWebhookPayload
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::KrakenEmbedCustomOrderExecutionFailedWebhookPayload
- Defined in:
- lib/privy/models/kraken_embed_custom_order_execution_failed_webhook_payload.rb
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#custom_order_id ⇒ String
The ID of the custom order that failed to execute.
-
#failed_at ⇒ String
ISO 8601 timestamp of when the custom order execution failed.
-
#reason ⇒ String
A human-readable description of why the custom order execution failed.
-
#type ⇒ Symbol, Privy::Models::KrakenEmbedCustomOrderExecutionFailedWebhookPayload::Type
The type of webhook event.
-
#user_id ⇒ String
The ID of the user.
Instance Method Summary collapse
-
#initialize(custom_order_id:, failed_at:, reason:, type:, user_id:) ⇒ Object
constructor
Some parameter documentations has been truncated, see KrakenEmbedCustomOrderExecutionFailedWebhookPayload for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(custom_order_id:, failed_at:, reason:, type:, user_id:) ⇒ Object
Some parameter documentations has been truncated, see Privy::Models::KrakenEmbedCustomOrderExecutionFailedWebhookPayload for more details.
Payload for the kraken_embed.custom_order.execution_failed webhook event.
|
|
# File 'lib/privy/models/kraken_embed_custom_order_execution_failed_webhook_payload.rb', line 37
|
Instance Attribute Details
#custom_order_id ⇒ String
The ID of the custom order that failed to execute.
10 |
# File 'lib/privy/models/kraken_embed_custom_order_execution_failed_webhook_payload.rb', line 10 required :custom_order_id, String |
#failed_at ⇒ String
ISO 8601 timestamp of when the custom order execution failed.
16 |
# File 'lib/privy/models/kraken_embed_custom_order_execution_failed_webhook_payload.rb', line 16 required :failed_at, String |
#reason ⇒ String
A human-readable description of why the custom order execution failed. Intended for display and logging purposes only.
23 |
# File 'lib/privy/models/kraken_embed_custom_order_execution_failed_webhook_payload.rb', line 23 required :reason, String |
#type ⇒ Symbol, Privy::Models::KrakenEmbedCustomOrderExecutionFailedWebhookPayload::Type
The type of webhook event.
29 |
# File 'lib/privy/models/kraken_embed_custom_order_execution_failed_webhook_payload.rb', line 29 required :type, enum: -> { Privy::KrakenEmbedCustomOrderExecutionFailedWebhookPayload::Type } |
#user_id ⇒ String
The ID of the user.
35 |
# File 'lib/privy/models/kraken_embed_custom_order_execution_failed_webhook_payload.rb', line 35 required :user_id, String |