Class: Privy::Models::KrakenEmbedEarnAsset
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::KrakenEmbedEarnAsset
- Defined in:
- lib/privy/models/kraken_embed_earn_asset.rb,
sig/privy/models/kraken_embed_earn_asset.rbs
Instance Attribute Summary collapse
-
#apr_estimate ⇒ Privy::Models::KrakenEmbedEarnAprEstimate?
Low and high estimate of the yield of an earn asset.
-
#user_allocation ⇒ Privy::Models::KrakenEmbedEarnUserAllocation?
User allocation for an earn asset.
Instance Method Summary collapse
-
#initialize(apr_estimate:, user_allocation: nil) ⇒ Object
constructor
A single asset that can yield rewards.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(apr_estimate:, user_allocation: nil) ⇒ Object
A single asset that can yield rewards.
|
|
# File 'lib/privy/models/kraken_embed_earn_asset.rb', line 18
|
Instance Attribute Details
#apr_estimate ⇒ Privy::Models::KrakenEmbedEarnAprEstimate?
Low and high estimate of the yield of an earn asset.
10 |
# File 'lib/privy/models/kraken_embed_earn_asset.rb', line 10 required :apr_estimate, -> { Privy::KrakenEmbedEarnAprEstimate }, nil?: true |
#user_allocation ⇒ Privy::Models::KrakenEmbedEarnUserAllocation?
User allocation for an earn asset.
16 |
# File 'lib/privy/models/kraken_embed_earn_asset.rb', line 16 optional :user_allocation, -> { Privy::KrakenEmbedEarnUserAllocation }, nil?: true |
Instance Method Details
#to_hash ⇒ {
19 |
# File 'sig/privy/models/kraken_embed_earn_asset.rbs', line 19
def to_hash: -> {
|