Class: Privy::Models::KrakenEmbedFullName
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::KrakenEmbedFullName
- Defined in:
- lib/privy/models/kraken_embed_full_name.rb,
sig/privy/models/kraken_embed_full_name.rbs
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(first_name:, last_name:, middle_name: nil) ⇒ Object
constructor
User's full name including first, optional middle, and last name.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(first_name:, last_name:, middle_name: nil) ⇒ Object
User's full name including first, optional middle, and last name.
|
|
# File 'lib/privy/models/kraken_embed_full_name.rb', line 21
|
Instance Attribute Details
#first_name ⇒ String
9 |
# File 'lib/privy/models/kraken_embed_full_name.rb', line 9 required :first_name, String |
#last_name ⇒ String
14 |
# File 'lib/privy/models/kraken_embed_full_name.rb', line 14 required :last_name, String |
#middle_name ⇒ String?
19 |
# File 'lib/privy/models/kraken_embed_full_name.rb', line 19 optional :middle_name, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
19 |
# File 'sig/privy/models/kraken_embed_full_name.rbs', line 19
def to_hash: -> {
|