Class: Privy::Models::KrakenEmbedStartAddressMetadata
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::KrakenEmbedStartAddressMetadata
- Defined in:
- lib/privy/models/kraken_embed_start_address_metadata.rb,
sig/privy/models/kraken_embed_start_address_metadata.rbs
Instance Attribute Summary collapse
-
#address ⇒ Privy::Models::KrakenEmbedResidence?
User's residential address including street, city, postal code, and country.
- #document_number ⇒ String?
-
#document_type ⇒ Symbol, ...
Document types accepted for proof of address verification.
- #expiration_date ⇒ Date?
Instance Method Summary collapse
-
#initialize(address: nil, document_number: nil, document_type: nil, expiration_date: nil) ⇒ Object
constructor
Optional best-effort metadata hints for proof of address verification.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(address: nil, document_number: nil, document_type: nil, expiration_date: nil) ⇒ Object
Optional best-effort metadata hints for proof of address verification.
|
|
# File 'lib/privy/models/kraken_embed_start_address_metadata.rb', line 28
|
Instance Attribute Details
#address ⇒ Privy::Models::KrakenEmbedResidence?
User's residential address including street, city, postal code, and country.
10 |
# File 'lib/privy/models/kraken_embed_start_address_metadata.rb', line 10 optional :address, -> { Privy::KrakenEmbedResidence }, nil?: true |
#document_number ⇒ String?
15 |
# File 'lib/privy/models/kraken_embed_start_address_metadata.rb', line 15 optional :document_number, String, nil?: true |
#document_type ⇒ Symbol, ...
Document types accepted for proof of address verification.
21 |
# File 'lib/privy/models/kraken_embed_start_address_metadata.rb', line 21 optional :document_type, enum: -> { Privy::KrakenEmbedResidenceDocumentType }, nil?: true |
#expiration_date ⇒ Date?
26 |
# File 'lib/privy/models/kraken_embed_start_address_metadata.rb', line 26 optional :expiration_date, Date, nil?: true |
Instance Method Details
#to_hash ⇒ {
27 |
# File 'sig/privy/models/kraken_embed_start_address_metadata.rbs', line 27
def to_hash: -> {
|