Class: Privy::Models::KrakenEmbedStartIdentityInfo

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/privy/models/kraken_embed_start_identity_info.rb,
sig/privy/models/kraken_embed_start_identity_info.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(date_of_birth: nil, full_name: nil) ⇒ Object

Identity information hints including full name and date of birth for proof of identity verification.

Parameters:

  • date_of_birth (Date, nil) (defaults to: nil)
  • full_name (Privy::Models::KrakenEmbedFullName, nil) (defaults to: nil)

    User's full name including first, optional middle, and last name.



# File 'lib/privy/models/kraken_embed_start_identity_info.rb', line 17

Instance Attribute Details

#date_of_birthDate?

Parameters:

  • value (Date, nil)

Returns:

  • (Date, nil)


9
# File 'lib/privy/models/kraken_embed_start_identity_info.rb', line 9

optional :date_of_birth, Date, nil?: true

#full_namePrivy::Models::KrakenEmbedFullName?

User's full name including first, optional middle, and last name.

Parameters:

Returns:



15
# File 'lib/privy/models/kraken_embed_start_identity_info.rb', line 15

optional :full_name, -> { Privy::KrakenEmbedFullName }, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


16
# File 'sig/privy/models/kraken_embed_start_identity_info.rbs', line 16

def to_hash: -> {