Class: Privy::Models::KrakenEmbedStartIdentityMetadata
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::KrakenEmbedStartIdentityMetadata
- Defined in:
- lib/privy/models/kraken_embed_start_identity_metadata.rb,
sig/privy/models/kraken_embed_start_identity_metadata.rbs
Instance Attribute Summary collapse
- #document_number ⇒ String?
-
#document_type ⇒ Symbol, ...
Document types accepted for proof of identity verification.
- #expiration_date ⇒ Date?
-
#identity ⇒ Privy::Models::KrakenEmbedStartIdentityInfo?
Identity information hints including full name and date of birth for proof of identity verification.
-
#issuing_country ⇒ Symbol, ...
ISO 3166-1 alpha-2 country codes supported by Kraken Embed.
-
#nationality ⇒ Symbol, ...
ISO 3166-1 alpha-2 country codes supported by Kraken Embed.
Instance Method Summary collapse
-
#initialize(document_number: nil, document_type: nil, expiration_date: nil, identity: nil, issuing_country: nil, nationality: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see KrakenEmbedStartIdentityMetadata for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(document_number: nil, document_type: nil, expiration_date: nil, identity: nil, issuing_country: nil, nationality: nil) ⇒ Object
Some parameter documentations has been truncated, see Privy::Models::KrakenEmbedStartIdentityMetadata for more details.
Optional best-effort metadata hints for proof of identity verification.
|
|
# File 'lib/privy/models/kraken_embed_start_identity_metadata.rb', line 41
|
Instance Attribute Details
#document_number ⇒ String?
9 |
# File 'lib/privy/models/kraken_embed_start_identity_metadata.rb', line 9 optional :document_number, String, nil?: true |
#document_type ⇒ Symbol, ...
Document types accepted for proof of identity verification.
15 |
# File 'lib/privy/models/kraken_embed_start_identity_metadata.rb', line 15 optional :document_type, enum: -> { Privy::KrakenEmbedIdentityDocumentType }, nil?: true |
#expiration_date ⇒ Date?
20 |
# File 'lib/privy/models/kraken_embed_start_identity_metadata.rb', line 20 optional :expiration_date, Date, nil?: true |
#identity ⇒ Privy::Models::KrakenEmbedStartIdentityInfo?
Identity information hints including full name and date of birth for proof of identity verification.
27 |
# File 'lib/privy/models/kraken_embed_start_identity_metadata.rb', line 27 optional :identity, -> { Privy::KrakenEmbedStartIdentityInfo }, nil?: true |
#issuing_country ⇒ Symbol, ...
ISO 3166-1 alpha-2 country codes supported by Kraken Embed.
33 |
# File 'lib/privy/models/kraken_embed_start_identity_metadata.rb', line 33 optional :issuing_country, enum: -> { Privy::KrakenEmbedCountryCode }, nil?: true |
#nationality ⇒ Symbol, ...
ISO 3166-1 alpha-2 country codes supported by Kraken Embed.
39 |
# File 'lib/privy/models/kraken_embed_start_identity_metadata.rb', line 39 optional :nationality, enum: -> { Privy::KrakenEmbedCountryCode }, nil?: true |
Instance Method Details
#to_hash ⇒ {
35 |
# File 'sig/privy/models/kraken_embed_start_identity_metadata.rbs', line 35
def to_hash: -> {
|