Class: Privy::Models::LinkedAccountBaseWallet
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::LinkedAccountBaseWallet
- Defined in:
- lib/privy/models/linked_account_base_wallet.rb
Defined Under Namespace
Instance Attribute Summary collapse
- #address ⇒ String
- #chain_type ⇒ Symbol, Privy::Models::LinkedAccountBaseWallet::ChainType
- #type ⇒ Symbol, Privy::Models::LinkedAccountBaseWallet::Type
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(address:, chain_type:, type:) ⇒ Object
constructor
Base schema for wallet accounts linked to the user.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(address:, chain_type:, type:) ⇒ Object
Base schema for wallet accounts linked to the user.
|
|
# File 'lib/privy/models/linked_account_base_wallet.rb', line 21
|
Instance Attribute Details
#address ⇒ String
9 |
# File 'lib/privy/models/linked_account_base_wallet.rb', line 9 required :address, String |
#chain_type ⇒ Symbol, Privy::Models::LinkedAccountBaseWallet::ChainType
14 |
# File 'lib/privy/models/linked_account_base_wallet.rb', line 14 required :chain_type, enum: -> { Privy::LinkedAccountBaseWallet::ChainType } |
#type ⇒ Symbol, Privy::Models::LinkedAccountBaseWallet::Type
19 |
# File 'lib/privy/models/linked_account_base_wallet.rb', line 19 required :type, enum: -> { Privy::LinkedAccountBaseWallet::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/privy/models/linked_account_base_wallet.rb', line 35
|