Class: Privy::Models::LinkedAccountBitcoinTaprootEmbeddedWallet
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::LinkedAccountBitcoinTaprootEmbeddedWallet
- Defined in:
- lib/privy/models/linked_account_bitcoin_taproot_embedded_wallet.rb
Direct Known Subclasses
Privy::Models::LinkedAccountEmbeddedWalletWithID::LinkedAccountBitcoinTaprootEmbeddedWallet
Defined Under Namespace
Modules: ChainType, ConnectorType, Type, WalletClient, WalletClientType
Instance Attribute Summary collapse
- #address ⇒ String
- #chain_id ⇒ String
- #chain_type ⇒ Symbol, Privy::Models::LinkedAccountBitcoinTaprootEmbeddedWallet::ChainType
- #connector_type ⇒ Symbol, Privy::Models::LinkedAccountBitcoinTaprootEmbeddedWallet::ConnectorType
- #delegated ⇒ Boolean
- #first_verified_at ⇒ Float?
- #id ⇒ String?
- #imported ⇒ Boolean
- #latest_verified_at ⇒ Float?
- #public_key ⇒ String
-
#recovery_method ⇒ Symbol, Privy::Models::EmbeddedWalletRecoveryMethod
The method used to recover an embedded wallet account.
- #type ⇒ Symbol, Privy::Models::LinkedAccountBitcoinTaprootEmbeddedWallet::Type
- #verified_at ⇒ Float
- #wallet_client ⇒ Symbol, Privy::Models::LinkedAccountBitcoinTaprootEmbeddedWallet::WalletClient
- #wallet_client_type ⇒ Symbol, Privy::Models::LinkedAccountBitcoinTaprootEmbeddedWallet::WalletClientType
- #wallet_index ⇒ Float
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, address:, chain_id:, chain_type:, connector_type:, delegated:, first_verified_at:, imported:, latest_verified_at:, public_key:, recovery_method:, type:, verified_at:, wallet_client:, wallet_client_type:, wallet_index:) ⇒ Object
constructor
A Bitcoin Taproot embedded wallet account linked to the user.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, address:, chain_id:, chain_type:, connector_type:, delegated:, first_verified_at:, imported:, latest_verified_at:, public_key:, recovery_method:, type:, verified_at:, wallet_client:, wallet_client_type:, wallet_index:) ⇒ Object
A Bitcoin Taproot embedded wallet account linked to the user.
|
|
# File 'lib/privy/models/linked_account_bitcoin_taproot_embedded_wallet.rb', line 88
|
Instance Attribute Details
#address ⇒ String
14 |
# File 'lib/privy/models/linked_account_bitcoin_taproot_embedded_wallet.rb', line 14 required :address, String |
#chain_id ⇒ String
19 |
# File 'lib/privy/models/linked_account_bitcoin_taproot_embedded_wallet.rb', line 19 required :chain_id, String |
#chain_type ⇒ Symbol, Privy::Models::LinkedAccountBitcoinTaprootEmbeddedWallet::ChainType
24 |
# File 'lib/privy/models/linked_account_bitcoin_taproot_embedded_wallet.rb', line 24 required :chain_type, enum: -> { Privy::LinkedAccountBitcoinTaprootEmbeddedWallet::ChainType } |
#connector_type ⇒ Symbol, Privy::Models::LinkedAccountBitcoinTaprootEmbeddedWallet::ConnectorType
29 |
# File 'lib/privy/models/linked_account_bitcoin_taproot_embedded_wallet.rb', line 29 required :connector_type, enum: -> { Privy::LinkedAccountBitcoinTaprootEmbeddedWallet::ConnectorType } |
#delegated ⇒ Boolean
34 |
# File 'lib/privy/models/linked_account_bitcoin_taproot_embedded_wallet.rb', line 34 required :delegated, Privy::Internal::Type::Boolean |
#first_verified_at ⇒ Float?
39 |
# File 'lib/privy/models/linked_account_bitcoin_taproot_embedded_wallet.rb', line 39 required :first_verified_at, Float, nil?: true |
#id ⇒ String?
9 |
# File 'lib/privy/models/linked_account_bitcoin_taproot_embedded_wallet.rb', line 9 required :id, String, nil?: true |
#imported ⇒ Boolean
44 |
# File 'lib/privy/models/linked_account_bitcoin_taproot_embedded_wallet.rb', line 44 required :imported, Privy::Internal::Type::Boolean |
#latest_verified_at ⇒ Float?
49 |
# File 'lib/privy/models/linked_account_bitcoin_taproot_embedded_wallet.rb', line 49 required :latest_verified_at, Float, nil?: true |
#public_key ⇒ String
54 |
# File 'lib/privy/models/linked_account_bitcoin_taproot_embedded_wallet.rb', line 54 required :public_key, String |
#recovery_method ⇒ Symbol, Privy::Models::EmbeddedWalletRecoveryMethod
The method used to recover an embedded wallet account.
60 |
# File 'lib/privy/models/linked_account_bitcoin_taproot_embedded_wallet.rb', line 60 required :recovery_method, enum: -> { Privy::EmbeddedWalletRecoveryMethod } |
#type ⇒ Symbol, Privy::Models::LinkedAccountBitcoinTaprootEmbeddedWallet::Type
65 |
# File 'lib/privy/models/linked_account_bitcoin_taproot_embedded_wallet.rb', line 65 required :type, enum: -> { Privy::LinkedAccountBitcoinTaprootEmbeddedWallet::Type } |
#verified_at ⇒ Float
70 |
# File 'lib/privy/models/linked_account_bitcoin_taproot_embedded_wallet.rb', line 70 required :verified_at, Float |
#wallet_client ⇒ Symbol, Privy::Models::LinkedAccountBitcoinTaprootEmbeddedWallet::WalletClient
75 |
# File 'lib/privy/models/linked_account_bitcoin_taproot_embedded_wallet.rb', line 75 required :wallet_client, enum: -> { Privy::LinkedAccountBitcoinTaprootEmbeddedWallet::WalletClient } |
#wallet_client_type ⇒ Symbol, Privy::Models::LinkedAccountBitcoinTaprootEmbeddedWallet::WalletClientType
80 81 |
# File 'lib/privy/models/linked_account_bitcoin_taproot_embedded_wallet.rb', line 80 required :wallet_client_type, enum: -> { Privy::LinkedAccountBitcoinTaprootEmbeddedWallet::WalletClientType } |
#wallet_index ⇒ Float
86 |
# File 'lib/privy/models/linked_account_bitcoin_taproot_embedded_wallet.rb', line 86 required :wallet_index, Float |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/privy/models/linked_account_bitcoin_taproot_embedded_wallet.rb', line 129
|