Module: Privy::Models::LinkedAccountEmbeddedWalletWithID::LinkedAccountBitcoinTaprootEmbeddedWallet::RecoveryMethod
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/privy/models/linked_account_embedded_wallet_with_id.rb
Constant Summary collapse
- PRIVY_V2 =
:"privy-v2"
Instance Method Summary collapse
-
#initialize(id:, recovery_method:) ⇒ Object
A Bitcoin Taproot embedded wallet account linked to the user.
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#initialize(id:, recovery_method:) ⇒ Object
A Bitcoin Taproot embedded wallet account linked to the user.
126 127 128 129 130 131 132 133 |
# File 'lib/privy/models/linked_account_embedded_wallet_with_id.rb', line 126 module RecoveryMethod extend Privy::Internal::Type::Enum PRIVY_V2 = :"privy-v2" # @!method self.values # @return [Array<Symbol>] end |