Module: Privy::Models::LinkedAccountEmbeddedWalletWithID::LinkedAccountEthereumEmbeddedWallet::RecoveryMethod
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/privy/models/linked_account_embedded_wallet_with_id.rb
Constant Summary collapse
- PRIVY_V2 =
:"privy-v2"
Instance Method Summary collapse
-
#initialize(id:, recovery_method:) ⇒ Object
An Ethereum embedded wallet account linked to the user.
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#initialize(id:, recovery_method:) ⇒ Object
An Ethereum embedded wallet account linked to the user.
42 43 44 45 46 47 48 49 |
# File 'lib/privy/models/linked_account_embedded_wallet_with_id.rb', line 42 module RecoveryMethod extend Privy::Internal::Type::Enum PRIVY_V2 = :"privy-v2" # @!method self.values # @return [Array<Symbol>] end |