Class: Privy::Models::LinkedAccountEthereumEmbeddedWallet
- Inherits:
-
Internal::Type::BaseModel
show all
- Defined in:
- lib/privy/models/linked_account_ethereum_embedded_wallet.rb,
sig/privy/models/linked_account_ethereum_embedded_wallet.rbs
Defined Under Namespace
Modules: ChainType, ConnectorType, Type, WalletClient, WalletClientType
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
-
#initialize(id:, address:, chain_id:, chain_type:, connector_type:, delegated:, first_verified_at:, imported:, latest_verified_at:, recovery_method:, type:, verified_at:, wallet_client:, wallet_client_type:, wallet_index:) ⇒ Object
constructor
An Ethereum embedded wallet account linked to the user.
-
#to_hash ⇒ {
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, address:, chain_id:, chain_type:, connector_type:, delegated:, first_verified_at:, imported:, latest_verified_at:, recovery_method:, type:, verified_at:, wallet_client:, wallet_client_type:, wallet_index:) ⇒ Object
An Ethereum embedded wallet account linked to the user.
|
# File 'lib/privy/models/linked_account_ethereum_embedded_wallet.rb', line 82
|
Instance Attribute Details
#address ⇒ String
14
|
# File 'lib/privy/models/linked_account_ethereum_embedded_wallet.rb', line 14
required :address, String
|
#chain_id ⇒ String
19
|
# File 'lib/privy/models/linked_account_ethereum_embedded_wallet.rb', line 19
required :chain_id, String
|
24
|
# File 'lib/privy/models/linked_account_ethereum_embedded_wallet.rb', line 24
required :chain_type, enum: -> { Privy::LinkedAccountEthereumEmbeddedWallet::ChainType }
|
29
|
# File 'lib/privy/models/linked_account_ethereum_embedded_wallet.rb', line 29
required :connector_type, enum: -> { Privy::LinkedAccountEthereumEmbeddedWallet::ConnectorType }
|
#delegated ⇒ Boolean
34
|
# File 'lib/privy/models/linked_account_ethereum_embedded_wallet.rb', line 34
required :delegated, Privy::Internal::Type::Boolean
|
#first_verified_at ⇒ Float?
39
|
# File 'lib/privy/models/linked_account_ethereum_embedded_wallet.rb', line 39
required :first_verified_at, Float, nil?: true
|
#id ⇒ String?
9
|
# File 'lib/privy/models/linked_account_ethereum_embedded_wallet.rb', line 9
required :id, String, nil?: true
|
#imported ⇒ Boolean
44
|
# File 'lib/privy/models/linked_account_ethereum_embedded_wallet.rb', line 44
required :imported, Privy::Internal::Type::Boolean
|
#latest_verified_at ⇒ Float?
49
|
# File 'lib/privy/models/linked_account_ethereum_embedded_wallet.rb', line 49
required :latest_verified_at, Float, nil?: true
|
The method used to recover an embedded wallet account.
55
|
# File 'lib/privy/models/linked_account_ethereum_embedded_wallet.rb', line 55
required :recovery_method, enum: -> { Privy::EmbeddedWalletRecoveryMethod }
|
60
|
# File 'lib/privy/models/linked_account_ethereum_embedded_wallet.rb', line 60
required :type, enum: -> { Privy::LinkedAccountEthereumEmbeddedWallet::Type }
|
#verified_at ⇒ Float
65
|
# File 'lib/privy/models/linked_account_ethereum_embedded_wallet.rb', line 65
required :verified_at, Float
|
70
|
# File 'lib/privy/models/linked_account_ethereum_embedded_wallet.rb', line 70
required :wallet_client, enum: -> { Privy::LinkedAccountEthereumEmbeddedWallet::WalletClient }
|
75
|
# File 'lib/privy/models/linked_account_ethereum_embedded_wallet.rb', line 75
required :wallet_client_type, enum: -> { Privy::LinkedAccountEthereumEmbeddedWallet::WalletClientType }
|
#wallet_index ⇒ Float
80
|
# File 'lib/privy/models/linked_account_ethereum_embedded_wallet.rb', line 80
required :wallet_index, Float
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/privy/models/linked_account_ethereum_embedded_wallet.rb', line 121
|
Instance Method Details
#to_hash ⇒ {
71
|
# File 'sig/privy/models/linked_account_ethereum_embedded_wallet.rbs', line 71
def to_hash: -> {
|