Class: Privy::Models::LinkedAccountWalletInput

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/privy/models/linked_account_wallet_input.rb,
sig/privy/models/linked_account_wallet_input.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(address:, chain_type:, type: :wallet) ⇒ Object

The payload for importing a wallet account.

Parameters:

  • address (String)
  • chain_type (Symbol, Privy::Models::FirstClassChainType)

    The wallet chain types that offer first class support.

  • type (Symbol, :wallet) (defaults to: :wallet)


# File 'lib/privy/models/linked_account_wallet_input.rb', line 22

Instance Attribute Details

#addressString

Parameters:

  • value (String)

Returns:

  • (String)


9
# File 'lib/privy/models/linked_account_wallet_input.rb', line 9

required :address, String

#chain_typeSymbol, Privy::Models::FirstClassChainType

The wallet chain types that offer first class support.

Parameters:

  • value (Privy::Models::first_class_chain_type)

Returns:



15
# File 'lib/privy/models/linked_account_wallet_input.rb', line 15

required :chain_type, enum: -> { Privy::FirstClassChainType }

#typeSymbol, :wallet

Parameters:

  • value (:wallet)

Returns:

  • (Symbol, :wallet)


20
# File 'lib/privy/models/linked_account_wallet_input.rb', line 20

required :type, const: :wallet

Instance Method Details

#to_hash{

Returns:

  • ({)


23
# File 'sig/privy/models/linked_account_wallet_input.rbs', line 23

def to_hash: -> {