Class: Privy::Models::NamedTokenTransferSource
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::NamedTokenTransferSource
- Defined in:
- lib/privy/models/named_token_transfer_source.rb,
sig/privy/models/named_token_transfer_source.rbs
Instance Attribute Summary collapse
- #amount ⇒ String deprecated Deprecated.
-
#asset ⇒ String
The asset to transfer.
-
#chain ⇒ String
The blockchain network on which to perform the transfer.
Instance Method Summary collapse
-
#initialize(amount:, asset:, chain:) ⇒ NamedTokenTransferSource
constructor
Some parameter documentations has been truncated, see NamedTokenTransferSource for more details.
- #to_hash ⇒ { amount: String, asset: String, chain: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, asset:, chain:) ⇒ NamedTokenTransferSource
Some parameter documentations has been truncated, see Privy::Models::NamedTokenTransferSource for more details.
Source for a transfer identified by a named asset (e.g. "usdc", "eth"). Use this variant for first-class assets maintained by Privy.
|
|
# File 'lib/privy/models/named_token_transfer_source.rb', line 31
|
Instance Attribute Details
#amount ⇒ String
Amount as a decimal string in the token's standard unit (e.g. "1.5" for 1.5 USDC, "0.01" for 0.01 ETH). For exact_input, specifies the amount to send. Not in the smallest on-chain unit (wei, lamports, etc.). Maximum 100 characters.
14 |
# File 'lib/privy/models/named_token_transfer_source.rb', line 14 required :amount, String |
#asset ⇒ String
The asset to transfer. Supported: 'usdc', 'usdb', 'usdt' (stablecoins), 'eth' (native Ethereum), 'sol' (native Solana).
21 |
# File 'lib/privy/models/named_token_transfer_source.rb', line 21 required :asset, String |
#chain ⇒ String
The blockchain network on which to perform the transfer. Supported chains include: 'ethereum', 'base', 'arbitrum', 'polygon', 'solana', and their respective testnets.
29 |
# File 'lib/privy/models/named_token_transfer_source.rb', line 29 required :chain, String |
Instance Method Details
#to_hash ⇒ { amount: String, asset: String, chain: String }
15 |
# File 'sig/privy/models/named_token_transfer_source.rbs', line 15
def to_hash: -> { amount: String, asset: String, chain: String }
|