Class: Privy::Models::OAuthTokenDeviceCodePendingError
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::OAuthTokenDeviceCodePendingError
- Defined in:
- lib/privy/models/oauth_token_device_code_pending_error.rb
Defined Under Namespace
Modules: Error
Instance Attribute Summary collapse
-
#error ⇒ Symbol, Privy::Models::OAuthTokenDeviceCodePendingError::Error
The error code indicating why the token request failed.
-
#error_description ⇒ String?
Human-readable description of the error.
-
#interval ⇒ Float?
The minimum polling interval in seconds.
Instance Method Summary collapse
-
#initialize(error:, error_description: nil, interval: nil) ⇒ Object
constructor
Error response returned while the device authorization is still pending (RFC 8628 Section 3.5).
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(error:, error_description: nil, interval: nil) ⇒ Object
Error response returned while the device authorization is still pending (RFC 8628 Section 3.5).
|
|
# File 'lib/privy/models/oauth_token_device_code_pending_error.rb', line 24
|
Instance Attribute Details
#error ⇒ Symbol, Privy::Models::OAuthTokenDeviceCodePendingError::Error
The error code indicating why the token request failed.
10 |
# File 'lib/privy/models/oauth_token_device_code_pending_error.rb', line 10 required :error, enum: -> { Privy::OAuthTokenDeviceCodePendingError::Error } |
#error_description ⇒ String?
Human-readable description of the error.
16 |
# File 'lib/privy/models/oauth_token_device_code_pending_error.rb', line 16 optional :error_description, String |
#interval ⇒ Float?
The minimum polling interval in seconds.
22 |
# File 'lib/privy/models/oauth_token_device_code_pending_error.rb', line 22 optional :interval, Float |