Class: Privy::Models::OAuthTokenRefreshTokenRequestBody

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/privy/models/oauth_token_refresh_token_request_body.rb

Defined Under Namespace

Modules: GrantType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(grant_type:, refresh_token:) ⇒ Object

Request body for the refresh_token grant type. Rotates the refresh token and issues a new access token.

Parameters:



# File 'lib/privy/models/oauth_token_refresh_token_request_body.rb', line 17

Instance Attribute Details

#grant_typeSymbol, Privy::Models::OAuthTokenRefreshTokenRequestBody::GrantType



9
# File 'lib/privy/models/oauth_token_refresh_token_request_body.rb', line 9

required :grant_type, enum: -> { Privy::OAuthTokenRefreshTokenRequestBody::GrantType }

#refresh_tokenString

The refresh token to exchange for a new access token.

Returns:

  • (String)


15
# File 'lib/privy/models/oauth_token_refresh_token_request_body.rb', line 15

required :refresh_token, String