Class: Privy::Models::OrganizationSecretView

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/privy/models/organization_secret_view.rb

Direct Known Subclasses

CreateOrganizationSecretResponse

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, created_at:, last_four:, revoked_at:, signing_public_key:) ⇒ Object

View of an organization secret for list and management endpoints.

Parameters:

  • id (String)

    Unique secret identifier

  • created_at (String)

    ISO 8601 creation timestamp

  • last_four (String)

    Last four characters of the secret

  • revoked_at (String, nil)

    ISO 8601 revocation timestamp, or null if active

  • signing_public_key (String, nil)

    P-256 public key in PEM format for request signing, or null if not configured



# File 'lib/privy/models/organization_secret_view.rb', line 36

Instance Attribute Details

#created_atString

ISO 8601 creation timestamp

Returns:

  • (String)


16
# File 'lib/privy/models/organization_secret_view.rb', line 16

required :created_at, String

#idString

Unique secret identifier

Returns:

  • (String)


10
# File 'lib/privy/models/organization_secret_view.rb', line 10

required :id, String

#last_fourString

Last four characters of the secret

Returns:

  • (String)


22
# File 'lib/privy/models/organization_secret_view.rb', line 22

required :last_four, String

#revoked_atString?

ISO 8601 revocation timestamp, or null if active

Returns:

  • (String, nil)


28
# File 'lib/privy/models/organization_secret_view.rb', line 28

required :revoked_at, String, nil?: true

#signing_public_keyString?

P-256 public key in PEM format for request signing, or null if not configured

Returns:

  • (String, nil)


34
# File 'lib/privy/models/organization_secret_view.rb', line 34

required :signing_public_key, String, nil?: true