Module: Privy::Models::OwnerInput

Extended by:
Internal::Type::Union
Defined in:
lib/privy/models/owner_input.rb

Overview

The owner of the resource, specified as a Privy user ID, a P-256 public key, or null to remove the current owner.

Class Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.variantsArray(Privy::Models::OwnerInputUser, Privy::Models::OwnerInputPublicKey)



# File 'lib/privy/models/owner_input.rb', line 16