Class: Privy::Models::PasskeyAuthenticatorEnrollmentOptions
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::PasskeyAuthenticatorEnrollmentOptions
- Defined in:
- lib/privy/models/passkey_authenticator_enrollment_options.rb
Instance Attribute Summary collapse
- #attestation ⇒ String?
-
#authenticator_selection ⇒ Privy::Models::PasskeyAuthenticatorSelection?
Authenticator selection criteria for a WebAuthn registration ceremony.
- #challenge ⇒ String
- #exclude_credentials ⇒ Array<Privy::Models::PasskeyCredentialDescriptor>?
-
#extensions ⇒ Privy::Models::PasskeyEnrollmentExtensions?
Extensions for a WebAuthn registration ceremony.
- #pub_key_cred_params ⇒ Array<Privy::Models::PasskeyPubKeyCredParam>
-
#rp ⇒ Privy::Models::PasskeyRelyingParty
Relying party information for a WebAuthn ceremony.
- #timeout ⇒ Float?
-
#user ⇒ Privy::Models::PasskeyUser
User entity for a WebAuthn registration ceremony.
Instance Method Summary collapse
-
#initialize(challenge:, pub_key_cred_params:, rp:, user:, attestation: nil, authenticator_selection: nil, exclude_credentials: nil, extensions: nil, timeout: nil) ⇒ Object
constructor
WebAuthn registration options as defined by the Web Authentication specification.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(challenge:, pub_key_cred_params:, rp:, user:, attestation: nil, authenticator_selection: nil, exclude_credentials: nil, extensions: nil, timeout: nil) ⇒ Object
WebAuthn registration options as defined by the Web Authentication specification.
|
|
# File 'lib/privy/models/passkey_authenticator_enrollment_options.rb', line 55
|
Instance Attribute Details
#attestation ⇒ String?
31 |
# File 'lib/privy/models/passkey_authenticator_enrollment_options.rb', line 31 optional :attestation, String |
#authenticator_selection ⇒ Privy::Models::PasskeyAuthenticatorSelection?
Authenticator selection criteria for a WebAuthn registration ceremony.
37 |
# File 'lib/privy/models/passkey_authenticator_enrollment_options.rb', line 37 optional :authenticator_selection, -> { Privy::PasskeyAuthenticatorSelection } |
#challenge ⇒ String
9 |
# File 'lib/privy/models/passkey_authenticator_enrollment_options.rb', line 9 required :challenge, String |
#exclude_credentials ⇒ Array<Privy::Models::PasskeyCredentialDescriptor>?
42 |
# File 'lib/privy/models/passkey_authenticator_enrollment_options.rb', line 42 optional :exclude_credentials, -> { Privy::Internal::Type::ArrayOf[Privy::PasskeyCredentialDescriptor] } |
#extensions ⇒ Privy::Models::PasskeyEnrollmentExtensions?
Extensions for a WebAuthn registration ceremony.
48 |
# File 'lib/privy/models/passkey_authenticator_enrollment_options.rb', line 48 optional :extensions, -> { Privy::PasskeyEnrollmentExtensions } |
#pub_key_cred_params ⇒ Array<Privy::Models::PasskeyPubKeyCredParam>
14 |
# File 'lib/privy/models/passkey_authenticator_enrollment_options.rb', line 14 required :pub_key_cred_params, -> { Privy::Internal::Type::ArrayOf[Privy::PasskeyPubKeyCredParam] } |
#rp ⇒ Privy::Models::PasskeyRelyingParty
Relying party information for a WebAuthn ceremony.
20 |
# File 'lib/privy/models/passkey_authenticator_enrollment_options.rb', line 20 required :rp, -> { Privy::PasskeyRelyingParty } |
#timeout ⇒ Float?
53 |
# File 'lib/privy/models/passkey_authenticator_enrollment_options.rb', line 53 optional :timeout, Float |
#user ⇒ Privy::Models::PasskeyUser
User entity for a WebAuthn registration ceremony.
26 |
# File 'lib/privy/models/passkey_authenticator_enrollment_options.rb', line 26 required :user, -> { Privy::PasskeyUser } |