Class: Privy::Models::PasskeyAuthenticatorVerifyResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::PasskeyAuthenticatorVerifyResponse
- Defined in:
- lib/privy/models/passkey_authenticator_verify_response.rb
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
- #authenticator_attachment ⇒ String?
-
#client_extension_results ⇒ Privy::Models::PasskeyClientExtensionResults
Client extension results returned by the WebAuthn authenticator.
- #id ⇒ String
- #raw_id ⇒ String
-
#response ⇒ Privy::Models::PasskeyAssertionResponse
The authenticator assertion response from a WebAuthn authentication ceremony.
- #type ⇒ Symbol, Privy::Models::PasskeyAuthenticatorVerifyResponse::Type
Instance Method Summary collapse
-
#initialize(id:, client_extension_results:, raw_id:, response:, type:, authenticator_attachment: nil) ⇒ Object
constructor
WebAuthn authentication response as defined by the Web Authentication specification.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, client_extension_results:, raw_id:, response:, type:, authenticator_attachment: nil) ⇒ Object
WebAuthn authentication response as defined by the Web Authentication specification.
|
|
# File 'lib/privy/models/passkey_authenticator_verify_response.rb', line 38
|
Instance Attribute Details
#authenticator_attachment ⇒ String?
36 |
# File 'lib/privy/models/passkey_authenticator_verify_response.rb', line 36 optional :authenticator_attachment, String |
#client_extension_results ⇒ Privy::Models::PasskeyClientExtensionResults
Client extension results returned by the WebAuthn authenticator.
15 |
# File 'lib/privy/models/passkey_authenticator_verify_response.rb', line 15 required :client_extension_results, -> { Privy::PasskeyClientExtensionResults } |
#id ⇒ String
9 |
# File 'lib/privy/models/passkey_authenticator_verify_response.rb', line 9 required :id, String |
#raw_id ⇒ String
20 |
# File 'lib/privy/models/passkey_authenticator_verify_response.rb', line 20 required :raw_id, String |
#response ⇒ Privy::Models::PasskeyAssertionResponse
The authenticator assertion response from a WebAuthn authentication ceremony.
26 |
# File 'lib/privy/models/passkey_authenticator_verify_response.rb', line 26 required :response, -> { Privy::PasskeyAssertionResponse } |
#type ⇒ Symbol, Privy::Models::PasskeyAuthenticatorVerifyResponse::Type
31 |
# File 'lib/privy/models/passkey_authenticator_verify_response.rb', line 31 required :type, enum: -> { Privy::PasskeyAuthenticatorVerifyResponse::Type } |