Class: Privy::Models::PolicyCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/privy/models/policy_create_params.rb

Overview

Defined Under Namespace

Modules: Version Classes: Rule

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Instance Attribute Details

#chain_typeSymbol, Privy::Models::WalletChainType

The wallet chain types.

Returns:



14
# File 'lib/privy/models/policy_create_params.rb', line 14

required :chain_type, enum: -> { Privy::WalletChainType }

#nameString

Name to assign to policy.

Returns:

  • (String)


20
# File 'lib/privy/models/policy_create_params.rb', line 20

required :name, String

#ownerPrivy::Models::OwnerInputUser, ...

The owner of the resource, specified as a Privy user ID, a P-256 public key, or null to remove the current owner.



38
# File 'lib/privy/models/policy_create_params.rb', line 38

optional :owner, union: -> { Privy::OwnerInput }, nil?: true

#owner_idString?

The key quorum ID to set as the owner of the resource. If you provide this, do not specify an owner.

Returns:

  • (String, nil)


45
# File 'lib/privy/models/policy_create_params.rb', line 45

optional :owner_id, String, nil?: true

#privy_idempotency_keyString?

Idempotency keys ensure API requests are executed only once within a 24-hour window.

Returns:

  • (String, nil)


52
# File 'lib/privy/models/policy_create_params.rb', line 52

optional :privy_idempotency_key, String

#rulesArray<Privy::Models::PolicyCreateParams::Rule>



25
# File 'lib/privy/models/policy_create_params.rb', line 25

required :rules, -> { Privy::Internal::Type::ArrayOf[Privy::PolicyCreateParams::Rule] }

#versionSymbol, Privy::Models::PolicyCreateParams::Version

Version of the policy. Currently, 1.0 is the only version.



31
# File 'lib/privy/models/policy_create_params.rb', line 31

required :version, enum: -> { Privy::PolicyCreateParams::Version }