Class: Privy::Models::PolicyCreateRuleParams

Inherits:
PolicyRuleRequestBody show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/privy/models/policy_create_rule_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Attributes inherited from PolicyRuleRequestBody

#action, #conditions, #method_, #name

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(policy_id:, privy_authorization_signature: nil, privy_request_expiry: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Privy::Models::PolicyCreateRuleParams for more details.

Parameters:

  • policy_id (String)
  • privy_authorization_signature (String) (defaults to: nil)

    Request authorization signature. If multiple signatures are required, they shoul

  • privy_request_expiry (String) (defaults to: nil)

    Request expiry. Value is a Unix timestamp in milliseconds representing the deadl

  • request_options (Privy::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/privy/models/policy_create_rule_params.rb', line 29

Instance Attribute Details

#policy_idString

Returns:

  • (String)


13
# File 'lib/privy/models/policy_create_rule_params.rb', line 13

required :policy_id, String

#privy_authorization_signatureString?

Request authorization signature. If multiple signatures are required, they should be comma separated.

Returns:

  • (String, nil)


20
# File 'lib/privy/models/policy_create_rule_params.rb', line 20

optional :privy_authorization_signature, String

#privy_request_expiryString?

Request expiry. Value is a Unix timestamp in milliseconds representing the deadline by which the request must be processed.

Returns:

  • (String, nil)


27
# File 'lib/privy/models/policy_create_rule_params.rb', line 27

optional :privy_request_expiry, String