Class: Privy::Models::PolicyIntentResponse::RequestDetails::Body

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/privy/models/policy_intent_response.rb,
sig/privy/models/policy_intent_response.rbs

Overview

See Also:

  • Privy::Models::PolicyIntentResponse::RequestDetails#body

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



105
# File 'sig/privy/models/policy_intent_response.rbs', line 105

def initialize: (

Instance Attribute Details

#nameString?

Name to assign to policy.

Parameters:

  • (String)

Returns:

  • (String, nil)


83
# File 'lib/privy/models/policy_intent_response.rb', line 83

optional :name, String

#ownerPrivy::Models::OwnerInputUser, ...

The owner of the resource, specified as a Privy user ID, a P-256 public key, or null to remove the current owner.

Parameters:

  • value (Privy::Models::owner_input, nil)

Returns:



90
# File 'lib/privy/models/policy_intent_response.rb', line 90

optional :owner, union: -> { Privy::OwnerInput }, nil?: true

#owner_idString?

The key quorum ID to set as the owner of the resource. If you provide this, do not specify an owner.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


97
# File 'lib/privy/models/policy_intent_response.rb', line 97

optional :owner_id, String, nil?: true

#rulesArray<Privy::Models::PolicyRuleRequestBody>?

Returns:



102
# File 'lib/privy/models/policy_intent_response.rb', line 102

optional :rules, -> { Privy::Internal::Type::ArrayOf[Privy::PolicyRuleRequestBody] }

Instance Method Details

#to_hash{

Returns:

  • ({)


112
# File 'sig/privy/models/policy_intent_response.rbs', line 112

def to_hash: -> {