Class: Privy::Models::PolicyRuleResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::PolicyRuleResponse
- Defined in:
- lib/privy/models/policy_rule_response.rb
Overview
Instance Attribute Summary collapse
-
#action ⇒ Symbol, Privy::Models::PolicyAction
The action to take when a policy rule matches.
- #conditions ⇒ Array<Privy::Models::EthereumTransactionCondition, Privy::Models::EthereumCalldataCondition, Privy::Models::EthereumTypedDataDomainCondition, Privy::Models::EthereumTypedDataMessageCondition, Privy::Models::Ethereum7702AuthorizationCondition, Privy::Models::TempoTransactionCondition, Privy::Models::SolanaProgramInstructionCondition, Privy::Models::SolanaSystemProgramInstructionCondition, Privy::Models::SolanaTokenProgramInstructionCondition, Privy::Models::SystemCondition, Privy::Models::TronTransactionCondition, Privy::Models::TronCalldataCondition, Privy::Models::SuiTransactionCommandCondition, Privy::Models::SuiTransferObjectsCommandCondition, Privy::Models::ActionRequestBodyCondition, Privy::Models::AggregationCondition>
- #id ⇒ String
-
#method_ ⇒ Symbol, Privy::Models::PolicyMethod
Method the rule applies to.
- #name ⇒ String
Instance Method Summary collapse
-
#initialize(id:, action:, conditions:, method_:, name:) ⇒ Object
constructor
A rule that defines the conditions and action to take if the conditions are true.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, action:, conditions:, method_:, name:) ⇒ Object
A rule that defines the conditions and action to take if the conditions are true.
|
|
# File 'lib/privy/models/policy_rule_response.rb', line 34
|
Instance Attribute Details
#action ⇒ Symbol, Privy::Models::PolicyAction
The action to take when a policy rule matches.
16 |
# File 'lib/privy/models/policy_rule_response.rb', line 16 required :action, enum: -> { Privy::PolicyAction } |
#conditions ⇒ Array<Privy::Models::EthereumTransactionCondition, Privy::Models::EthereumCalldataCondition, Privy::Models::EthereumTypedDataDomainCondition, Privy::Models::EthereumTypedDataMessageCondition, Privy::Models::Ethereum7702AuthorizationCondition, Privy::Models::TempoTransactionCondition, Privy::Models::SolanaProgramInstructionCondition, Privy::Models::SolanaSystemProgramInstructionCondition, Privy::Models::SolanaTokenProgramInstructionCondition, Privy::Models::SystemCondition, Privy::Models::TronTransactionCondition, Privy::Models::TronCalldataCondition, Privy::Models::SuiTransactionCommandCondition, Privy::Models::SuiTransferObjectsCommandCondition, Privy::Models::ActionRequestBodyCondition, Privy::Models::AggregationCondition>
21 |
# File 'lib/privy/models/policy_rule_response.rb', line 21 required :conditions, -> { Privy::Internal::Type::ArrayOf[union: Privy::PolicyCondition] } |
#id ⇒ String
10 |
# File 'lib/privy/models/policy_rule_response.rb', line 10 required :id, String |
#method_ ⇒ Symbol, Privy::Models::PolicyMethod
Method the rule applies to.
27 |
# File 'lib/privy/models/policy_rule_response.rb', line 27 required :method_, enum: -> { Privy::PolicyMethod }, api_name: :method |
#name ⇒ String
32 |
# File 'lib/privy/models/policy_rule_response.rb', line 32 required :name, String |