Class: Privy::Models::PolicyUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::PolicyUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/privy/models/policy_update_params.rb
Overview
Instance Attribute Summary collapse
-
#name ⇒ String?
Name to assign to policy.
-
#owner ⇒ Privy::Models::OwnerInputUser, ...
The owner of the resource, specified as a Privy user ID, a P-256 public key, or null to remove the current owner.
-
#owner_id ⇒ String?
The key quorum ID to set as the owner of the resource.
- #policy_id ⇒ String
-
#privy_authorization_signature ⇒ String?
Request authorization signature.
-
#privy_request_expiry ⇒ String?
Request expiry.
- #rules ⇒ Array<Privy::Models::PolicyRuleRequestBody>?
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(policy_id:, name: nil, owner: nil, owner_id: nil, rules: nil, privy_authorization_signature: nil, privy_request_expiry: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see PolicyUpdateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(policy_id:, name: nil, owner: nil, owner_id: nil, rules: nil, privy_authorization_signature: nil, privy_request_expiry: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Privy::Models::PolicyUpdateParams for more details.
|
|
# File 'lib/privy/models/policy_update_params.rb', line 54
|
Instance Attribute Details
#name ⇒ String?
Name to assign to policy.
19 |
# File 'lib/privy/models/policy_update_params.rb', line 19 optional :name, String |
#owner ⇒ Privy::Models::OwnerInputUser, ...
The owner of the resource, specified as a Privy user ID, a P-256 public key, or null to remove the current owner.
26 |
# File 'lib/privy/models/policy_update_params.rb', line 26 optional :owner, union: -> { Privy::OwnerInput }, nil?: true |
#owner_id ⇒ String?
The key quorum ID to set as the owner of the resource. If you provide this, do not specify an owner.
33 |
# File 'lib/privy/models/policy_update_params.rb', line 33 optional :owner_id, String, nil?: true |
#policy_id ⇒ String
13 |
# File 'lib/privy/models/policy_update_params.rb', line 13 required :policy_id, String |
#privy_authorization_signature ⇒ String?
Request authorization signature. If multiple signatures are required, they should be comma separated.
45 |
# File 'lib/privy/models/policy_update_params.rb', line 45 optional :privy_authorization_signature, String |
#privy_request_expiry ⇒ String?
Request expiry. Value is a Unix timestamp in milliseconds representing the deadline by which the request must be processed.
52 |
# File 'lib/privy/models/policy_update_params.rb', line 52 optional :privy_request_expiry, String |
#rules ⇒ Array<Privy::Models::PolicyRuleRequestBody>?
38 |
# File 'lib/privy/models/policy_update_params.rb', line 38 optional :rules, -> { Privy::Internal::Type::ArrayOf[Privy::PolicyRuleRequestBody] } |