Class: Privy::Models::PrivateKeySubmitInput

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/privy/models/private_key_submit_input.rb

Defined Under Namespace

Modules: EntropyType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(address:, chain_type:, ciphertext:, encapsulated_key:, encryption_type:, entropy_type:, hpke_config: nil) ⇒ Object

Some parameter documentations has been truncated, see Privy::Models::PrivateKeySubmitInput for more details.

The submission input for importing a private key wallet.

Parameters:



# File 'lib/privy/models/private_key_submit_input.rb', line 51

Instance Attribute Details

#addressString

The address of the wallet to import.

Returns:

  • (String)


10
# File 'lib/privy/models/private_key_submit_input.rb', line 10

required :address, String

#chain_typeSymbol, Privy::Models::WalletImportSupportedChains

The chain type of the wallet to import. Currently supports ‘ethereum` and `solana`.



17
# File 'lib/privy/models/private_key_submit_input.rb', line 17

required :chain_type, enum: -> { Privy::WalletImportSupportedChains }

#ciphertextString

The encrypted entropy of the wallet to import.

Returns:

  • (String)


23
# File 'lib/privy/models/private_key_submit_input.rb', line 23

required :ciphertext, String

#encapsulated_keyString

The base64-encoded encapsulated key that was generated during encryption, for use during decryption inside the TEE.

Returns:

  • (String)


30
# File 'lib/privy/models/private_key_submit_input.rb', line 30

required :encapsulated_key, String

#encryption_typeSymbol, Privy::Models::HpkeEncryption

The encryption type of the wallet to import. Currently only supports ‘HPKE`.

Returns:



36
# File 'lib/privy/models/private_key_submit_input.rb', line 36

required :encryption_type, enum: -> { Privy::HpkeEncryption }

#entropy_typeSymbol, Privy::Models::PrivateKeySubmitInput::EntropyType



41
# File 'lib/privy/models/private_key_submit_input.rb', line 41

required :entropy_type, enum: -> { Privy::PrivateKeySubmitInput::EntropyType }

#hpke_configPrivy::Models::HpkeImportConfig?

Optional HPKE configuration for wallet import decryption. These parameters allow importing wallets encrypted by external providers that use different HPKE configurations.



49
# File 'lib/privy/models/private_key_submit_input.rb', line 49

optional :hpke_config, -> { Privy::HpkeImportConfig }