Class: Privy::Models::RawSignBytesParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::RawSignBytesParams
- Defined in:
- lib/privy/models/raw_sign_bytes_params.rb
Instance Attribute Summary collapse
-
#bytes ⇒ String
The bytes to hash and sign.
-
#encoding ⇒ Symbol, Privy::Models::RawSignBytesEncoding
Encoding scheme for bytes in the ‘raw_sign` RPC.
-
#hash_function ⇒ Symbol, Privy::Models::RawSignBytesHashFunction
Hash function for bytes in the ‘raw_sign` RPC.
Instance Method Summary collapse
-
#initialize(bytes:, encoding:, hash_function:) ⇒ Object
constructor
Parameters for hashing and signing bytes with the ‘raw_sign` RPC.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(bytes:, encoding:, hash_function:) ⇒ Object
Parameters for hashing and signing bytes with the ‘raw_sign` RPC.
|
|
# File 'lib/privy/models/raw_sign_bytes_params.rb', line 24
|
Instance Attribute Details
#bytes ⇒ String
The bytes to hash and sign.
10 |
# File 'lib/privy/models/raw_sign_bytes_params.rb', line 10 required :bytes, String |
#encoding ⇒ Symbol, Privy::Models::RawSignBytesEncoding
Encoding scheme for bytes in the ‘raw_sign` RPC.
16 |
# File 'lib/privy/models/raw_sign_bytes_params.rb', line 16 required :encoding, enum: -> { Privy::RawSignBytesEncoding } |
#hash_function ⇒ Symbol, Privy::Models::RawSignBytesHashFunction
Hash function for bytes in the ‘raw_sign` RPC.
22 |
# File 'lib/privy/models/raw_sign_bytes_params.rb', line 22 required :hash_function, enum: -> { Privy::RawSignBytesHashFunction } |