Class: Privy::Models::RecoveryKeyMaterialResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::RecoveryKeyMaterialResponse
- Defined in:
- lib/privy/models/recovery_key_material_response.rb
Instance Attribute Summary collapse
- #file_id ⇒ String
- #icloud_record_name ⇒ String
- #recovery_code ⇒ String
- #recovery_key ⇒ String
- #recovery_key_derivation_salt ⇒ String
-
#recovery_type ⇒ Symbol, Privy::Models::RecoveryType
The type of recovery mechanism used for wallet recovery.
Instance Method Summary collapse
-
#initialize(file_id:, icloud_record_name:, recovery_code:, recovery_key:, recovery_key_derivation_salt:, recovery_type:) ⇒ Object
constructor
The response containing the recovery key material.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(file_id:, icloud_record_name:, recovery_code:, recovery_key:, recovery_key_derivation_salt:, recovery_type:) ⇒ Object
The response containing the recovery key material.
|
|
# File 'lib/privy/models/recovery_key_material_response.rb', line 37
|
Instance Attribute Details
#file_id ⇒ String
9 |
# File 'lib/privy/models/recovery_key_material_response.rb', line 9 required :file_id, String |
#icloud_record_name ⇒ String
14 |
# File 'lib/privy/models/recovery_key_material_response.rb', line 14 required :icloud_record_name, String |
#recovery_code ⇒ String
19 |
# File 'lib/privy/models/recovery_key_material_response.rb', line 19 required :recovery_code, String |
#recovery_key ⇒ String
24 |
# File 'lib/privy/models/recovery_key_material_response.rb', line 24 required :recovery_key, String |
#recovery_key_derivation_salt ⇒ String
29 |
# File 'lib/privy/models/recovery_key_material_response.rb', line 29 required :recovery_key_derivation_salt, String |
#recovery_type ⇒ Symbol, Privy::Models::RecoveryType
The type of recovery mechanism used for wallet recovery.
35 |
# File 'lib/privy/models/recovery_key_material_response.rb', line 35 required :recovery_type, enum: -> { Privy::RecoveryType } |