Class: Privy::Models::ResponsePasskeyInitLink
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::ResponsePasskeyInitLink
- Defined in:
- lib/privy/models/response_passkey_init_link.rb
Instance Attribute Summary collapse
-
#options ⇒ Privy::Models::PasskeyAuthenticatorEnrollmentOptions
WebAuthn registration options as defined by the Web Authentication specification.
- #relying_party ⇒ String?
Instance Method Summary collapse
-
#initialize(options:, relying_party: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ResponsePasskeyInitLink for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(options:, relying_party: nil) ⇒ Object
Some parameter documentations has been truncated, see Privy::Models::ResponsePasskeyInitLink for more details.
Response for initiating a passkey link ceremony.
|
|
# File 'lib/privy/models/response_passkey_init_link.rb', line 18
|
Instance Attribute Details
#options ⇒ Privy::Models::PasskeyAuthenticatorEnrollmentOptions
WebAuthn registration options as defined by the Web Authentication specification.
11 |
# File 'lib/privy/models/response_passkey_init_link.rb', line 11 required :options, -> { Privy::PasskeyAuthenticatorEnrollmentOptions } |
#relying_party ⇒ String?
16 |
# File 'lib/privy/models/response_passkey_init_link.rb', line 16 optional :relying_party, String |