Class: Privy::Models::RpcIntentResponse::RequestDetails
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::RpcIntentResponse::RequestDetails
- Defined in:
- lib/privy/models/rpc_intent_response.rb
Defined Under Namespace
Modules: Method
Instance Attribute Summary collapse
-
#body ⇒ Privy::Models::EthereumSignTransactionRpcInput, ...
Request body for wallet RPC operations, discriminated by method.
- #method_ ⇒ Symbol, Privy::Models::RpcIntentResponse::RequestDetails::Method
- #url ⇒ String
Instance Method Summary collapse
-
#initialize(body:, method_:, url:) ⇒ Object
constructor
The original RPC request that would be sent to the wallet endpoint.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(body:, method_:, url:) ⇒ Object
The original RPC request that would be sent to the wallet endpoint
|
|
# File 'lib/privy/models/rpc_intent_response.rb', line 67
|
Instance Attribute Details
#body ⇒ Privy::Models::EthereumSignTransactionRpcInput, ...
Request body for wallet RPC operations, discriminated by method.
55 |
# File 'lib/privy/models/rpc_intent_response.rb', line 55 required :body, union: -> { Privy::WalletRpcRequestBody } |
#method_ ⇒ Symbol, Privy::Models::RpcIntentResponse::RequestDetails::Method
60 |
# File 'lib/privy/models/rpc_intent_response.rb', line 60 required :method_, enum: -> { Privy::RpcIntentResponse::RequestDetails::Method }, api_name: :method |
#url ⇒ String
65 |
# File 'lib/privy/models/rpc_intent_response.rb', line 65 required :url, String |