Class: Privy::Models::SeedPhraseExportInput

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/privy/models/seed_phrase_export_input.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(encryption_type:, recipient_public_key:, export_seed_phrase: nil, export_type: nil) ⇒ Object

Some parameter documentations has been truncated, see Privy::Models::SeedPhraseExportInput for more details.

Input for exporting a wallet (private key or seed phrase) with HPKE encryption.

Parameters:

  • encryption_type (Symbol, Privy::Models::HpkeEncryption)

    The encryption type of the wallet to import. Currently only supports ‘HPKE`.

  • recipient_public_key (String)

    The recipient public key for HPKE encryption, in PEM or DER (base64-encoded) for

  • export_seed_phrase (Boolean) (defaults to: nil)
  • export_type (Symbol, Privy::Models::ExportType) (defaults to: nil)

    The export type. ‘display’ is for showing the key to the user in the UI, ‘client



# File 'lib/privy/models/seed_phrase_export_input.rb', line 31

Instance Attribute Details

#encryption_typeSymbol, Privy::Models::HpkeEncryption

The encryption type of the wallet to import. Currently only supports ‘HPKE`.

Returns:



10
# File 'lib/privy/models/seed_phrase_export_input.rb', line 10

required :encryption_type, enum: -> { Privy::HpkeEncryption }

#export_seed_phraseBoolean?

Returns:

  • (Boolean, nil)


22
# File 'lib/privy/models/seed_phrase_export_input.rb', line 22

optional :export_seed_phrase, Privy::Internal::Type::Boolean

#export_typeSymbol, ...

The export type. ‘display’ is for showing the key to the user in the UI, ‘client’ is for exporting to the client application.

Returns:



29
# File 'lib/privy/models/seed_phrase_export_input.rb', line 29

optional :export_type, enum: -> { Privy::ExportType }

#recipient_public_keyString

The recipient public key for HPKE encryption, in PEM or DER (base64-encoded) format.

Returns:

  • (String)


17
# File 'lib/privy/models/seed_phrase_export_input.rb', line 17

required :recipient_public_key, String