Class: Privy::Models::SeedPhraseExportWebhookPayload

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/privy/models/seed_phrase_export_webhook_payload.rb,
sig/privy/models/seed_phrase_export_webhook_payload.rbs

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(type:, user_id:, wallet_address:, wallet_id:, export_source: nil) ⇒ Object

Some parameter documentations has been truncated, see Privy::Models::SeedPhraseExportWebhookPayload for more details.

Payload for the wallet.seed_phrase_export webhook event.

Parameters:

  • type (Symbol, Privy::Models::SeedPhraseExportWebhookPayload::Type)

    The type of webhook event.

  • user_id (String)

    The ID of the user who exported the seed phrase.

  • wallet_address (String)

    The address of the wallet.

  • wallet_id (String)

    The ID of the wallet.

  • export_source (Symbol, Privy::Models::ExportType) (defaults to: nil)

    The export type. 'display' is for showing the key to the user in the UI, 'client



# File 'lib/privy/models/seed_phrase_export_webhook_payload.rb', line 37

Instance Attribute Details

#export_sourceSymbol, ...

The export type. 'display' is for showing the key to the user in the UI, 'client' is for exporting to the client application.

Returns:



35
# File 'lib/privy/models/seed_phrase_export_webhook_payload.rb', line 35

optional :export_source, enum: -> { Privy::ExportType }

#typeSymbol, Privy::Models::SeedPhraseExportWebhookPayload::Type

The type of webhook event.

Parameters:

  • value (Privy::Models::SeedPhraseExportWebhookPayload::type_)

Returns:



10
# File 'lib/privy/models/seed_phrase_export_webhook_payload.rb', line 10

required :type, enum: -> { Privy::SeedPhraseExportWebhookPayload::Type }

#user_idString

The ID of the user who exported the seed phrase.

Parameters:

  • value (String)

Returns:

  • (String)


16
# File 'lib/privy/models/seed_phrase_export_webhook_payload.rb', line 16

required :user_id, String

#wallet_addressString

The address of the wallet.

Parameters:

  • value (String)

Returns:

  • (String)


22
# File 'lib/privy/models/seed_phrase_export_webhook_payload.rb', line 22

required :wallet_address, String

#wallet_idString

The ID of the wallet.

Parameters:

  • value (String)

Returns:

  • (String)


28
# File 'lib/privy/models/seed_phrase_export_webhook_payload.rb', line 28

required :wallet_id, String

Instance Method Details

#to_hash{

Returns:

  • ({)


35
# File 'sig/privy/models/seed_phrase_export_webhook_payload.rbs', line 35

def to_hash: -> {