Class: Privy::Models::SmartWalletNetworkConfigurationInput
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::SmartWalletNetworkConfigurationInput
- Defined in:
- lib/privy/models/smart_wallet_network_configuration_input.rb
Instance Attribute Summary collapse
- #bundler_url ⇒ String?
- #chain_id ⇒ String
- #chain_name ⇒ String?
-
#paymaster_context ⇒ Privy::Models::AlchemyPaymasterContext?
The Alchemy paymaster context for a smart wallet network configuration.
- #paymaster_url ⇒ String?
- #rpc_url ⇒ String?
Instance Method Summary collapse
-
#initialize(chain_id:, bundler_url: nil, chain_name: nil, paymaster_context: nil, paymaster_url: nil, rpc_url: nil) ⇒ Object
constructor
Input for network configuration for a smart wallet.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(chain_id:, bundler_url: nil, chain_name: nil, paymaster_context: nil, paymaster_url: nil, rpc_url: nil) ⇒ Object
Input for network configuration for a smart wallet.
|
|
# File 'lib/privy/models/smart_wallet_network_configuration_input.rb', line 37
|
Instance Attribute Details
#bundler_url ⇒ String?
14 |
# File 'lib/privy/models/smart_wallet_network_configuration_input.rb', line 14 optional :bundler_url, String |
#chain_id ⇒ String
9 |
# File 'lib/privy/models/smart_wallet_network_configuration_input.rb', line 9 required :chain_id, String |
#chain_name ⇒ String?
19 |
# File 'lib/privy/models/smart_wallet_network_configuration_input.rb', line 19 optional :chain_name, String |
#paymaster_context ⇒ Privy::Models::AlchemyPaymasterContext?
The Alchemy paymaster context for a smart wallet network configuration.
25 |
# File 'lib/privy/models/smart_wallet_network_configuration_input.rb', line 25 optional :paymaster_context, -> { Privy::AlchemyPaymasterContext } |
#paymaster_url ⇒ String?
30 |
# File 'lib/privy/models/smart_wallet_network_configuration_input.rb', line 30 optional :paymaster_url, String |
#rpc_url ⇒ String?
35 |
# File 'lib/privy/models/smart_wallet_network_configuration_input.rb', line 35 optional :rpc_url, String |