Class: Privy::Models::SparkCoopExitFeeQuote
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::SparkCoopExitFeeQuote
- Defined in:
- lib/privy/models/spark_coop_exit_fee_quote.rb,
sig/privy/models/spark_coop_exit_fee_quote.rbs
Instance Attribute Summary collapse
- #created_at ⇒ String
- #expires_at ⇒ String
- #id ⇒ String
-
#l1_broadcast_fee_fast ⇒ Privy::Models::SparkCurrencyAmount
A currency amount with its original value and unit.
-
#l1_broadcast_fee_medium ⇒ Privy::Models::SparkCurrencyAmount
A currency amount with its original value and unit.
-
#l1_broadcast_fee_slow ⇒ Privy::Models::SparkCurrencyAmount
A currency amount with its original value and unit.
- #network ⇒ String
-
#total_amount ⇒ Privy::Models::SparkCurrencyAmount
A currency amount with its original value and unit.
- #updated_at ⇒ String
-
#user_fee_fast ⇒ Privy::Models::SparkCurrencyAmount
A currency amount with its original value and unit.
-
#user_fee_medium ⇒ Privy::Models::SparkCurrencyAmount
A currency amount with its original value and unit.
-
#user_fee_slow ⇒ Privy::Models::SparkCurrencyAmount
A currency amount with its original value and unit.
Instance Method Summary collapse
-
#initialize(id:, created_at:, expires_at:, l1_broadcast_fee_fast:, l1_broadcast_fee_medium:, l1_broadcast_fee_slow:, network:, total_amount:, updated_at:, user_fee_fast:, user_fee_medium:, user_fee_slow:) ⇒ Object
constructor
A fee quote for a cooperative exit from Spark to Bitcoin L1.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, created_at:, expires_at:, l1_broadcast_fee_fast:, l1_broadcast_fee_medium:, l1_broadcast_fee_slow:, network:, total_amount:, updated_at:, user_fee_fast:, user_fee_medium:, user_fee_slow:) ⇒ Object
A fee quote for a cooperative exit from Spark to Bitcoin L1.
|
|
# File 'lib/privy/models/spark_coop_exit_fee_quote.rb', line 73
|
Instance Attribute Details
#created_at ⇒ String
14 |
# File 'lib/privy/models/spark_coop_exit_fee_quote.rb', line 14 required :created_at, String |
#expires_at ⇒ String
19 |
# File 'lib/privy/models/spark_coop_exit_fee_quote.rb', line 19 required :expires_at, String |
#id ⇒ String
9 |
# File 'lib/privy/models/spark_coop_exit_fee_quote.rb', line 9 required :id, String |
#l1_broadcast_fee_fast ⇒ Privy::Models::SparkCurrencyAmount
A currency amount with its original value and unit.
25 |
# File 'lib/privy/models/spark_coop_exit_fee_quote.rb', line 25 required :l1_broadcast_fee_fast, -> { Privy::SparkCurrencyAmount } |
#l1_broadcast_fee_medium ⇒ Privy::Models::SparkCurrencyAmount
A currency amount with its original value and unit.
31 |
# File 'lib/privy/models/spark_coop_exit_fee_quote.rb', line 31 required :l1_broadcast_fee_medium, -> { Privy::SparkCurrencyAmount } |
#l1_broadcast_fee_slow ⇒ Privy::Models::SparkCurrencyAmount
A currency amount with its original value and unit.
37 |
# File 'lib/privy/models/spark_coop_exit_fee_quote.rb', line 37 required :l1_broadcast_fee_slow, -> { Privy::SparkCurrencyAmount } |
#network ⇒ String
42 |
# File 'lib/privy/models/spark_coop_exit_fee_quote.rb', line 42 required :network, String |
#total_amount ⇒ Privy::Models::SparkCurrencyAmount
A currency amount with its original value and unit.
48 |
# File 'lib/privy/models/spark_coop_exit_fee_quote.rb', line 48 required :total_amount, -> { Privy::SparkCurrencyAmount } |
#updated_at ⇒ String
53 |
# File 'lib/privy/models/spark_coop_exit_fee_quote.rb', line 53 required :updated_at, String |
#user_fee_fast ⇒ Privy::Models::SparkCurrencyAmount
A currency amount with its original value and unit.
59 |
# File 'lib/privy/models/spark_coop_exit_fee_quote.rb', line 59 required :user_fee_fast, -> { Privy::SparkCurrencyAmount } |
#user_fee_medium ⇒ Privy::Models::SparkCurrencyAmount
A currency amount with its original value and unit.
65 |
# File 'lib/privy/models/spark_coop_exit_fee_quote.rb', line 65 required :user_fee_medium, -> { Privy::SparkCurrencyAmount } |
#user_fee_slow ⇒ Privy::Models::SparkCurrencyAmount
A currency amount with its original value and unit.
71 |
# File 'lib/privy/models/spark_coop_exit_fee_quote.rb', line 71 required :user_fee_slow, -> { Privy::SparkCurrencyAmount } |
Instance Method Details
#to_hash ⇒ {
59 |
# File 'sig/privy/models/spark_coop_exit_fee_quote.rbs', line 59
def to_hash: -> {
|