Class: Privy::Models::SparkCoopExitRequest

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/privy/models/spark_coop_exit_request.rb,
sig/privy/models/spark_coop_exit_request.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, coop_exit_txid:, created_at:, expires_at:, fee:, l1_broadcast_fee:, network:, status:, updated_at:, exit_speed: nil, fee_quote_id: nil) ⇒ Object

A cooperative exit request from Spark to Bitcoin L1.

Parameters:

  • id (String)
  • coop_exit_txid (String)
  • created_at (String)
  • expires_at (String)
  • fee (Privy::Models::SparkCurrencyAmount)

    A currency amount with its original value and unit.

  • l1_broadcast_fee (Privy::Models::SparkCurrencyAmount)

    A currency amount with its original value and unit.

  • network (String)
  • status (String)
  • updated_at (String)
  • exit_speed (Symbol, Privy::Models::SparkExitSpeed) (defaults to: nil)

    The exit speed for a cooperative withdrawal from Spark to L1.

  • fee_quote_id (String) (defaults to: nil)


# File 'lib/privy/models/spark_coop_exit_request.rb', line 64

Instance Attribute Details

#coop_exit_txidString

Parameters:

  • value (String)

Returns:

  • (String)


14
# File 'lib/privy/models/spark_coop_exit_request.rb', line 14

required :coop_exit_txid, String

#created_atString

Parameters:

  • value (String)

Returns:

  • (String)


19
# File 'lib/privy/models/spark_coop_exit_request.rb', line 19

required :created_at, String

#exit_speedSymbol, ...

The exit speed for a cooperative withdrawal from Spark to L1.

Returns:



57
# File 'lib/privy/models/spark_coop_exit_request.rb', line 57

optional :exit_speed, enum: -> { Privy::SparkExitSpeed }

#expires_atString

Parameters:

  • value (String)

Returns:

  • (String)


24
# File 'lib/privy/models/spark_coop_exit_request.rb', line 24

required :expires_at, String

#feePrivy::Models::SparkCurrencyAmount

A currency amount with its original value and unit.



30
# File 'lib/privy/models/spark_coop_exit_request.rb', line 30

required :fee, -> { Privy::SparkCurrencyAmount }

#fee_quote_idString?

Parameters:

  • (String)

Returns:

  • (String, nil)


62
# File 'lib/privy/models/spark_coop_exit_request.rb', line 62

optional :fee_quote_id, String

#idString

Parameters:

  • value (String)

Returns:

  • (String)


9
# File 'lib/privy/models/spark_coop_exit_request.rb', line 9

required :id, String

#l1_broadcast_feePrivy::Models::SparkCurrencyAmount

A currency amount with its original value and unit.



36
# File 'lib/privy/models/spark_coop_exit_request.rb', line 36

required :l1_broadcast_fee, -> { Privy::SparkCurrencyAmount }

#networkString

Parameters:

  • value (String)

Returns:

  • (String)


41
# File 'lib/privy/models/spark_coop_exit_request.rb', line 41

required :network, String

#statusString

Parameters:

  • value (String)

Returns:

  • (String)


46
# File 'lib/privy/models/spark_coop_exit_request.rb', line 46

required :status, String

#updated_atString

Parameters:

  • value (String)

Returns:

  • (String)


51
# File 'lib/privy/models/spark_coop_exit_request.rb', line 51

required :updated_at, String

Instance Method Details

#to_hash{

Returns:

  • ({)


61
# File 'sig/privy/models/spark_coop_exit_request.rbs', line 61

def to_hash: -> {