Class: Privy::Models::SparkWithdrawRpcInputParams

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/privy/models/spark_withdraw_rpc_input_params.rb,
sig/privy/models/spark_withdraw_rpc_input_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(exit_speed:, onchain_address:, amount_sats: nil, deduct_fee_from_withdrawal_amount: nil, fee_amount_sats: nil, fee_quote_id: nil) ⇒ Object

Parameters for the Spark withdraw RPC.

Parameters:

  • exit_speed (Symbol, Privy::Models::SparkExitSpeed)

    The exit speed for a cooperative withdrawal from Spark to L1.

  • onchain_address (String)
  • amount_sats (Float) (defaults to: nil)
  • deduct_fee_from_withdrawal_amount (Boolean) (defaults to: nil)
  • fee_amount_sats (Float) (defaults to: nil)
  • fee_quote_id (String) (defaults to: nil)


# File 'lib/privy/models/spark_withdraw_rpc_input_params.rb', line 37

Instance Attribute Details

#amount_satsFloat?

Parameters:

  • (Float)

Returns:

  • (Float, nil)


20
# File 'lib/privy/models/spark_withdraw_rpc_input_params.rb', line 20

optional :amount_sats, Float

#deduct_fee_from_withdrawal_amountBoolean?

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


25
# File 'lib/privy/models/spark_withdraw_rpc_input_params.rb', line 25

optional :deduct_fee_from_withdrawal_amount, Privy::Internal::Type::Boolean

#exit_speedSymbol, Privy::Models::SparkExitSpeed

The exit speed for a cooperative withdrawal from Spark to L1.

Parameters:

  • value (Privy::Models::spark_exit_speed)

Returns:



10
# File 'lib/privy/models/spark_withdraw_rpc_input_params.rb', line 10

required :exit_speed, enum: -> { Privy::SparkExitSpeed }

#fee_amount_satsFloat?

Parameters:

  • (Float)

Returns:

  • (Float, nil)


30
# File 'lib/privy/models/spark_withdraw_rpc_input_params.rb', line 30

optional :fee_amount_sats, Float

#fee_quote_idString?

Parameters:

  • (String)

Returns:

  • (String, nil)


35
# File 'lib/privy/models/spark_withdraw_rpc_input_params.rb', line 35

optional :fee_quote_id, String

#onchain_addressString

Parameters:

  • value (String)

Returns:

  • (String)


15
# File 'lib/privy/models/spark_withdraw_rpc_input_params.rb', line 15

required :onchain_address, String

Instance Method Details

#to_hash{

Returns:

  • ({)


43
# File 'sig/privy/models/spark_withdraw_rpc_input_params.rbs', line 43

def to_hash: -> {