Class: Privy::Models::SwapSource
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::SwapSource
- Defined in:
- lib/privy/models/swap_source.rb
Instance Attribute Summary collapse
-
#asset_address ⇒ String
Token contract address to sell, or “native” for the chain’s native token.
-
#caip2 ⇒ String
CAIP-2 chain identifier (e.g., “eip155:1”).
Instance Method Summary collapse
-
#initialize(asset_address:, caip2:) ⇒ Object
constructor
The input side of a swap request, including token and chain.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(asset_address:, caip2:) ⇒ Object
The input side of a swap request, including token and chain.
|
|
# File 'lib/privy/models/swap_source.rb', line 18
|
Instance Attribute Details
#asset_address ⇒ String
Token contract address to sell, or “native” for the chain’s native token.
10 |
# File 'lib/privy/models/swap_source.rb', line 10 required :asset_address, String |
#caip2 ⇒ String
CAIP-2 chain identifier (e.g., “eip155:1”).
16 |
# File 'lib/privy/models/swap_source.rb', line 16 required :caip2, String |