Class: Privy::Models::TelegramAuthenticateInput

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/privy/models/telegram_authenticate_input.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(captcha_token: nil, mode: nil, telegram_auth_result: nil, telegram_web_app_data: nil) ⇒ Object

Some parameter documentations has been truncated, see Privy::Models::TelegramAuthenticateInput for more details.

Input for authenticating with Telegram.

Parameters:



# File 'lib/privy/models/telegram_authenticate_input.rb', line 31

Instance Attribute Details

#captcha_tokenString?

Returns:

  • (String, nil)


9
# File 'lib/privy/models/telegram_authenticate_input.rb', line 9

optional :captcha_token, String

#modeSymbol, ...

Whether to allow sign-up during authentication.

Returns:



15
# File 'lib/privy/models/telegram_authenticate_input.rb', line 15

optional :mode, enum: -> { Privy::AuthenticateModeOption }

#telegram_auth_resultPrivy::Models::TelegramAuthResult?

Auth result object returned by Telegram when a user authenticates using the login widget.



22
# File 'lib/privy/models/telegram_authenticate_input.rb', line 22

optional :telegram_auth_result, -> { Privy::TelegramAuthResult }

#telegram_web_app_dataPrivy::Models::TelegramWebAppData?

Auth result object returned by Telegram when a user authenticates using a mini app.



29
# File 'lib/privy/models/telegram_authenticate_input.rb', line 29

optional :telegram_web_app_data, -> { Privy::TelegramWebAppData }