Class: Privy::Models::TempoAaAuthorization

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/privy/models/tempo_aa_authorization.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(chain_id:, contract:, nonce:, signature:) ⇒ Object

Some parameter documentations has been truncated, see Privy::Models::TempoAaAuthorization for more details.

An AA authorization for Tempo transactions with P256/WebAuthn signatures.

Parameters:

  • chain_id (String, Integer)

    A quantity value that can be either a hex string starting with ‘0x’ or a non-neg

  • contract (String)
  • nonce (String, Integer)

    A quantity value that can be either a hex string starting with ‘0x’ or a non-neg

  • signature (String)

    A hex-encoded string prefixed with ‘0x’, capped at 100002 characters (50,000 byt



# File 'lib/privy/models/tempo_aa_authorization.rb', line 32

Instance Attribute Details

#chain_idString, Integer

A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.

Returns:

  • (String, Integer)


11
# File 'lib/privy/models/tempo_aa_authorization.rb', line 11

required :chain_id, union: -> { Privy::Quantity }

#contractString

Returns:

  • (String)


16
# File 'lib/privy/models/tempo_aa_authorization.rb', line 16

required :contract, String

#nonceString, Integer

A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.

Returns:

  • (String, Integer)


23
# File 'lib/privy/models/tempo_aa_authorization.rb', line 23

required :nonce, union: -> { Privy::Quantity }

#signatureString

A hex-encoded string prefixed with ‘0x’, capped at 100002 characters (50,000 bytes).

Returns:

  • (String)


30
# File 'lib/privy/models/tempo_aa_authorization.rb', line 30

required :signature, String