Class: Privy::Models::TransactionScanningAssetDiff
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::TransactionScanningAssetDiff
- Defined in:
- lib/privy/models/transaction_scanning_asset_diff.rb
Instance Attribute Summary collapse
-
#asset ⇒ Privy::Models::TransactionScanningAssetInfo
Information about the moving asset in a transaction scan.
- #in_ ⇒ Array<Privy::Models::TransactionScanningAssetValue>
- #out ⇒ Array<Privy::Models::TransactionScanningAssetValue>
Instance Method Summary collapse
-
#initialize(asset:, in_:, out:) ⇒ Object
constructor
An asset diff representing assets entering/leaving a wallet.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(asset:, in_:, out:) ⇒ Object
An asset diff representing assets entering/leaving a wallet.
|
|
# File 'lib/privy/models/transaction_scanning_asset_diff.rb', line 26
|
Instance Attribute Details
#asset ⇒ Privy::Models::TransactionScanningAssetInfo
Information about the moving asset in a transaction scan.
10 |
# File 'lib/privy/models/transaction_scanning_asset_diff.rb', line 10 required :asset, -> { Privy::TransactionScanningAssetInfo } |
#in_ ⇒ Array<Privy::Models::TransactionScanningAssetValue>
15 16 17 18 19 |
# File 'lib/privy/models/transaction_scanning_asset_diff.rb', line 15 required :in_, -> { Privy::Internal::Type::ArrayOf[Privy::TransactionScanningAssetValue] }, api_name: :in |
#out ⇒ Array<Privy::Models::TransactionScanningAssetValue>
24 |
# File 'lib/privy/models/transaction_scanning_asset_diff.rb', line 24 required :out, -> { Privy::Internal::Type::ArrayOf[Privy::TransactionScanningAssetValue] } |