Class: Privy::Models::TransactionScanningExposure
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::TransactionScanningExposure
- Defined in:
- lib/privy/models/transaction_scanning_exposure.rb
Instance Attribute Summary collapse
-
#asset ⇒ Privy::Models::TransactionScanningAssetInfo
Information about the moving asset in a transaction scan.
- #spenders ⇒ Hash{Symbol=>Privy::Models::TransactionScanningAssetValue}
Instance Method Summary collapse
-
#initialize(asset:, spenders:) ⇒ Object
constructor
An exposure representing assets approved to spend.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(asset:, spenders:) ⇒ Object
An exposure representing assets approved to spend.
|
|
# File 'lib/privy/models/transaction_scanning_exposure.rb', line 17
|
Instance Attribute Details
#asset ⇒ Privy::Models::TransactionScanningAssetInfo
Information about the moving asset in a transaction scan.
10 |
# File 'lib/privy/models/transaction_scanning_exposure.rb', line 10 required :asset, -> { Privy::TransactionScanningAssetInfo } |
#spenders ⇒ Hash{Symbol=>Privy::Models::TransactionScanningAssetValue}
15 |
# File 'lib/privy/models/transaction_scanning_exposure.rb', line 15 required :spenders, -> { Privy::Internal::Type::HashOf[Privy::TransactionScanningAssetValue] } |