Class: Privy::Models::TransferIntentResponse::RequestDetails

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/privy/models/transfer_intent_response.rb

Defined Under Namespace

Modules: Method

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(body:, method_:, url:) ⇒ Object

The original transfer request that would be sent to the wallet transfer endpoint

Parameters:



# File 'lib/privy/models/transfer_intent_response.rb', line 75

Instance Attribute Details

#bodyPrivy::Models::TransferRequestBody

Request body for initiating a sponsored token transfer from an embedded wallet.



59
# File 'lib/privy/models/transfer_intent_response.rb', line 59

required :body, -> { Privy::TransferRequestBody }

#method_Symbol, Privy::Models::TransferIntentResponse::RequestDetails::Method



64
65
66
67
68
# File 'lib/privy/models/transfer_intent_response.rb', line 64

required :method_,
enum: -> {
  Privy::TransferIntentResponse::RequestDetails::Method
},
api_name: :method

#urlString

Returns:

  • (String)


73
# File 'lib/privy/models/transfer_intent_response.rb', line 73

required :url, String