Class: Privy::Models::TransferTelegramInput

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/privy/models/transfer_telegram_input.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(nonce:, telegram_auth_result: nil, telegram_web_app_data: nil) ⇒ Object

Some parameter documentations has been truncated, see Privy::Models::TransferTelegramInput for more details.

Input for transferring a Telegram account.

Parameters:

  • nonce (String)
  • telegram_auth_result (Privy::Models::TelegramAuthResult) (defaults to: nil)

    Auth result object returned by Telegram when a user authenticates using the logi

  • telegram_web_app_data (Privy::Models::TelegramWebAppData) (defaults to: nil)

    Auth result object returned by Telegram when a user authenticates using a mini a



# File 'lib/privy/models/transfer_telegram_input.rb', line 25

Instance Attribute Details

#nonceString

Returns:

  • (String)


9
# File 'lib/privy/models/transfer_telegram_input.rb', line 9

required :nonce, String

#telegram_auth_resultPrivy::Models::TelegramAuthResult?

Auth result object returned by Telegram when a user authenticates using the login widget.



16
# File 'lib/privy/models/transfer_telegram_input.rb', line 16

optional :telegram_auth_result, -> { Privy::TelegramAuthResult }

#telegram_web_app_dataPrivy::Models::TelegramWebAppData?

Auth result object returned by Telegram when a user authenticates using a mini app.



23
# File 'lib/privy/models/transfer_telegram_input.rb', line 23

optional :telegram_web_app_data, -> { Privy::TelegramWebAppData }