Class: Privy::Models::TypedDataInput
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::TypedDataInput
- Defined in:
- lib/privy/models/typed_data_input.rb,
sig/privy/models/typed_data_input.rbs
Instance Attribute Summary collapse
- #primary_type ⇒ String
-
#types ⇒ Hash{Symbol=>Array<Privy::Models::TypedDataTypeFieldInput>}
The type definitions for EIP-712 typed data signing.
Instance Method Summary collapse
-
#initialize(primary_type:, types:) ⇒ Object
constructor
The typed data structure containing EIP-712 types and the primary type for typed data message policy conditions.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(primary_type:, types:) ⇒ Object
The typed data structure containing EIP-712 types and the primary type for typed data message policy conditions.
|
|
# File 'lib/privy/models/typed_data_input.rb', line 18
|
Instance Attribute Details
#primary_type ⇒ String
9 |
# File 'lib/privy/models/typed_data_input.rb', line 9 required :primary_type, String |
#types ⇒ Hash{Symbol=>Array<Privy::Models::TypedDataTypeFieldInput>}
The type definitions for EIP-712 typed data signing.
15 16 |
# File 'lib/privy/models/typed_data_input.rb', line 15 required :types, -> { Privy::Internal::Type::HashOf[Privy::Internal::Type::ArrayOf[Privy::TypedDataTypeFieldInput]] } |
Instance Method Details
#to_hash ⇒ {
19 |
# File 'sig/privy/models/typed_data_input.rbs', line 19
def to_hash: -> {
|