Class: Privy::Models::UnsignedStandardEthereumTransaction

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/privy/models/unsigned_standard_ethereum_transaction.rb

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(authorization_list: nil, chain_id: nil, data: nil, from: nil, gas_limit: nil, gas_price: nil, max_fee_per_gas: nil, max_priority_fee_per_gas: nil, nonce: nil, to: nil, type: nil, value: nil) ⇒ Object

Some parameter documentations has been truncated, see Privy::Models::UnsignedStandardEthereumTransaction for more details.

An unsigned standard Ethereum transaction object. Supports EVM transaction types 0, 1, 2, and 4.

Parameters:

  • authorization_list (Array<Privy::Models::EthereumSign7702Authorization>) (defaults to: nil)
  • chain_id (String, Integer) (defaults to: nil)

    A quantity value that can be either a hex string starting with ‘0x’ or a non-neg

  • data (String) (defaults to: nil)

    A hex-encoded string prefixed with ‘0x’, capped at 100002 characters (50,000 byt

  • from (String) (defaults to: nil)
  • gas_limit (String, Integer) (defaults to: nil)

    A quantity value that can be either a hex string starting with ‘0x’ or a non-neg

  • gas_price (String, Integer) (defaults to: nil)

    A quantity value that can be either a hex string starting with ‘0x’ or a non-neg

  • max_fee_per_gas (String, Integer) (defaults to: nil)

    A quantity value that can be either a hex string starting with ‘0x’ or a non-neg

  • max_priority_fee_per_gas (String, Integer) (defaults to: nil)

    A quantity value that can be either a hex string starting with ‘0x’ or a non-neg

  • nonce (String, Integer) (defaults to: nil)

    A quantity value that can be either a hex string starting with ‘0x’ or a non-neg

  • to (String) (defaults to: nil)
  • type (Float, Privy::Models::UnsignedStandardEthereumTransaction::Type) (defaults to: nil)
  • value (String, Integer) (defaults to: nil)

    A quantity value that can be either a hex string starting with ‘0x’ or a non-neg



# File 'lib/privy/models/unsigned_standard_ethereum_transaction.rb', line 82

Instance Attribute Details

#authorization_listArray<Privy::Models::EthereumSign7702Authorization>?



9
# File 'lib/privy/models/unsigned_standard_ethereum_transaction.rb', line 9

optional :authorization_list, -> { Privy::Internal::Type::ArrayOf[Privy::EthereumSign7702Authorization] }

#chain_idString, ...

A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.

Returns:

  • (String, Integer, nil)


16
# File 'lib/privy/models/unsigned_standard_ethereum_transaction.rb', line 16

optional :chain_id, union: -> { Privy::Quantity }

#dataString?

A hex-encoded string prefixed with ‘0x’, capped at 100002 characters (50,000 bytes).

Returns:

  • (String, nil)


23
# File 'lib/privy/models/unsigned_standard_ethereum_transaction.rb', line 23

optional :data, String

#fromString?

Returns:

  • (String, nil)


28
# File 'lib/privy/models/unsigned_standard_ethereum_transaction.rb', line 28

optional :from, String

#gas_limitString, ...

A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.

Returns:

  • (String, Integer, nil)


35
# File 'lib/privy/models/unsigned_standard_ethereum_transaction.rb', line 35

optional :gas_limit, union: -> { Privy::Quantity }

#gas_priceString, ...

A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.

Returns:

  • (String, Integer, nil)


42
# File 'lib/privy/models/unsigned_standard_ethereum_transaction.rb', line 42

optional :gas_price, union: -> { Privy::Quantity }

#max_fee_per_gasString, ...

A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.

Returns:

  • (String, Integer, nil)


49
# File 'lib/privy/models/unsigned_standard_ethereum_transaction.rb', line 49

optional :max_fee_per_gas, union: -> { Privy::Quantity }

#max_priority_fee_per_gasString, ...

A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.

Returns:

  • (String, Integer, nil)


56
# File 'lib/privy/models/unsigned_standard_ethereum_transaction.rb', line 56

optional :max_priority_fee_per_gas, union: -> { Privy::Quantity }

#nonceString, ...

A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.

Returns:

  • (String, Integer, nil)


63
# File 'lib/privy/models/unsigned_standard_ethereum_transaction.rb', line 63

optional :nonce, union: -> { Privy::Quantity }

#toString?

Returns:

  • (String, nil)


68
# File 'lib/privy/models/unsigned_standard_ethereum_transaction.rb', line 68

optional :to, String

#typeFloat, ...



73
# File 'lib/privy/models/unsigned_standard_ethereum_transaction.rb', line 73

optional :type, enum: -> { Privy::UnsignedStandardEthereumTransaction::Type }

#valueString, ...

A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.

Returns:

  • (String, Integer, nil)


80
# File 'lib/privy/models/unsigned_standard_ethereum_transaction.rb', line 80

optional :value, union: -> { Privy::Quantity }