Class: Privy::Models::UnsignedTempoTransaction

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/privy/models/unsigned_tempo_transaction.rb

Defined Under Namespace

Modules: Type Classes: AccessList

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(calls:, type:, aa_authorization_list: nil, access_list: nil, chain_id: nil, fee_payer_signature: nil, fee_token: nil, from: nil, gas_limit: nil, max_fee_per_gas: nil, max_priority_fee_per_gas: nil, nonce: nil, nonce_key: nil, valid_after: nil, valid_before: nil) ⇒ Object

Some parameter documentations has been truncated, see Privy::Models::UnsignedTempoTransaction for more details.

An unsigned Tempo transaction (type 118) with batched calls.

Parameters:

  • calls (Array<Privy::Models::TempoCall>)
  • type (Float, Privy::Models::UnsignedTempoTransaction::Type)
  • aa_authorization_list (Array<Privy::Models::TempoAaAuthorization>) (defaults to: nil)
  • access_list (Array<Privy::Models::UnsignedTempoTransaction::AccessList>) (defaults to: nil)
  • chain_id (String, Integer) (defaults to: nil)

    A quantity value that can be either a hex string starting with ‘0x’ or a non-neg

  • fee_payer_signature (Privy::Models::TempoFeePayerSignature) (defaults to: nil)

    A fee payer signature for sponsored Tempo transactions (secp256k1 only).

  • fee_token (String) (defaults to: nil)
  • from (String) (defaults to: nil)
  • gas_limit (String, Integer) (defaults to: nil)

    A quantity value that can be either a hex string starting with ‘0x’ or a non-neg

  • max_fee_per_gas (String, Integer) (defaults to: nil)

    A quantity value that can be either a hex string starting with ‘0x’ or a non-neg

  • max_priority_fee_per_gas (String, Integer) (defaults to: nil)

    A quantity value that can be either a hex string starting with ‘0x’ or a non-neg

  • nonce (String, Integer) (defaults to: nil)

    A quantity value that can be either a hex string starting with ‘0x’ or a non-neg

  • nonce_key (String, Integer) (defaults to: nil)

    A quantity value that can be either a hex string starting with ‘0x’ or a non-neg

  • valid_after (String, Integer) (defaults to: nil)

    A quantity value that can be either a hex string starting with ‘0x’ or a non-neg

  • valid_before (String, Integer) (defaults to: nil)

    A quantity value that can be either a hex string starting with ‘0x’ or a non-neg



# File 'lib/privy/models/unsigned_tempo_transaction.rb', line 98

Instance Attribute Details

#aa_authorization_listArray<Privy::Models::TempoAaAuthorization>?

Returns:



19
# File 'lib/privy/models/unsigned_tempo_transaction.rb', line 19

optional :aa_authorization_list, -> { Privy::Internal::Type::ArrayOf[Privy::TempoAaAuthorization] }

#access_listArray<Privy::Models::UnsignedTempoTransaction::AccessList>?



24
# File 'lib/privy/models/unsigned_tempo_transaction.rb', line 24

optional :access_list, -> { Privy::Internal::Type::ArrayOf[Privy::UnsignedTempoTransaction::AccessList] }

#callsArray<Privy::Models::TempoCall>

Returns:



9
# File 'lib/privy/models/unsigned_tempo_transaction.rb', line 9

required :calls, -> { Privy::Internal::Type::ArrayOf[Privy::TempoCall] }

#chain_idString, ...

A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.

Returns:

  • (String, Integer, nil)


31
# File 'lib/privy/models/unsigned_tempo_transaction.rb', line 31

optional :chain_id, union: -> { Privy::Quantity }

#fee_payer_signaturePrivy::Models::TempoFeePayerSignature?

A fee payer signature for sponsored Tempo transactions (secp256k1 only).



37
# File 'lib/privy/models/unsigned_tempo_transaction.rb', line 37

optional :fee_payer_signature, -> { Privy::TempoFeePayerSignature }

#fee_tokenString?

Returns:

  • (String, nil)


42
# File 'lib/privy/models/unsigned_tempo_transaction.rb', line 42

optional :fee_token, String

#fromString?

Returns:

  • (String, nil)


47
# File 'lib/privy/models/unsigned_tempo_transaction.rb', line 47

optional :from, String

#gas_limitString, ...

A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.

Returns:

  • (String, Integer, nil)


54
# File 'lib/privy/models/unsigned_tempo_transaction.rb', line 54

optional :gas_limit, union: -> { Privy::Quantity }

#max_fee_per_gasString, ...

A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.

Returns:

  • (String, Integer, nil)


61
# File 'lib/privy/models/unsigned_tempo_transaction.rb', line 61

optional :max_fee_per_gas, union: -> { Privy::Quantity }

#max_priority_fee_per_gasString, ...

A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.

Returns:

  • (String, Integer, nil)


68
# File 'lib/privy/models/unsigned_tempo_transaction.rb', line 68

optional :max_priority_fee_per_gas, union: -> { Privy::Quantity }

#nonceString, ...

A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.

Returns:

  • (String, Integer, nil)


75
# File 'lib/privy/models/unsigned_tempo_transaction.rb', line 75

optional :nonce, union: -> { Privy::Quantity }

#nonce_keyString, ...

A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.

Returns:

  • (String, Integer, nil)


82
# File 'lib/privy/models/unsigned_tempo_transaction.rb', line 82

optional :nonce_key, union: -> { Privy::Quantity }

#typeFloat, Privy::Models::UnsignedTempoTransaction::Type



14
# File 'lib/privy/models/unsigned_tempo_transaction.rb', line 14

required :type, enum: -> { Privy::UnsignedTempoTransaction::Type }

#valid_afterString, ...

A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.

Returns:

  • (String, Integer, nil)


89
# File 'lib/privy/models/unsigned_tempo_transaction.rb', line 89

optional :valid_after, union: -> { Privy::Quantity }

#valid_beforeString, ...

A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.

Returns:

  • (String, Integer, nil)


96
# File 'lib/privy/models/unsigned_tempo_transaction.rb', line 96

optional :valid_before, union: -> { Privy::Quantity }

Class Method Details

.valuesArray<Float>

Returns:

  • (Array<Float>)


# File 'lib/privy/models/unsigned_tempo_transaction.rb', line 140