Class: Privy::Models::UpdateAccountFromWalletsConfigurationInput
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::UpdateAccountFromWalletsConfigurationInput
- Defined in:
- lib/privy/models/update_account_from_wallets_configuration_input.rb
Instance Attribute Summary collapse
-
#display_name ⇒ String?
An optional display name for the account.
-
#wallets_configuration ⇒ Array<Privy::Models::AccountWalletConfigurationItem>?
Configuration for the wallets on this account.
Instance Method Summary collapse
-
#initialize(display_name: nil, wallets_configuration: nil) ⇒ Object
constructor
Input for updating a digital asset account with a ‘wallets_configuration` specification.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(display_name: nil, wallets_configuration: nil) ⇒ Object
Input for updating a digital asset account with a ‘wallets_configuration` specification.
|
|
# File 'lib/privy/models/update_account_from_wallets_configuration_input.rb', line 19
|
Instance Attribute Details
#display_name ⇒ String?
An optional display name for the account.
10 |
# File 'lib/privy/models/update_account_from_wallets_configuration_input.rb', line 10 optional :display_name, String |
#wallets_configuration ⇒ Array<Privy::Models::AccountWalletConfigurationItem>?
Configuration for the wallets on this account.
16 17 |
# File 'lib/privy/models/update_account_from_wallets_configuration_input.rb', line 16 optional :wallets_configuration, -> { Privy::Internal::Type::ArrayOf[Privy::AccountWalletConfigurationItem] } |