Class: Privy::Models::Wallet

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/privy/models/wallet.rb,
sig/privy/models/wallet.rbs

Overview

See Also:

  • Privy::Resources::Wallets#create

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, additional_signers:, address:, chain_type:, created_at:, exported_at:, imported_at:, owner_id:, policy_ids:, archived_at: nil, authorization_threshold: nil, custody: nil, display_name: nil, external_id: nil, public_key: nil) ⇒ Object

Some parameter documentations has been truncated, see Privy::Models::Wallet for more details.

A wallet managed by Privy's wallet infrastructure.

Parameters:

  • id (String)

    Unique ID of the wallet. This will be the primary identifier when using the wall

  • additional_signers (Array<Privy::Models::WalletAdditionalSignerItem>)

    Additional signers for the wallet.

  • address (String)

    Address of the wallet.

  • chain_type (Symbol, Privy::Models::WalletChainType)

    The wallet chain types.

  • created_at (Float)

    Unix timestamp of when the wallet was created in milliseconds.

  • exported_at (Float, nil)

    Unix timestamp of when the wallet was exported in milliseconds, if the wallet wa

  • imported_at (Float, nil)

    Unix timestamp of when the wallet was imported in milliseconds, if the wallet wa

  • owner_id (String, nil)

    The key quorum ID of the owner of the wallet.

  • policy_ids (Array<String>)

    List of policy IDs for policies that are enforced on the wallet.

  • archived_at (Float, nil) (defaults to: nil)

    Unix timestamp of when the wallet was archived in milliseconds, or null if the w

  • authorization_threshold (Float) (defaults to: nil)

    The number of keys that must sign for an action to be valid.

  • custody (Privy::Models::WalletCustodian) (defaults to: nil)

    Information about the custodian managing this wallet.

  • display_name (String) (defaults to: nil)

    A human-readable label for the wallet.

  • external_id (String) (defaults to: nil)

    A customer-provided identifier for mapping to external systems. Write-once, set

  • public_key (String) (defaults to: nil)

    The compressed, raw public key for the wallet along the chain cryptographic curv



# File 'lib/privy/models/wallet.rb', line 103

Instance Attribute Details

#additional_signersArray<Privy::Models::WalletAdditionalSignerItem>

Additional signers for the wallet.

Parameters:

  • value (Privy::Models::wallet_additional_signer)

Returns:



18
# File 'lib/privy/models/wallet.rb', line 18

required :additional_signers, -> { Privy::Internal::Type::ArrayOf[Privy::WalletAdditionalSignerItem] }

#addressString

Address of the wallet.

Parameters:

  • value (String)

Returns:

  • (String)


24
# File 'lib/privy/models/wallet.rb', line 24

required :address, String

#archived_atFloat?

Unix timestamp of when the wallet was archived in milliseconds, or null if the wallet is active.

Parameters:

  • value (Float, nil)

Returns:

  • (Float, nil)


69
# File 'lib/privy/models/wallet.rb', line 69

optional :archived_at, Float, nil?: true

#authorization_thresholdFloat?

The number of keys that must sign for an action to be valid.

Parameters:

  • (Float)

Returns:

  • (Float, nil)


75
# File 'lib/privy/models/wallet.rb', line 75

optional :authorization_threshold, Float

#chain_typeSymbol, Privy::Models::WalletChainType

The wallet chain types.

Parameters:

  • value (Privy::Models::wallet_chain_type)

Returns:



30
# File 'lib/privy/models/wallet.rb', line 30

required :chain_type, enum: -> { Privy::WalletChainType }

#created_atFloat

Unix timestamp of when the wallet was created in milliseconds.

Parameters:

  • value (Float)

Returns:

  • (Float)


36
# File 'lib/privy/models/wallet.rb', line 36

required :created_at, Float

#custodyPrivy::Models::WalletCustodian?

Information about the custodian managing this wallet.



81
# File 'lib/privy/models/wallet.rb', line 81

optional :custody, -> { Privy::WalletCustodian }

#display_nameString?

A human-readable label for the wallet.

Parameters:

  • (String)

Returns:

  • (String, nil)


87
# File 'lib/privy/models/wallet.rb', line 87

optional :display_name, String

#exported_atFloat?

Unix timestamp of when the wallet was exported in milliseconds, if the wallet was exported.

Parameters:

  • value (Float, nil)

Returns:

  • (Float, nil)


43
# File 'lib/privy/models/wallet.rb', line 43

required :exported_at, Float, nil?: true

#external_idString?

A customer-provided identifier for mapping to external systems. Write-once, set only at creation.

Parameters:

  • (String)

Returns:

  • (String, nil)


94
# File 'lib/privy/models/wallet.rb', line 94

optional :external_id, String

#idString

Unique ID of the wallet. This will be the primary identifier when using the wallet in the future.

Parameters:

  • value (String)

Returns:

  • (String)


12
# File 'lib/privy/models/wallet.rb', line 12

required :id, String

#imported_atFloat?

Unix timestamp of when the wallet was imported in milliseconds, if the wallet was imported.

Parameters:

  • value (Float, nil)

Returns:

  • (Float, nil)


50
# File 'lib/privy/models/wallet.rb', line 50

required :imported_at, Float, nil?: true

#owner_idString?

The key quorum ID of the owner of the wallet.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


56
# File 'lib/privy/models/wallet.rb', line 56

required :owner_id, String, nil?: true

#policy_idsArray<String>

List of policy IDs for policies that are enforced on the wallet.

Parameters:

  • value (::Array[String])

Returns:

  • (Array<String>)


62
# File 'lib/privy/models/wallet.rb', line 62

required :policy_ids, Privy::Internal::Type::ArrayOf[String]

#public_keyString?

The compressed, raw public key for the wallet along the chain cryptographic curve.

Parameters:

  • (String)

Returns:

  • (String, nil)


101
# File 'lib/privy/models/wallet.rb', line 101

optional :public_key, String

Instance Method Details

#to_hash{

Returns:

  • ({)


81
# File 'sig/privy/models/wallet.rbs', line 81

def to_hash: -> {