Class: Privy::Models::WalletActionEarnDepositFailedWebhookPayload

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/privy/models/wallet_action_earn_deposit_failed_webhook_payload.rb

Defined Under Namespace

Modules: Status, Type

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(action_type:, asset_address:, caip2:, failure_reason:, raw_amount:, status:, steps:, type:, vault_address:, vault_id:, wallet_action_id:, wallet_id:, amount: nil, asset: nil, decimals: nil) ⇒ Object

Some parameter documentations has been truncated, see Privy::Models::WalletActionEarnDepositFailedWebhookPayload for more details.

Payload for the wallet_action.earn_deposit.failed webhook event.

Parameters:



# File 'lib/privy/models/wallet_action_earn_deposit_failed_webhook_payload.rb', line 100

Instance Attribute Details

#action_typeSymbol, Privy::Models::WalletActionType

Type of wallet action

Returns:



10
# File 'lib/privy/models/wallet_action_earn_deposit_failed_webhook_payload.rb', line 10

required :action_type, enum: -> { Privy::WalletActionType }

#amountString?

Human-readable decimal amount of asset deposited (e.g. “1.5”). Only present when the token is known in the asset registry.

Returns:

  • (String, nil)


84
# File 'lib/privy/models/wallet_action_earn_deposit_failed_webhook_payload.rb', line 84

optional :amount, String

#assetString?

Asset identifier (e.g. “usdc”, “eth”). Only present when the token is known in the asset registry.

Returns:

  • (String, nil)


91
# File 'lib/privy/models/wallet_action_earn_deposit_failed_webhook_payload.rb', line 91

optional :asset, String

#asset_addressString

Underlying asset token address.

Returns:

  • (String)


16
# File 'lib/privy/models/wallet_action_earn_deposit_failed_webhook_payload.rb', line 16

required :asset_address, String

#caip2String

CAIP-2 chain identifier.

Returns:

  • (String)


22
# File 'lib/privy/models/wallet_action_earn_deposit_failed_webhook_payload.rb', line 22

required :caip2, String

#decimalsInteger?

Number of decimals for the underlying asset (e.g. 6 for USDC, 18 for ETH). Only present when the token is known in the asset registry.

Returns:

  • (Integer, nil)


98
# File 'lib/privy/models/wallet_action_earn_deposit_failed_webhook_payload.rb', line 98

optional :decimals, Integer

#failure_reasonPrivy::Models::FailureReason

A description of why a wallet action (or a step within a wallet action) failed.



28
# File 'lib/privy/models/wallet_action_earn_deposit_failed_webhook_payload.rb', line 28

required :failure_reason, -> { Privy::FailureReason }

#raw_amountString

Base-unit amount of asset deposited (e.g. “1500000”).

Returns:

  • (String)


34
# File 'lib/privy/models/wallet_action_earn_deposit_failed_webhook_payload.rb', line 34

required :raw_amount, String

#statusSymbol, Privy::Models::WalletActionEarnDepositFailedWebhookPayload::Status

The status of the wallet action.



40
# File 'lib/privy/models/wallet_action_earn_deposit_failed_webhook_payload.rb', line 40

required :status, enum: -> { Privy::WalletActionEarnDepositFailedWebhookPayload::Status }

#stepsArray<Privy::Models::EvmTransactionWalletActionStep, Privy::Models::EvmUserOperationWalletActionStep, Privy::Models::SvmTransactionWalletActionStep, Privy::Models::ExternalTransactionWalletActionStep>

The steps of the wallet action. Completed steps will have transaction hashes; the failing step will have a failure_reason.



47
# File 'lib/privy/models/wallet_action_earn_deposit_failed_webhook_payload.rb', line 47

required :steps, -> { Privy::Internal::Type::ArrayOf[union: Privy::WalletActionStep] }

#typeSymbol, Privy::Models::WalletActionEarnDepositFailedWebhookPayload::Type

The type of webhook event.



53
# File 'lib/privy/models/wallet_action_earn_deposit_failed_webhook_payload.rb', line 53

required :type, enum: -> { Privy::WalletActionEarnDepositFailedWebhookPayload::Type }

#vault_addressString

ERC-4626 vault contract address.

Returns:

  • (String)


59
# File 'lib/privy/models/wallet_action_earn_deposit_failed_webhook_payload.rb', line 59

required :vault_address, String

#vault_idString

The vault ID.

Returns:

  • (String)


65
# File 'lib/privy/models/wallet_action_earn_deposit_failed_webhook_payload.rb', line 65

required :vault_id, String

#wallet_action_idString

The ID of the wallet action.

Returns:

  • (String)


71
# File 'lib/privy/models/wallet_action_earn_deposit_failed_webhook_payload.rb', line 71

required :wallet_action_id, String

#wallet_idString

The ID of the wallet involved in the action.

Returns:

  • (String)


77
# File 'lib/privy/models/wallet_action_earn_deposit_failed_webhook_payload.rb', line 77

required :wallet_id, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/privy/models/wallet_action_earn_deposit_failed_webhook_payload.rb', line 144