Class: Privy::Models::WalletActionEarnIncentiveClaimRejectedWebhookPayload
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::WalletActionEarnIncentiveClaimRejectedWebhookPayload
- Defined in:
- lib/privy/models/wallet_action_earn_incentive_claim_rejected_webhook_payload.rb,
sig/privy/models/wallet_action_earn_incentive_claim_rejected_webhook_payload.rbs
Defined Under Namespace
Instance Attribute Summary collapse
-
#action_type ⇒ Symbol, Privy::Models::Wallets::WalletActionType
Type of wallet action.
-
#chain ⇒ String
EVM chain name (e.g. "base", "ethereum").
-
#created_at ⇒ String
ISO 8601 timestamp of when the wallet action was created.
-
#failure_reason ⇒ Privy::Models::Wallets::FailureReason
A description of why a wallet action (or a step within a wallet action) failed.
-
#rejected_at ⇒ String
ISO 8601 timestamp of when the wallet action was rejected.
-
#rewards ⇒ Array<Privy::Models::Wallets::EarnIncetiveClaimRewardEntry>?
Claimed reward tokens.
-
#status ⇒ Symbol, Privy::Models::WalletActionEarnIncentiveClaimRejectedWebhookPayload::Status
The status of the wallet action.
-
#steps ⇒ Array<Privy::Models::Wallets::EvmTransactionWalletActionStep, Privy::Models::Wallets::EvmUserOperationWalletActionStep, Privy::Models::Wallets::SvmTransactionWalletActionStep, Privy::Models::Wallets::TvmTransactionWalletActionStep, Privy::Models::Wallets::ExternalTransactionWalletActionStep, Privy::Models::Wallets::CustodianTransactionWalletActionStep>
The steps of the wallet action at the time of rejection.
-
#type ⇒ Symbol, Privy::Models::WalletActionEarnIncentiveClaimRejectedWebhookPayload::Type
The type of webhook event.
-
#wallet_action_id ⇒ String
The ID of the wallet action.
-
#wallet_id ⇒ String
The ID of the wallet involved in the action.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(action_type:, chain:, created_at:, failure_reason:, rejected_at:, rewards:, status:, steps:, type:, wallet_action_id:, wallet_id:) ⇒ Object
constructor
Payload for the wallet_action.earn_incentive_claim.rejected webhook event.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(action_type:, chain:, created_at:, failure_reason:, rejected_at:, rewards:, status:, steps:, type:, wallet_action_id:, wallet_id:) ⇒ Object
Payload for the wallet_action.earn_incentive_claim.rejected webhook event.
|
|
# File 'lib/privy/models/wallet_action_earn_incentive_claim_rejected_webhook_payload.rb', line 74
|
Instance Attribute Details
#action_type ⇒ Symbol, Privy::Models::Wallets::WalletActionType
Type of wallet action
10 |
# File 'lib/privy/models/wallet_action_earn_incentive_claim_rejected_webhook_payload.rb', line 10 required :action_type, enum: -> { Privy::Wallets::WalletActionType } |
#chain ⇒ String
EVM chain name (e.g. "base", "ethereum").
16 |
# File 'lib/privy/models/wallet_action_earn_incentive_claim_rejected_webhook_payload.rb', line 16 required :chain, String |
#created_at ⇒ String
ISO 8601 timestamp of when the wallet action was created.
22 |
# File 'lib/privy/models/wallet_action_earn_incentive_claim_rejected_webhook_payload.rb', line 22 required :created_at, String |
#failure_reason ⇒ Privy::Models::Wallets::FailureReason
A description of why a wallet action (or a step within a wallet action) failed.
28 |
# File 'lib/privy/models/wallet_action_earn_incentive_claim_rejected_webhook_payload.rb', line 28 required :failure_reason, -> { Privy::Wallets::FailureReason } |
#rejected_at ⇒ String
ISO 8601 timestamp of when the wallet action was rejected.
34 |
# File 'lib/privy/models/wallet_action_earn_incentive_claim_rejected_webhook_payload.rb', line 34 required :rejected_at, String |
#rewards ⇒ Array<Privy::Models::Wallets::EarnIncetiveClaimRewardEntry>?
Claimed reward tokens. Populated after the preparation step fetches from Merkl.
40 41 42 |
# File 'lib/privy/models/wallet_action_earn_incentive_claim_rejected_webhook_payload.rb', line 40 required :rewards, -> { Privy::Internal::Type::ArrayOf[Privy::Wallets::EarnIncetiveClaimRewardEntry] }, nil?: true |
#status ⇒ Symbol, Privy::Models::WalletActionEarnIncentiveClaimRejectedWebhookPayload::Status
The status of the wallet action.
48 |
# File 'lib/privy/models/wallet_action_earn_incentive_claim_rejected_webhook_payload.rb', line 48 required :status, enum: -> { Privy::WalletActionEarnIncentiveClaimRejectedWebhookPayload::Status } |
#steps ⇒ Array<Privy::Models::Wallets::EvmTransactionWalletActionStep, Privy::Models::Wallets::EvmUserOperationWalletActionStep, Privy::Models::Wallets::SvmTransactionWalletActionStep, Privy::Models::Wallets::TvmTransactionWalletActionStep, Privy::Models::Wallets::ExternalTransactionWalletActionStep, Privy::Models::Wallets::CustodianTransactionWalletActionStep>
The steps of the wallet action at the time of rejection.
54 |
# File 'lib/privy/models/wallet_action_earn_incentive_claim_rejected_webhook_payload.rb', line 54 required :steps, -> { Privy::Internal::Type::ArrayOf[union: Privy::Wallets::WalletActionStep] } |
#type ⇒ Symbol, Privy::Models::WalletActionEarnIncentiveClaimRejectedWebhookPayload::Type
The type of webhook event.
60 |
# File 'lib/privy/models/wallet_action_earn_incentive_claim_rejected_webhook_payload.rb', line 60 required :type, enum: -> { Privy::WalletActionEarnIncentiveClaimRejectedWebhookPayload::Type } |
#wallet_action_id ⇒ String
The ID of the wallet action.
66 |
# File 'lib/privy/models/wallet_action_earn_incentive_claim_rejected_webhook_payload.rb', line 66 required :wallet_action_id, String |
#wallet_id ⇒ String
The ID of the wallet involved in the action.
72 |
# File 'lib/privy/models/wallet_action_earn_incentive_claim_rejected_webhook_payload.rb', line 72 required :wallet_id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/privy/models/wallet_action_earn_incentive_claim_rejected_webhook_payload.rb', line 107
|
Instance Method Details
#to_hash ⇒ {
55 |
# File 'sig/privy/models/wallet_action_earn_incentive_claim_rejected_webhook_payload.rbs', line 55
def to_hash: -> {
|