Class: Privy::Models::WalletActionEarnWithdrawSucceededWebhookPayload
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::WalletActionEarnWithdrawSucceededWebhookPayload
- Defined in:
- lib/privy/models/wallet_action_earn_withdraw_succeeded_webhook_payload.rb,
sig/privy/models/wallet_action_earn_withdraw_succeeded_webhook_payload.rbs
Defined Under Namespace
Instance Attribute Summary collapse
-
#action_type ⇒ Symbol, Privy::Models::Wallets::WalletActionType
Type of wallet action.
-
#amount ⇒ String?
Human-readable decimal amount of asset withdrawn (e.g. "1.5").
-
#asset ⇒ String?
Asset identifier (e.g. "usdc", "eth").
-
#asset_address ⇒ String
Underlying asset token address.
-
#caip2 ⇒ String
CAIP-2 chain identifier.
-
#completed_at ⇒ String
ISO 8601 timestamp of when the wallet action completed successfully.
-
#created_at ⇒ String
ISO 8601 timestamp of when the wallet action was created.
-
#decimals ⇒ Integer?
Number of decimals for the underlying asset (e.g. 6 for USDC, 18 for ETH).
-
#raw_amount ⇒ String
Base-unit amount of asset withdrawn (e.g. "1500000").
-
#share_amount ⇒ String
Vault shares burned in base units.
-
#status ⇒ Symbol, Privy::Models::WalletActionEarnWithdrawSucceededWebhookPayload::Status
The status of the wallet action.
-
#steps ⇒ Array<Privy::Models::Wallets::EvmTransactionWalletActionStep, Privy::Models::Wallets::EvmUserOperationWalletActionStep, Privy::Models::Wallets::SvmTransactionWalletActionStep, Privy::Models::Wallets::TvmTransactionWalletActionStep, Privy::Models::Wallets::ExternalTransactionWalletActionStep, Privy::Models::Wallets::CustodianTransactionWalletActionStep>
The steps of the wallet action, including transaction hashes.
-
#type ⇒ Symbol, Privy::Models::WalletActionEarnWithdrawSucceededWebhookPayload::Type
The type of webhook event.
-
#vault_address ⇒ String
ERC-4626 vault contract address.
-
#vault_id ⇒ String
The vault ID.
-
#wallet_action_id ⇒ String
The ID of the wallet action.
-
#wallet_id ⇒ String
The ID of the wallet involved in the action.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(action_type:, asset_address:, caip2:, completed_at:, created_at:, raw_amount:, share_amount:, status:, steps:, type:, vault_address:, vault_id:, wallet_action_id:, wallet_id:, amount: nil, asset: nil, decimals: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see WalletActionEarnWithdrawSucceededWebhookPayload for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(action_type:, asset_address:, caip2:, completed_at:, created_at:, raw_amount:, share_amount:, status:, steps:, type:, vault_address:, vault_id:, wallet_action_id:, wallet_id:, amount: nil, asset: nil, decimals: nil) ⇒ Object
Some parameter documentations has been truncated, see Privy::Models::WalletActionEarnWithdrawSucceededWebhookPayload for more details.
Payload for the wallet_action.earn_withdraw.succeeded webhook event.
|
|
# File 'lib/privy/models/wallet_action_earn_withdraw_succeeded_webhook_payload.rb', line 111
|
Instance Attribute Details
#action_type ⇒ Symbol, Privy::Models::Wallets::WalletActionType
Type of wallet action
10 |
# File 'lib/privy/models/wallet_action_earn_withdraw_succeeded_webhook_payload.rb', line 10 required :action_type, enum: -> { Privy::Wallets::WalletActionType } |
#amount ⇒ String?
Human-readable decimal amount of asset withdrawn (e.g. "1.5"). Only present when the token is known in the asset registry.
95 |
# File 'lib/privy/models/wallet_action_earn_withdraw_succeeded_webhook_payload.rb', line 95 optional :amount, String |
#asset ⇒ String?
Asset identifier (e.g. "usdc", "eth"). Only present when the token is known in the asset registry.
102 |
# File 'lib/privy/models/wallet_action_earn_withdraw_succeeded_webhook_payload.rb', line 102 optional :asset, String |
#asset_address ⇒ String
Underlying asset token address.
16 |
# File 'lib/privy/models/wallet_action_earn_withdraw_succeeded_webhook_payload.rb', line 16 required :asset_address, String |
#caip2 ⇒ String
CAIP-2 chain identifier.
22 |
# File 'lib/privy/models/wallet_action_earn_withdraw_succeeded_webhook_payload.rb', line 22 required :caip2, String |
#completed_at ⇒ String
ISO 8601 timestamp of when the wallet action completed successfully.
28 |
# File 'lib/privy/models/wallet_action_earn_withdraw_succeeded_webhook_payload.rb', line 28 required :completed_at, String |
#created_at ⇒ String
ISO 8601 timestamp of when the wallet action was created.
34 |
# File 'lib/privy/models/wallet_action_earn_withdraw_succeeded_webhook_payload.rb', line 34 required :created_at, String |
#decimals ⇒ Integer?
Number of decimals for the underlying asset (e.g. 6 for USDC, 18 for ETH). Only present when the token is known in the asset registry.
109 |
# File 'lib/privy/models/wallet_action_earn_withdraw_succeeded_webhook_payload.rb', line 109 optional :decimals, Integer |
#raw_amount ⇒ String
Base-unit amount of asset withdrawn (e.g. "1500000").
40 |
# File 'lib/privy/models/wallet_action_earn_withdraw_succeeded_webhook_payload.rb', line 40 required :raw_amount, String |
#share_amount ⇒ String
Vault shares burned in base units.
46 |
# File 'lib/privy/models/wallet_action_earn_withdraw_succeeded_webhook_payload.rb', line 46 required :share_amount, String |
#status ⇒ Symbol, Privy::Models::WalletActionEarnWithdrawSucceededWebhookPayload::Status
The status of the wallet action.
52 |
# File 'lib/privy/models/wallet_action_earn_withdraw_succeeded_webhook_payload.rb', line 52 required :status, enum: -> { Privy::WalletActionEarnWithdrawSucceededWebhookPayload::Status } |
#steps ⇒ Array<Privy::Models::Wallets::EvmTransactionWalletActionStep, Privy::Models::Wallets::EvmUserOperationWalletActionStep, Privy::Models::Wallets::SvmTransactionWalletActionStep, Privy::Models::Wallets::TvmTransactionWalletActionStep, Privy::Models::Wallets::ExternalTransactionWalletActionStep, Privy::Models::Wallets::CustodianTransactionWalletActionStep>
The steps of the wallet action, including transaction hashes.
58 |
# File 'lib/privy/models/wallet_action_earn_withdraw_succeeded_webhook_payload.rb', line 58 required :steps, -> { Privy::Internal::Type::ArrayOf[union: Privy::Wallets::WalletActionStep] } |
#type ⇒ Symbol, Privy::Models::WalletActionEarnWithdrawSucceededWebhookPayload::Type
The type of webhook event.
64 |
# File 'lib/privy/models/wallet_action_earn_withdraw_succeeded_webhook_payload.rb', line 64 required :type, enum: -> { Privy::WalletActionEarnWithdrawSucceededWebhookPayload::Type } |
#vault_address ⇒ String
ERC-4626 vault contract address.
70 |
# File 'lib/privy/models/wallet_action_earn_withdraw_succeeded_webhook_payload.rb', line 70 required :vault_address, String |
#vault_id ⇒ String
The vault ID.
76 |
# File 'lib/privy/models/wallet_action_earn_withdraw_succeeded_webhook_payload.rb', line 76 required :vault_id, String |
#wallet_action_id ⇒ String
The ID of the wallet action.
82 |
# File 'lib/privy/models/wallet_action_earn_withdraw_succeeded_webhook_payload.rb', line 82 required :wallet_action_id, String |
#wallet_id ⇒ String
The ID of the wallet involved in the action.
88 |
# File 'lib/privy/models/wallet_action_earn_withdraw_succeeded_webhook_payload.rb', line 88 required :wallet_id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/privy/models/wallet_action_earn_withdraw_succeeded_webhook_payload.rb', line 160
|
Instance Method Details
#to_hash ⇒ {
85 |
# File 'sig/privy/models/wallet_action_earn_withdraw_succeeded_webhook_payload.rbs', line 85
def to_hash: -> {
|