Class: Privy::Models::WalletActionSwapSucceededWebhookPayload
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::WalletActionSwapSucceededWebhookPayload
- Defined in:
- lib/privy/models/wallet_action_swap_succeeded_webhook_payload.rb,
sig/privy/models/wallet_action_swap_succeeded_webhook_payload.rbs
Defined Under Namespace
Instance Attribute Summary collapse
-
#action_type ⇒ Symbol, Privy::Models::Wallets::WalletActionType
Type of wallet action.
-
#caip2 ⇒ String
Chain identifier.
-
#completed_at ⇒ String
ISO 8601 timestamp of when the wallet action completed successfully.
-
#created_at ⇒ String
ISO 8601 timestamp of when the wallet action was created.
-
#input_amount ⇒ String?
Amount of input token in base units.
-
#input_token ⇒ String
Token address being sold.
-
#output_amount ⇒ String?
Amount of output token received, in base units.
-
#output_token ⇒ String
Token address being bought.
-
#status ⇒ Symbol, Privy::Models::WalletActionSwapSucceededWebhookPayload::Status
The status of the wallet action.
-
#steps ⇒ Array<Privy::Models::Wallets::EvmTransactionWalletActionStep, Privy::Models::Wallets::EvmUserOperationWalletActionStep, Privy::Models::Wallets::SvmTransactionWalletActionStep, Privy::Models::Wallets::TvmTransactionWalletActionStep, Privy::Models::Wallets::ExternalTransactionWalletActionStep, Privy::Models::Wallets::CustodianTransactionWalletActionStep>
The steps of the wallet action, including transaction hashes.
-
#type ⇒ Symbol, Privy::Models::WalletActionSwapSucceededWebhookPayload::Type
The type of webhook event.
-
#wallet_action_id ⇒ String
The ID of the wallet action.
-
#wallet_id ⇒ String
The ID of the wallet involved in the action.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(action_type:, caip2:, completed_at:, created_at:, input_amount:, input_token:, output_amount:, output_token:, status:, steps:, type:, wallet_action_id:, wallet_id:) ⇒ Object
constructor
Some parameter documentations has been truncated, see WalletActionSwapSucceededWebhookPayload for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(action_type:, caip2:, completed_at:, created_at:, input_amount:, input_token:, output_amount:, output_token:, status:, steps:, type:, wallet_action_id:, wallet_id:) ⇒ Object
Some parameter documentations has been truncated, see Privy::Models::WalletActionSwapSucceededWebhookPayload for more details.
Payload for the wallet_action.swap.succeeded webhook event.
|
|
# File 'lib/privy/models/wallet_action_swap_succeeded_webhook_payload.rb', line 85
|
Instance Attribute Details
#action_type ⇒ Symbol, Privy::Models::Wallets::WalletActionType
Type of wallet action
10 |
# File 'lib/privy/models/wallet_action_swap_succeeded_webhook_payload.rb', line 10 required :action_type, enum: -> { Privy::Wallets::WalletActionType } |
#caip2 ⇒ String
Chain identifier.
16 |
# File 'lib/privy/models/wallet_action_swap_succeeded_webhook_payload.rb', line 16 required :caip2, String |
#completed_at ⇒ String
ISO 8601 timestamp of when the wallet action completed successfully.
22 |
# File 'lib/privy/models/wallet_action_swap_succeeded_webhook_payload.rb', line 22 required :completed_at, String |
#created_at ⇒ String
ISO 8601 timestamp of when the wallet action was created.
28 |
# File 'lib/privy/models/wallet_action_swap_succeeded_webhook_payload.rb', line 28 required :created_at, String |
#input_amount ⇒ String?
Amount of input token in base units. Populated after onchain confirmation.
34 |
# File 'lib/privy/models/wallet_action_swap_succeeded_webhook_payload.rb', line 34 required :input_amount, String, nil?: true |
#input_token ⇒ String
Token address being sold.
40 |
# File 'lib/privy/models/wallet_action_swap_succeeded_webhook_payload.rb', line 40 required :input_token, String |
#output_amount ⇒ String?
Amount of output token received, in base units. Populated after onchain confirmation.
47 |
# File 'lib/privy/models/wallet_action_swap_succeeded_webhook_payload.rb', line 47 required :output_amount, String, nil?: true |
#output_token ⇒ String
Token address being bought.
53 |
# File 'lib/privy/models/wallet_action_swap_succeeded_webhook_payload.rb', line 53 required :output_token, String |
#status ⇒ Symbol, Privy::Models::WalletActionSwapSucceededWebhookPayload::Status
The status of the wallet action.
59 |
# File 'lib/privy/models/wallet_action_swap_succeeded_webhook_payload.rb', line 59 required :status, enum: -> { Privy::WalletActionSwapSucceededWebhookPayload::Status } |
#steps ⇒ Array<Privy::Models::Wallets::EvmTransactionWalletActionStep, Privy::Models::Wallets::EvmUserOperationWalletActionStep, Privy::Models::Wallets::SvmTransactionWalletActionStep, Privy::Models::Wallets::TvmTransactionWalletActionStep, Privy::Models::Wallets::ExternalTransactionWalletActionStep, Privy::Models::Wallets::CustodianTransactionWalletActionStep>
The steps of the wallet action, including transaction hashes.
65 |
# File 'lib/privy/models/wallet_action_swap_succeeded_webhook_payload.rb', line 65 required :steps, -> { Privy::Internal::Type::ArrayOf[union: Privy::Wallets::WalletActionStep] } |
#type ⇒ Symbol, Privy::Models::WalletActionSwapSucceededWebhookPayload::Type
The type of webhook event.
71 |
# File 'lib/privy/models/wallet_action_swap_succeeded_webhook_payload.rb', line 71 required :type, enum: -> { Privy::WalletActionSwapSucceededWebhookPayload::Type } |
#wallet_action_id ⇒ String
The ID of the wallet action.
77 |
# File 'lib/privy/models/wallet_action_swap_succeeded_webhook_payload.rb', line 77 required :wallet_action_id, String |
#wallet_id ⇒ String
The ID of the wallet involved in the action.
83 |
# File 'lib/privy/models/wallet_action_swap_succeeded_webhook_payload.rb', line 83 required :wallet_id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/privy/models/wallet_action_swap_succeeded_webhook_payload.rb', line 125
|
Instance Method Details
#to_hash ⇒ {
63 |
# File 'sig/privy/models/wallet_action_swap_succeeded_webhook_payload.rbs', line 63
def to_hash: -> {
|