Class: Privy::Models::WalletAuthenticateBoundEncryptedRequestBody
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::WalletAuthenticateBoundEncryptedRequestBody
- Defined in:
- lib/privy/models/wallet_authenticate_bound_encrypted_request_body.rb,
sig/privy/models/wallet_authenticate_bound_encrypted_request_body.rbs
Defined Under Namespace
Modules: EncryptionType
Instance Attribute Summary collapse
-
#bindings ⇒ Array<Privy::Models::UserSigningKeyBinding>
Bindings that scope the USK.
- #encryption_type ⇒ Symbol, Privy::Models::WalletAuthenticateBoundEncryptedRequestBody::EncryptionType
- #recipient_public_key ⇒ String
- #user_jwt ⇒ String
Instance Method Summary collapse
-
#initialize(bindings:, encryption_type:, recipient_public_key:, user_jwt:) ⇒ Object
constructor
Request body for creating an encrypted, bound user signing key.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(bindings:, encryption_type:, recipient_public_key:, user_jwt:) ⇒ Object
Request body for creating an encrypted, bound user signing key.
|
|
# File 'lib/privy/models/wallet_authenticate_bound_encrypted_request_body.rb', line 27
|
Instance Attribute Details
#bindings ⇒ Array<Privy::Models::UserSigningKeyBinding>
Bindings that scope the USK. The key can only authorize the bound values.
10 |
# File 'lib/privy/models/wallet_authenticate_bound_encrypted_request_body.rb', line 10 required :bindings, -> { Privy::Internal::Type::ArrayOf[Privy::UserSigningKeyBinding] } |
#encryption_type ⇒ Symbol, Privy::Models::WalletAuthenticateBoundEncryptedRequestBody::EncryptionType
15 |
# File 'lib/privy/models/wallet_authenticate_bound_encrypted_request_body.rb', line 15 required :encryption_type, enum: -> { Privy::WalletAuthenticateBoundEncryptedRequestBody::EncryptionType } |
#recipient_public_key ⇒ String
20 |
# File 'lib/privy/models/wallet_authenticate_bound_encrypted_request_body.rb', line 20 required :recipient_public_key, String |
#user_jwt ⇒ String
25 |
# File 'lib/privy/models/wallet_authenticate_bound_encrypted_request_body.rb', line 25 required :user_jwt, String |
Instance Method Details
#to_hash ⇒ {
27 |
# File 'sig/privy/models/wallet_authenticate_bound_encrypted_request_body.rbs', line 27
def to_hash: -> {
|