Module: Privy::Models::WalletAuthenticateIntentsResponse
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/privy/models/wallet_authenticate_intents_response.rb,
sig/privy/models/wallet_authenticate_intents_response.rbs
Overview
The response from authenticating a wallet with intent bindings, containing an authorization key, wallet data, and the bindings the key is scoped to.
Class Method Summary collapse
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.variants ⇒ Array(Privy::Models::EncryptedBoundAuthenticateResponse, Privy::Models::RawBoundAuthenticateResponse)
|
|
# File 'lib/privy/models/wallet_authenticate_intents_response.rb', line 16
|
Instance Method Details
#self?.variants ⇒ ::Array[Privy::Models::wallet_authenticate_intents_response]
10 |
# File 'sig/privy/models/wallet_authenticate_intents_response.rbs', line 10
def self?.variants: -> ::Array[Privy::Models::wallet_authenticate_intents_response]
|