Class: Privy::Models::WalletAuthenticateRequestBody
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::WalletAuthenticateRequestBody
- Defined in:
- lib/privy/models/wallet_authenticate_request_body.rb
Direct Known Subclasses
Defined Under Namespace
Modules: EncryptionType
Instance Attribute Summary collapse
-
#encryption_type ⇒ Symbol, Privy::Models::WalletAuthenticateRequestBody::EncryptionType
The encryption type for the authentication response.
-
#recipient_public_key ⇒ String
The public key of your ECDH keypair, in base64-encoded, SPKI-format, whose private key will be able to decrypt the session key.
-
#user_jwt ⇒ String
The user’s JWT, to be used to authenticate the user.
Instance Method Summary collapse
-
#initialize(encryption_type:, recipient_public_key:, user_jwt:) ⇒ Object
constructor
Some parameter documentations has been truncated, see WalletAuthenticateRequestBody for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(encryption_type:, recipient_public_key:, user_jwt:) ⇒ Object
Some parameter documentations has been truncated, see Privy::Models::WalletAuthenticateRequestBody for more details.
Request body for wallet authentication with HPKE-encrypted response.
|
|
# File 'lib/privy/models/wallet_authenticate_request_body.rb', line 26
|
Instance Attribute Details
#encryption_type ⇒ Symbol, Privy::Models::WalletAuthenticateRequestBody::EncryptionType
The encryption type for the authentication response. Currently only supports HPKE.
11 |
# File 'lib/privy/models/wallet_authenticate_request_body.rb', line 11 required :encryption_type, enum: -> { Privy::WalletAuthenticateRequestBody::EncryptionType } |
#recipient_public_key ⇒ String
The public key of your ECDH keypair, in base64-encoded, SPKI-format, whose private key will be able to decrypt the session key.
18 |
# File 'lib/privy/models/wallet_authenticate_request_body.rb', line 18 required :recipient_public_key, String |
#user_jwt ⇒ String
The user’s JWT, to be used to authenticate the user.
24 |
# File 'lib/privy/models/wallet_authenticate_request_body.rb', line 24 required :user_jwt, String |