Class: Privy::Models::WalletAuthenticateWithJwtResponse::WithoutEncryption
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::WalletAuthenticateWithJwtResponse::WithoutEncryption
- Defined in:
- lib/privy/models/wallet_authenticate_with_jwt_response.rb
Instance Attribute Summary collapse
-
#authorization_key ⇒ String
The raw authorization key data.
-
#expires_at ⇒ Float
The expiration time of the authorization key in milliseconds since the epoch.
- #wallets ⇒ Array<Privy::Models::Wallet>
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(authorization_key:, expires_at:, wallets:) ⇒ Object
|
|
# File 'lib/privy/models/wallet_authenticate_with_jwt_response.rb', line 110
|
Instance Attribute Details
#authorization_key ⇒ String
The raw authorization key data.
97 |
# File 'lib/privy/models/wallet_authenticate_with_jwt_response.rb', line 97 required :authorization_key, String |
#expires_at ⇒ Float
The expiration time of the authorization key in milliseconds since the epoch.
103 |
# File 'lib/privy/models/wallet_authenticate_with_jwt_response.rb', line 103 required :expires_at, Float |