Class: Privy::Models::WalletAuthorizationHeaders

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/privy/models/wallet_authorization_headers.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(privy_app_id:, privy_authorization_signature: nil, privy_request_expiry: nil) ⇒ Object

Some parameter documentations has been truncated, see Privy::Models::WalletAuthorizationHeaders for more details.

Headers required to authorize wallet operations.

Parameters:

  • privy_app_id (String)

    ID of your Privy app.

  • privy_authorization_signature (String) (defaults to: nil)

    Request authorization signature. If multiple signatures are required, they shoul

  • privy_request_expiry (String) (defaults to: nil)

    Request expiry. Value is a Unix timestamp in milliseconds representing the deadl



# File 'lib/privy/models/wallet_authorization_headers.rb', line 26

Instance Attribute Details

#privy_app_idString

ID of your Privy app.

Returns:

  • (String)


10
# File 'lib/privy/models/wallet_authorization_headers.rb', line 10

required :privy_app_id, String, api_name: :"privy-app-id"

#privy_authorization_signatureString?

Request authorization signature. If multiple signatures are required, they should be comma separated.

Returns:

  • (String, nil)


17
# File 'lib/privy/models/wallet_authorization_headers.rb', line 17

optional :privy_authorization_signature, String, api_name: :"privy-authorization-signature"

#privy_request_expiryString?

Request expiry. Value is a Unix timestamp in milliseconds representing the deadline by which the request must be processed.

Returns:

  • (String, nil)


24
# File 'lib/privy/models/wallet_authorization_headers.rb', line 24

optional :privy_request_expiry, String, api_name: :"privy-request-expiry"