Class: Privy::Models::WalletBatchCreateResult::WalletBatchCreateFailure

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/privy/models/wallet_batch_create_result.rb

Defined Under Namespace

Modules: Success

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(code:, error:, index:, success:) ⇒ Object

Some parameter documentations has been truncated, see Privy::Models::WalletBatchCreateResult::WalletBatchCreateFailure for more details.

A failed wallet creation result within a batch operation.

Parameters:



# File 'lib/privy/models/wallet_batch_create_result.rb', line 78

Instance Attribute Details

#codeString

A PrivyErrorCode string identifying the error type (e.g., “invalid_data”, “resource_conflict”).

Returns:

  • (String)


59
# File 'lib/privy/models/wallet_batch_create_result.rb', line 59

required :code, String

#errorString

A human-readable error message with details about what went wrong.

Returns:

  • (String)


65
# File 'lib/privy/models/wallet_batch_create_result.rb', line 65

required :error, String

#indexFloat

The index of the wallet in the original request array.

Returns:

  • (Float)


71
# File 'lib/privy/models/wallet_batch_create_result.rb', line 71

required :index, Float

#successBoolean, Privy::Models::WalletBatchCreateResult::WalletBatchCreateFailure::Success



76
# File 'lib/privy/models/wallet_batch_create_result.rb', line 76

required :success, enum: -> { Privy::WalletBatchCreateResult::WalletBatchCreateFailure::Success }