Class: Privy::Models::WalletBatchItemInput

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/privy/models/wallet_batch_item_input.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(chain_type:, additional_signers: nil, display_name: nil, external_id: nil, owner: nil, owner_id: nil, policy_ids: nil) ⇒ Object

Some parameter documentations has been truncated, see Privy::Models::WalletBatchItemInput for more details.

Input for a single wallet in a batch creation request.

Parameters:

  • chain_type (Symbol, Privy::Models::WalletChainType)

    The wallet chain types.

  • additional_signers (Array<Privy::Models::AdditionalSignerItemInput>) (defaults to: nil)

    Additional signers for the wallet.

  • display_name (String) (defaults to: nil)

    A human-readable label for the wallet.

  • external_id (String) (defaults to: nil)

    A customer-provided identifier for mapping to external systems. URL-safe charact

  • owner (Privy::Models::OwnerInputUser, Privy::Models::OwnerInputPublicKey, nil) (defaults to: nil)

    The owner of the resource, specified as a Privy user ID, a P-256 public key, or

  • owner_id (String, nil) (defaults to: nil)

    The key quorum ID to set as the owner of the resource. If you provide this, do n

  • policy_ids (Array<String>) (defaults to: nil)

    List of policy IDs for policies that should be enforced on the wallet. Currently



# File 'lib/privy/models/wallet_batch_item_input.rb', line 53

Instance Attribute Details

#additional_signersArray<Privy::Models::AdditionalSignerItemInput>?

Additional signers for the wallet.



16
# File 'lib/privy/models/wallet_batch_item_input.rb', line 16

optional :additional_signers, -> { Privy::Internal::Type::ArrayOf[Privy::AdditionalSignerItemInput] }

#chain_typeSymbol, Privy::Models::WalletChainType

The wallet chain types.

Returns:



10
# File 'lib/privy/models/wallet_batch_item_input.rb', line 10

required :chain_type, enum: -> { Privy::WalletChainType }

#display_nameString?

A human-readable label for the wallet.

Returns:

  • (String, nil)


22
# File 'lib/privy/models/wallet_batch_item_input.rb', line 22

optional :display_name, String

#external_idString?

A customer-provided identifier for mapping to external systems. URL-safe characters only ([a-zA-Z0-9_-]), max 64 chars. Write-once: cannot be changed after creation.

Returns:

  • (String, nil)


30
# File 'lib/privy/models/wallet_batch_item_input.rb', line 30

optional :external_id, String

#ownerPrivy::Models::OwnerInputUser, ...

The owner of the resource, specified as a Privy user ID, a P-256 public key, or null to remove the current owner.



37
# File 'lib/privy/models/wallet_batch_item_input.rb', line 37

optional :owner, union: -> { Privy::OwnerInput }, nil?: true

#owner_idString?

The key quorum ID to set as the owner of the resource. If you provide this, do not specify an owner.

Returns:

  • (String, nil)


44
# File 'lib/privy/models/wallet_batch_item_input.rb', line 44

optional :owner_id, String, nil?: true

#policy_idsArray<String>?

List of policy IDs for policies that should be enforced on the wallet. Currently, only one policy is supported per wallet.

Returns:

  • (Array<String>, nil)


51
# File 'lib/privy/models/wallet_batch_item_input.rb', line 51

optional :policy_ids, Privy::Internal::Type::ArrayOf[String]