Class: Privy::Models::WalletCreateWalletsWithRecoveryParams::Wallet

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/privy/models/wallet_create_wallets_with_recovery_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(chain_type:, display_name: nil, external_id: nil, policy_ids: nil) ⇒ Object

Some parameter documentations has been truncated, see Privy::Models::WalletCreateWalletsWithRecoveryParams::Wallet for more details.

Parameters:

  • chain_type (Symbol, Privy::Models::WalletChainType)

    The wallet chain types.

  • display_name (String) (defaults to: nil)

    A human-readable label for the wallet.

  • external_id (String) (defaults to: nil)

    A customer-provided identifier for mapping to external systems. URL-safe charact

  • policy_ids (Array<String>) (defaults to: nil)

    An optional list of up to one policy ID to enforce on the wallet.



# File 'lib/privy/models/wallet_create_wallets_with_recovery_params.rb', line 97

Instance Attribute Details

#chain_typeSymbol, Privy::Models::WalletChainType

The wallet chain types.

Returns:



75
# File 'lib/privy/models/wallet_create_wallets_with_recovery_params.rb', line 75

required :chain_type, enum: -> { Privy::WalletChainType }

#display_nameString?

A human-readable label for the wallet.

Returns:

  • (String, nil)


81
# File 'lib/privy/models/wallet_create_wallets_with_recovery_params.rb', line 81

optional :display_name, String

#external_idString?

A customer-provided identifier for mapping to external systems. URL-safe characters only ([a-zA-Z0-9_-]), max 64 chars. Write-once: cannot be changed after creation.

Returns:

  • (String, nil)


89
# File 'lib/privy/models/wallet_create_wallets_with_recovery_params.rb', line 89

optional :external_id, String

#policy_idsArray<String>?

An optional list of up to one policy ID to enforce on the wallet.

Returns:

  • (Array<String>, nil)


95
# File 'lib/privy/models/wallet_create_wallets_with_recovery_params.rb', line 95

optional :policy_ids, Privy::Internal::Type::ArrayOf[String]