Class: Privy::Models::WalletCreationInput

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/privy/models/wallet_creation_input.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(chain_type:, additional_signers: nil, create_smart_wallet: nil, policy_ids: nil) ⇒ Object

Some parameter documentations has been truncated, see Privy::Models::WalletCreationInput for more details.

The fields on wallet creation that can be specified when creating a user-controlled embedded server wallet.

Parameters:

  • chain_type (Symbol, Privy::Models::WalletChainType)

    The wallet chain types.

  • additional_signers (Array<Privy::Models::WalletCreationAdditionalSignerItem>) (defaults to: nil)

    Additional signers for the wallet.

  • create_smart_wallet (Boolean) (defaults to: nil)

    Create a smart wallet with this wallet as the signer. Only supported for wallets

  • policy_ids (Array<String>) (defaults to: nil)

    Policy IDs to enforce on the wallet. Currently, only one policy is supported per



# File 'lib/privy/models/wallet_creation_input.rb', line 33

Instance Attribute Details

#additional_signersArray<Privy::Models::WalletCreationAdditionalSignerItem>?

Additional signers for the wallet.



16
17
# File 'lib/privy/models/wallet_creation_input.rb', line 16

optional :additional_signers,
-> { Privy::Internal::Type::ArrayOf[Privy::WalletCreationAdditionalSignerItem] }

#chain_typeSymbol, Privy::Models::WalletChainType

The wallet chain types.

Returns:



10
# File 'lib/privy/models/wallet_creation_input.rb', line 10

required :chain_type, enum: -> { Privy::WalletChainType }

#create_smart_walletBoolean?

Create a smart wallet with this wallet as the signer. Only supported for wallets with ‘chain_type: “ethereum”`.

Returns:

  • (Boolean, nil)


24
# File 'lib/privy/models/wallet_creation_input.rb', line 24

optional :create_smart_wallet, Privy::Internal::Type::Boolean

#policy_idsArray<String>?

Policy IDs to enforce on the wallet. Currently, only one policy is supported per wallet.

Returns:

  • (Array<String>, nil)


31
# File 'lib/privy/models/wallet_creation_input.rb', line 31

optional :policy_ids, Privy::Internal::Type::ArrayOf[String]