Class: Privy::Models::WalletExportRequestBody

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/privy/models/wallet_export_request_body.rb

Direct Known Subclasses

WalletExportParams

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(encryption_type:, recipient_public_key:, export_seed_phrase: nil) ⇒ Object

Some parameter documentations has been truncated, see Privy::Models::WalletExportRequestBody for more details.

Request body for exporting a wallet private key.

Parameters:

  • encryption_type (Symbol, Privy::Models::HpkeEncryption)

    The encryption type of the wallet to import. Currently only supports ‘HPKE`.

  • recipient_public_key (String)

    The base64-encoded encryption public key to encrypt the wallet private key with.

  • export_seed_phrase (Boolean) (defaults to: nil)


# File 'lib/privy/models/wallet_export_request_body.rb', line 23

Instance Attribute Details

#encryption_typeSymbol, Privy::Models::HpkeEncryption

The encryption type of the wallet to import. Currently only supports ‘HPKE`.

Returns:



10
# File 'lib/privy/models/wallet_export_request_body.rb', line 10

required :encryption_type, enum: -> { Privy::HpkeEncryption }

#export_seed_phraseBoolean?

Returns:

  • (Boolean, nil)


21
# File 'lib/privy/models/wallet_export_request_body.rb', line 21

optional :export_seed_phrase, Privy::Internal::Type::Boolean

#recipient_public_keyString

The base64-encoded encryption public key to encrypt the wallet private key with.

Returns:

  • (String)


16
# File 'lib/privy/models/wallet_export_request_body.rb', line 16

required :recipient_public_key, String