Class: Privy::Models::WalletExportResponseBody

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/privy/models/wallet_export_response_body.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(ciphertext:, encapsulated_key:, encryption_type:) ⇒ Object

Some parameter documentations has been truncated, see Privy::Models::WalletExportResponseBody for more details.

Response body containing the encrypted wallet private key.

Parameters:

  • ciphertext (String)

    The encrypted private key.

  • encapsulated_key (String)

    The base64-encoded encapsulated key that was generated during encryption, for us

  • encryption_type (Symbol, Privy::Models::HpkeEncryption)

    The encryption type of the wallet to import. Currently only supports ‘HPKE`.



# File 'lib/privy/models/wallet_export_response_body.rb', line 26

Instance Attribute Details

#ciphertextString

The encrypted private key.

Returns:

  • (String)


11
# File 'lib/privy/models/wallet_export_response_body.rb', line 11

required :ciphertext, String

#encapsulated_keyString

The base64-encoded encapsulated key that was generated during encryption, for use during decryption.

Returns:

  • (String)


18
# File 'lib/privy/models/wallet_export_response_body.rb', line 18

required :encapsulated_key, String

#encryption_typeSymbol, Privy::Models::HpkeEncryption

The encryption type of the wallet to import. Currently only supports ‘HPKE`.

Returns:



24
# File 'lib/privy/models/wallet_export_response_body.rb', line 24

required :encryption_type, enum: -> { Privy::HpkeEncryption }