Class: Privy::Models::WalletImportInitResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::WalletImportInitResponse
- Defined in:
- lib/privy/models/wallet_import_init_response.rb
Instance Attribute Summary collapse
- #encryption_public_key ⇒ String
-
#encryption_type ⇒ Symbol, Privy::Models::HpkeEncryption
The encryption type of the wallet to import.
- #import_id ⇒ String?
Instance Method Summary collapse
-
#initialize(encryption_public_key:, encryption_type:, import_id: nil) ⇒ Object
constructor
Response from initializing a wallet import, containing the encryption public key.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(encryption_public_key:, encryption_type:, import_id: nil) ⇒ Object
Response from initializing a wallet import, containing the encryption public key.
|
|
# File 'lib/privy/models/wallet_import_init_response.rb', line 22
|
Instance Attribute Details
#encryption_public_key ⇒ String
9 |
# File 'lib/privy/models/wallet_import_init_response.rb', line 9 required :encryption_public_key, String |
#encryption_type ⇒ Symbol, Privy::Models::HpkeEncryption
The encryption type of the wallet to import. Currently only supports ‘HPKE`.
15 |
# File 'lib/privy/models/wallet_import_init_response.rb', line 15 required :encryption_type, enum: -> { Privy::HpkeEncryption } |
#import_id ⇒ String?
20 |
# File 'lib/privy/models/wallet_import_init_response.rb', line 20 optional :import_id, String |