Class: Privy::Models::WalletInitImportResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/privy/models/wallet_init_import_response.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(encryption_public_key:, encryption_type:) ⇒ Object

Parameters:

  • encryption_public_key (String)

    The base64-encoded encryption public key to encrypt the wallet entropy with.

  • encryption_type (Symbol, Privy::Models::HpkeEncryption)

    The encryption type of the wallet to import. Currently only supports ‘HPKE`.



# File 'lib/privy/models/wallet_init_import_response.rb', line 19

Instance Attribute Details

#encryption_public_keyString

The base64-encoded encryption public key to encrypt the wallet entropy with.

Returns:

  • (String)


11
# File 'lib/privy/models/wallet_init_import_response.rb', line 11

required :encryption_public_key, String

#encryption_typeSymbol, Privy::Models::HpkeEncryption

The encryption type of the wallet to import. Currently only supports ‘HPKE`.

Returns:



17
# File 'lib/privy/models/wallet_init_import_response.rb', line 17

required :encryption_type, enum: -> { Privy::HpkeEncryption }