Class: Privy::Models::WalletIntentResponse::RequestDetails
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::WalletIntentResponse::RequestDetails
- Defined in:
- lib/privy/models/wallet_intent_response.rb
Defined Under Namespace
Instance Attribute Summary collapse
- #body ⇒ Privy::Models::WalletIntentResponse::RequestDetails::Body
- #method_ ⇒ Symbol, Privy::Models::WalletIntentResponse::RequestDetails::Method
- #url ⇒ String
Instance Method Summary collapse
-
#initialize(additional_signers: nil, authorization_key_ids: nil, authorization_threshold: nil, display_name: nil, owner: nil, owner_id: nil, policy_ids: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Body for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(additional_signers: nil, authorization_key_ids: nil, authorization_threshold: nil, display_name: nil, owner: nil, owner_id: nil, policy_ids: nil) ⇒ Object
Some parameter documentations has been truncated, see Body for more details.
|
|
# File 'lib/privy/models/wallet_intent_response.rb', line 70
|
Instance Attribute Details
#body ⇒ Privy::Models::WalletIntentResponse::RequestDetails::Body
58 |
# File 'lib/privy/models/wallet_intent_response.rb', line 58 required :body, -> { Privy::WalletIntentResponse::RequestDetails::Body } |
#method_ ⇒ Symbol, Privy::Models::WalletIntentResponse::RequestDetails::Method
63 |
# File 'lib/privy/models/wallet_intent_response.rb', line 63 required :method_, enum: -> { Privy::WalletIntentResponse::RequestDetails::Method }, api_name: :method |
#url ⇒ String
68 |
# File 'lib/privy/models/wallet_intent_response.rb', line 68 required :url, String |