Class: Privy::Models::WalletIntentResponse::RequestDetails::Body

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/privy/models/wallet_intent_response.rb

Overview

See Also:

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Privy::Internal::Type::BaseModel

Instance Attribute Details

#additional_signersArray<Privy::Models::AdditionalSignerItemInput>?

Additional signers for the wallet.



83
# File 'lib/privy/models/wallet_intent_response.rb', line 83

optional :additional_signers, -> { Privy::Internal::Type::ArrayOf[Privy::AdditionalSignerItemInput] }

#authorization_key_idsArray<String>?

Returns:

  • (Array<String>, nil)


88
# File 'lib/privy/models/wallet_intent_response.rb', line 88

optional :authorization_key_ids, Privy::Internal::Type::ArrayOf[String]

#authorization_thresholdFloat?

Returns:

  • (Float, nil)


93
# File 'lib/privy/models/wallet_intent_response.rb', line 93

optional :authorization_threshold, Float

#display_nameString?

Returns:

  • (String, nil)


98
# File 'lib/privy/models/wallet_intent_response.rb', line 98

optional :display_name, String, nil?: true

#ownerPrivy::Models::OwnerInputUser, ...

The owner of the resource, specified as a Privy user ID, a P-256 public key, or null to remove the current owner.



105
# File 'lib/privy/models/wallet_intent_response.rb', line 105

optional :owner, union: -> { Privy::OwnerInput }, nil?: true

#owner_idString?

The key quorum ID to set as the owner of the resource. If you provide this, do not specify an owner.

Returns:

  • (String, nil)


112
# File 'lib/privy/models/wallet_intent_response.rb', line 112

optional :owner_id, String, nil?: true

#policy_idsArray<String>?

An optional list of up to one policy ID to enforce on the wallet.

Returns:

  • (Array<String>, nil)


118
# File 'lib/privy/models/wallet_intent_response.rb', line 118

optional :policy_ids, Privy::Internal::Type::ArrayOf[String]