Class: Privy::Models::WalletSubmitImportParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/privy/models/wallet_submit_import_params.rb

Overview

Defined Under Namespace

Modules: Wallet

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(wallet:, additional_signers: nil, display_name: nil, external_id: nil, owner: nil, owner_id: nil, policy_ids: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Privy::Models::WalletSubmitImportParams for more details.

Parameters:

  • wallet (Privy::Models::HDSubmitInput, Privy::Models::PrivateKeySubmitInput)

    The submission input for importing an HD wallet.

  • additional_signers (Array<Privy::Models::AdditionalSignerItemInput>) (defaults to: nil)

    Additional signers for the wallet.

  • display_name (String) (defaults to: nil)

    A human-readable label for the wallet.

  • external_id (String) (defaults to: nil)

    A customer-provided identifier for mapping to external systems. URL-safe charact

  • owner (Privy::Models::OwnerInputUser, Privy::Models::OwnerInputPublicKey, nil) (defaults to: nil)

    The owner of the resource, specified as a Privy user ID, a P-256 public key, or

  • owner_id (String, nil) (defaults to: nil)

    The key quorum ID to set as the owner of the resource. If you provide this, do n

  • policy_ids (Array<String>) (defaults to: nil)

    An optional list of up to one policy ID to enforce on the wallet.

  • request_options (Privy::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/privy/models/wallet_submit_import_params.rb', line 56

Instance Attribute Details

#additional_signersArray<Privy::Models::AdditionalSignerItemInput>?

Additional signers for the wallet.



20
# File 'lib/privy/models/wallet_submit_import_params.rb', line 20

optional :additional_signers, -> { Privy::Internal::Type::ArrayOf[Privy::AdditionalSignerItemInput] }

#display_nameString?

A human-readable label for the wallet.

Returns:

  • (String, nil)


26
# File 'lib/privy/models/wallet_submit_import_params.rb', line 26

optional :display_name, String

#external_idString?

A customer-provided identifier for mapping to external systems. URL-safe characters only ([a-zA-Z0-9_-]), max 64 chars. Write-once: cannot be changed after creation.

Returns:

  • (String, nil)


34
# File 'lib/privy/models/wallet_submit_import_params.rb', line 34

optional :external_id, String

#ownerPrivy::Models::OwnerInputUser, ...

The owner of the resource, specified as a Privy user ID, a P-256 public key, or null to remove the current owner.



41
# File 'lib/privy/models/wallet_submit_import_params.rb', line 41

optional :owner, union: -> { Privy::OwnerInput }, nil?: true

#owner_idString?

The key quorum ID to set as the owner of the resource. If you provide this, do not specify an owner.

Returns:

  • (String, nil)


48
# File 'lib/privy/models/wallet_submit_import_params.rb', line 48

optional :owner_id, String, nil?: true

#policy_idsArray<String>?

An optional list of up to one policy ID to enforce on the wallet.

Returns:

  • (Array<String>, nil)


54
# File 'lib/privy/models/wallet_submit_import_params.rb', line 54

optional :policy_ids, Privy::Internal::Type::ArrayOf[String]

#walletPrivy::Models::HDSubmitInput, Privy::Models::PrivateKeySubmitInput

The submission input for importing an HD wallet.



14
# File 'lib/privy/models/wallet_submit_import_params.rb', line 14

required :wallet, union: -> { Privy::WalletSubmitImportParams::Wallet }