Class: Privy::Models::Wallets::CustodianTransactionWalletActionStep

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/privy/models/wallets/custodian_transaction_wallet_action_step.rb,
sig/privy/models/wallets/custodian_transaction_wallet_action_step.rbs

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(custodian:, status:, type:, failure_reason: nil) ⇒ Object

A wallet action step representing a transaction executed by a custodian (e.g. Bridge).

Parameters:



# File 'lib/privy/models/wallets/custodian_transaction_wallet_action_step.rb', line 30

Instance Attribute Details

#custodianString

Identifier of the custodian executing this transaction (e.g. "bridge").

Parameters:

  • value (String)

Returns:

  • (String)


11
# File 'lib/privy/models/wallets/custodian_transaction_wallet_action_step.rb', line 11

required :custodian, String

#failure_reasonPrivy::Models::Wallets::FailureReason?

A description of why a wallet action (or a step within a wallet action) failed.



28
# File 'lib/privy/models/wallets/custodian_transaction_wallet_action_step.rb', line 28

optional :failure_reason, -> { Privy::Wallets::FailureReason }

#statusSymbol, Privy::Models::Wallets::CustodianTransactionWalletActionStepStatus

Status of a custodian transaction step in a wallet action.

Parameters:

  • value (Privy::Models::Wallets::custodian_transaction_wallet_action_step_status)

Returns:



17
# File 'lib/privy/models/wallets/custodian_transaction_wallet_action_step.rb', line 17

required :status, enum: -> { Privy::Wallets::CustodianTransactionWalletActionStepStatus }

#typeSymbol, Privy::Models::Wallets::CustodianTransactionWalletActionStep::Type

Parameters:

  • value (Privy::Models::Wallets::CustodianTransactionWalletActionStep::type_)

Returns:



22
# File 'lib/privy/models/wallets/custodian_transaction_wallet_action_step.rb', line 22

required :type, enum: -> { Privy::Wallets::CustodianTransactionWalletActionStep::Type }

Instance Method Details

#to_hash{

Returns:

  • ({)


32
# File 'sig/privy/models/wallets/custodian_transaction_wallet_action_step.rbs', line 32

def to_hash: -> {