Class: Privy::Models::Wallets::EarnFeeCollectRequestBody
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::Wallets::EarnFeeCollectRequestBody
- Defined in:
- lib/privy/models/wallets/earn_fee_collect_request_body.rb,
sig/privy/models/wallets/earn_fee_collect_request_body.rbs
Instance Attribute Summary collapse
-
#vault_id ⇒ String
The ID of the vault to collect fees from.
Instance Method Summary collapse
-
#initialize(vault_id:) ⇒ EarnFeeCollectRequestBody
constructor
Input for collecting accumulated fees from an Aave vault.
- #to_hash ⇒ { vault_id: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(vault_id:) ⇒ EarnFeeCollectRequestBody
Input for collecting accumulated fees from an Aave vault.
|
|
# File 'lib/privy/models/wallets/earn_fee_collect_request_body.rb', line 13
|
Instance Attribute Details
#vault_id ⇒ String
The ID of the vault to collect fees from.
11 |
# File 'lib/privy/models/wallets/earn_fee_collect_request_body.rb', line 11 required :vault_id, String |
Instance Method Details
#to_hash ⇒ { vault_id: String }
11 |
# File 'sig/privy/models/wallets/earn_fee_collect_request_body.rbs', line 11
def to_hash: -> { vault_id: String }
|