Class: Privy::Models::Wallets::EarnIncentiveRewardsResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::Wallets::EarnIncentiveRewardsResponse
- Defined in:
- lib/privy/models/wallets/earn_incentive_rewards_response.rb,
sig/privy/models/wallets/earn_incentive_rewards_response.rbs
Instance Attribute Summary collapse
-
#rewards ⇒ Array<Privy::Models::Wallets::EarnIncentiveRewardEntry>
Reward tokens with their claimed and unclaimed amounts.
Instance Method Summary collapse
-
#initialize(rewards:) ⇒ Object
constructor
All incentive rewards for a wallet, with claimed and unclaimed amounts per token.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(rewards:) ⇒ Object
All incentive rewards for a wallet, with claimed and unclaimed amounts per token.
|
|
# File 'lib/privy/models/wallets/earn_incentive_rewards_response.rb', line 13
|
Instance Attribute Details
#rewards ⇒ Array<Privy::Models::Wallets::EarnIncentiveRewardEntry>
Reward tokens with their claimed and unclaimed amounts.
11 |
# File 'lib/privy/models/wallets/earn_incentive_rewards_response.rb', line 11 required :rewards, -> { Privy::Internal::Type::ArrayOf[Privy::Wallets::EarnIncentiveRewardEntry] } |
Instance Method Details
#to_hash ⇒ {
14 |
# File 'sig/privy/models/wallets/earn_incentive_rewards_response.rbs', line 14
def to_hash: -> {
|