Class: Privy::Models::Wallets::EvmTransactionWalletActionStep
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::Wallets::EvmTransactionWalletActionStep
- Defined in:
- lib/privy/models/wallets/evm_transaction_wallet_action_step.rb,
sig/privy/models/wallets/evm_transaction_wallet_action_step.rbs
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#caip2 ⇒ String
CAIP-2 chain identifier of the transaction, containing the chain ID.
-
#failure_reason ⇒ Privy::Models::Wallets::FailureReason?
A description of why a wallet action (or a step within a wallet action) failed.
-
#finalized ⇒ Boolean?
Whether this step has reached on-chain finality.
-
#status ⇒ Symbol, Privy::Models::Wallets::EvmWalletActionStepStatus
Status of an EVM step in a wallet action.
-
#transaction_hash ⇒ String?
The transaction hash for this step.
- #type ⇒ Symbol, Privy::Models::Wallets::EvmTransactionWalletActionStep::Type
Instance Method Summary collapse
-
#initialize(caip2:, status:, transaction_hash:, type:, failure_reason: nil, finalized: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see EvmTransactionWalletActionStep for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(caip2:, status:, transaction_hash:, type:, failure_reason: nil, finalized: nil) ⇒ Object
Some parameter documentations has been truncated, see Privy::Models::Wallets::EvmTransactionWalletActionStep for more details.
A wallet action step consisting of an EVM transaction.
|
|
# File 'lib/privy/models/wallets/evm_transaction_wallet_action_step.rb', line 44
|
Instance Attribute Details
#caip2 ⇒ String
CAIP-2 chain identifier of the transaction, containing the chain ID.
11 |
# File 'lib/privy/models/wallets/evm_transaction_wallet_action_step.rb', line 11 required :caip2, String |
#failure_reason ⇒ Privy::Models::Wallets::FailureReason?
A description of why a wallet action (or a step within a wallet action) failed.
35 |
# File 'lib/privy/models/wallets/evm_transaction_wallet_action_step.rb', line 35 optional :failure_reason, -> { Privy::Wallets::FailureReason } |
#finalized ⇒ Boolean?
Whether this step has reached on-chain finality. Absent until finality is confirmed.
42 |
# File 'lib/privy/models/wallets/evm_transaction_wallet_action_step.rb', line 42 optional :finalized, Privy::Internal::Type::Boolean |
#status ⇒ Symbol, Privy::Models::Wallets::EvmWalletActionStepStatus
Status of an EVM step in a wallet action.
17 |
# File 'lib/privy/models/wallets/evm_transaction_wallet_action_step.rb', line 17 required :status, enum: -> { Privy::Wallets::EvmWalletActionStepStatus } |
#transaction_hash ⇒ String?
The transaction hash for this step. May change while the step status is non-terminal.
24 |
# File 'lib/privy/models/wallets/evm_transaction_wallet_action_step.rb', line 24 required :transaction_hash, String, nil?: true |
#type ⇒ Symbol, Privy::Models::Wallets::EvmTransactionWalletActionStep::Type
29 |
# File 'lib/privy/models/wallets/evm_transaction_wallet_action_step.rb', line 29 required :type, enum: -> { Privy::Wallets::EvmTransactionWalletActionStep::Type } |
Instance Method Details
#to_hash ⇒ {
42 |
# File 'sig/privy/models/wallets/evm_transaction_wallet_action_step.rbs', line 42
def to_hash: -> {
|