Class: Privy::Models::Wallets::MorphoVaultDetails
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::Wallets::MorphoVaultDetails
- Defined in:
- lib/privy/models/wallets/morpho_vault_details.rb,
sig/privy/models/wallets/morpho_vault_details.rbs
Defined Under Namespace
Modules: Provider
Instance Attribute Summary collapse
-
#admin_wallet_address ⇒ String
EVM address of the vault admin wallet.
-
#admin_wallet_id ⇒ String
Privy wallet ID of the vault admin.
-
#app_apy ⇒ Float?
Annual percentage yield earned by the app from fee wrapper fees, in basis points.
-
#asset ⇒ Privy::Models::Wallets::EarnAsset
Asset metadata for an earn vault position.
-
#available_liquidity_usd ⇒ Float?
Available liquidity in USD.
-
#caip2 ⇒ String
CAIP-2 chain identifier (e.g. "eip155:8453").
-
#id ⇒ String
Vault identifier.
-
#name ⇒ String
Human-readable vault name from the yield provider.
- #provider ⇒ Symbol, Privy::Models::Wallets::MorphoVaultDetails::Provider
-
#total_rewards_apr ⇒ Float
Total rewards annual percentage rate in basis points.
-
#tvl_usd ⇒ Float?
Total value locked in USD.
-
#user_apy ⇒ Float?
Annual percentage yield available to the user, after fees and excluding rewards, in basis points (e.g. 500 for 5%).
-
#vault_address ⇒ String
Onchain vault contract address.
Instance Method Summary collapse
-
#initialize(id:, admin_wallet_address:, admin_wallet_id:, app_apy:, asset:, available_liquidity_usd:, caip2:, name:, provider:, total_rewards_apr:, tvl_usd:, user_apy:, vault_address:) ⇒ Object
constructor
Some parameter documentations has been truncated, see MorphoVaultDetails for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, admin_wallet_address:, admin_wallet_id:, app_apy:, asset:, available_liquidity_usd:, caip2:, name:, provider:, total_rewards_apr:, tvl_usd:, user_apy:, vault_address:) ⇒ Object
Some parameter documentations has been truncated, see Privy::Models::Wallets::MorphoVaultDetails for more details.
Vault details for a Morpho earn vault.
|
|
# File 'lib/privy/models/wallets/morpho_vault_details.rb', line 86
|
Instance Attribute Details
#admin_wallet_address ⇒ String
EVM address of the vault admin wallet.
17 |
# File 'lib/privy/models/wallets/morpho_vault_details.rb', line 17 required :admin_wallet_address, String |
#admin_wallet_id ⇒ String
Privy wallet ID of the vault admin.
23 |
# File 'lib/privy/models/wallets/morpho_vault_details.rb', line 23 required :admin_wallet_id, String |
#app_apy ⇒ Float?
Annual percentage yield earned by the app from fee wrapper fees, in basis points.
30 |
# File 'lib/privy/models/wallets/morpho_vault_details.rb', line 30 required :app_apy, Float, nil?: true |
#asset ⇒ Privy::Models::Wallets::EarnAsset
Asset metadata for an earn vault position.
36 |
# File 'lib/privy/models/wallets/morpho_vault_details.rb', line 36 required :asset, -> { Privy::Wallets::EarnAsset } |
#available_liquidity_usd ⇒ Float?
Available liquidity in USD.
42 |
# File 'lib/privy/models/wallets/morpho_vault_details.rb', line 42 required :available_liquidity_usd, Float, nil?: true |
#caip2 ⇒ String
CAIP-2 chain identifier (e.g. "eip155:8453").
48 |
# File 'lib/privy/models/wallets/morpho_vault_details.rb', line 48 required :caip2, String |
#id ⇒ String
Vault identifier.
11 |
# File 'lib/privy/models/wallets/morpho_vault_details.rb', line 11 required :id, String |
#name ⇒ String
Human-readable vault name from the yield provider.
54 |
# File 'lib/privy/models/wallets/morpho_vault_details.rb', line 54 required :name, String |
#provider ⇒ Symbol, Privy::Models::Wallets::MorphoVaultDetails::Provider
59 |
# File 'lib/privy/models/wallets/morpho_vault_details.rb', line 59 required :provider, enum: -> { Privy::Wallets::MorphoVaultDetails::Provider } |
#total_rewards_apr ⇒ Float
Total rewards annual percentage rate in basis points.
65 |
# File 'lib/privy/models/wallets/morpho_vault_details.rb', line 65 required :total_rewards_apr, Float |
#tvl_usd ⇒ Float?
Total value locked in USD.
71 |
# File 'lib/privy/models/wallets/morpho_vault_details.rb', line 71 required :tvl_usd, Float, nil?: true |
#user_apy ⇒ Float?
Annual percentage yield available to the user, after fees and excluding rewards, in basis points (e.g. 500 for 5%). 1 basis point = 0.01%.
78 |
# File 'lib/privy/models/wallets/morpho_vault_details.rb', line 78 required :user_apy, Float, nil?: true |
#vault_address ⇒ String
Onchain vault contract address.
84 |
# File 'lib/privy/models/wallets/morpho_vault_details.rb', line 84 required :vault_address, String |
Instance Method Details
#to_hash ⇒ {
64 |
# File 'sig/privy/models/wallets/morpho_vault_details.rbs', line 64
def to_hash: -> {
|