Class: Privy::Models::YieldAuthorizationHeaders
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::YieldAuthorizationHeaders
- Defined in:
- lib/privy/models/yield_authorization_headers.rb
Instance Attribute Summary collapse
-
#privy_app_id ⇒ String
ID of your Privy app.
-
#privy_authorization_signature ⇒ String?
Request authorization signature.
-
#privy_request_expiry ⇒ String?
Request expiry.
Instance Method Summary collapse
-
#initialize(privy_app_id:, privy_authorization_signature: nil, privy_request_expiry: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see YieldAuthorizationHeaders for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(privy_app_id:, privy_authorization_signature: nil, privy_request_expiry: nil) ⇒ Object
Some parameter documentations has been truncated, see Privy::Models::YieldAuthorizationHeaders for more details.
Headers required to authorize yield operations.
|
|
# File 'lib/privy/models/yield_authorization_headers.rb', line 26
|
Instance Attribute Details
#privy_app_id ⇒ String
ID of your Privy app.
10 |
# File 'lib/privy/models/yield_authorization_headers.rb', line 10 required :privy_app_id, String, api_name: :"privy-app-id" |
#privy_authorization_signature ⇒ String?
Request authorization signature. If multiple signatures are required, they should be comma separated.
17 |
# File 'lib/privy/models/yield_authorization_headers.rb', line 17 optional :privy_authorization_signature, String, api_name: :"privy-authorization-signature" |
#privy_request_expiry ⇒ String?
Request expiry. Value is a Unix timestamp in milliseconds representing the deadline by which the request must be processed.
24 |
# File 'lib/privy/models/yield_authorization_headers.rb', line 24 optional :privy_request_expiry, String, api_name: :"privy-request-expiry" |