Class: Privy::Models::AccountsDashboardListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::AccountsDashboardListResponse
- Defined in:
- lib/privy/models/accounts_dashboard_list_response.rb
Instance Attribute Summary collapse
-
#data ⇒ Array<Privy::Models::AssetAccountWithBalance>
The list of accounts, with balances included for dashboard display.
-
#next_cursor ⇒ String?
Cursor for fetching the next page of results, or null if no more results.
Instance Method Summary collapse
-
#initialize(data:, next_cursor:) ⇒ Object
constructor
Paginated list of digital asset accounts for the dashboard.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(data:, next_cursor:) ⇒ Object
Paginated list of digital asset accounts for the dashboard.
|
|
# File 'lib/privy/models/accounts_dashboard_list_response.rb', line 18
|
Instance Attribute Details
#data ⇒ Array<Privy::Models::AssetAccountWithBalance>
The list of accounts, with balances included for dashboard display.
10 |
# File 'lib/privy/models/accounts_dashboard_list_response.rb', line 10 required :data, -> { Privy::Internal::Type::ArrayOf[Privy::AssetAccountWithBalance] } |
#next_cursor ⇒ String?
Cursor for fetching the next page of results, or null if no more results.
16 |
# File 'lib/privy/models/accounts_dashboard_list_response.rb', line 16 required :next_cursor, String, nil?: true |