Class: Privy::Models::BaseIntentResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::BaseIntentResponse
- Defined in:
- lib/privy/models/base_intent_response.rb
Direct Known Subclasses
KeyQuorumIntentResponse, PolicyIntentResponse, RpcIntentResponse, RuleIntentResponse, TransferIntentResponse, WalletIntentResponse
Instance Attribute Summary collapse
-
#authorization_details ⇒ Array<Privy::Models::IntentAuthorization>
Detailed authorization information including key quorum members, thresholds, and signature status.
-
#created_at ⇒ Float
Unix timestamp when the intent was created.
-
#created_by_display_name ⇒ String
Display name of the user who created the intent.
-
#created_by_id ⇒ String?
ID of the user who created the intent.
-
#custom_expiry ⇒ Boolean
Whether this intent has a custom expiry time set by the client.
-
#dismissal_reason ⇒ String?
Human-readable reason for dismissal, present when status is ‘dismissed’.
-
#dismissed_at ⇒ Float?
Unix timestamp when the intent was dismissed, present when status is ‘dismissed’.
-
#expires_at ⇒ Float
Unix timestamp when the intent expires.
-
#intent_id ⇒ String
Unique ID for the intent.
-
#rejected_at ⇒ Float?
Unix timestamp when the intent was rejected, present when status is ‘rejected’.
-
#resource_id ⇒ String
ID of the resource being modified (wallet_id, policy_id, etc).
-
#status ⇒ Symbol, Privy::Models::IntentStatus
Current status of an intent.
Instance Method Summary collapse
-
#initialize(authorization_details:, created_at:, created_by_display_name:, custom_expiry:, expires_at:, intent_id:, resource_id:, status:, created_by_id: nil, dismissal_reason: nil, dismissed_at: nil, rejected_at: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see BaseIntentResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(authorization_details:, created_at:, created_by_display_name:, custom_expiry:, expires_at:, intent_id:, resource_id:, status:, created_by_id: nil, dismissal_reason: nil, dismissed_at: nil, rejected_at: nil) ⇒ Object
Some parameter documentations has been truncated, see Privy::Models::BaseIntentResponse for more details.
Common fields shared by all intent response types.
|
|
# File 'lib/privy/models/base_intent_response.rb', line 81
|
Instance Attribute Details
#authorization_details ⇒ Array<Privy::Models::IntentAuthorization>
Detailed authorization information including key quorum members, thresholds, and signature status
11 |
# File 'lib/privy/models/base_intent_response.rb', line 11 required :authorization_details, -> { Privy::Internal::Type::ArrayOf[Privy::IntentAuthorization] } |
#created_at ⇒ Float
Unix timestamp when the intent was created
17 |
# File 'lib/privy/models/base_intent_response.rb', line 17 required :created_at, Float |
#created_by_display_name ⇒ String
Display name of the user who created the intent
23 |
# File 'lib/privy/models/base_intent_response.rb', line 23 required :created_by_display_name, String |
#created_by_id ⇒ String?
ID of the user who created the intent. If undefined, the intent was created using the app secret
61 |
# File 'lib/privy/models/base_intent_response.rb', line 61 optional :created_by_id, String |
#custom_expiry ⇒ Boolean
Whether this intent has a custom expiry time set by the client. If false, the intent expires after a default duration.
30 |
# File 'lib/privy/models/base_intent_response.rb', line 30 required :custom_expiry, Privy::Internal::Type::Boolean |
#dismissal_reason ⇒ String?
Human-readable reason for dismissal, present when status is ‘dismissed’
67 |
# File 'lib/privy/models/base_intent_response.rb', line 67 optional :dismissal_reason, String |
#dismissed_at ⇒ Float?
Unix timestamp when the intent was dismissed, present when status is ‘dismissed’
73 |
# File 'lib/privy/models/base_intent_response.rb', line 73 optional :dismissed_at, Float |
#expires_at ⇒ Float
Unix timestamp when the intent expires
36 |
# File 'lib/privy/models/base_intent_response.rb', line 36 required :expires_at, Float |
#intent_id ⇒ String
Unique ID for the intent
42 |
# File 'lib/privy/models/base_intent_response.rb', line 42 required :intent_id, String |
#rejected_at ⇒ Float?
Unix timestamp when the intent was rejected, present when status is ‘rejected’
79 |
# File 'lib/privy/models/base_intent_response.rb', line 79 optional :rejected_at, Float |
#resource_id ⇒ String
ID of the resource being modified (wallet_id, policy_id, etc)
48 |
# File 'lib/privy/models/base_intent_response.rb', line 48 required :resource_id, String |
#status ⇒ Symbol, Privy::Models::IntentStatus
Current status of an intent.
54 |
# File 'lib/privy/models/base_intent_response.rb', line 54 required :status, enum: -> { Privy::IntentStatus } |