Class: Privy::Models::ConditionSet

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/privy/models/condition_set.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, created_at:, name:, owner_id:) ⇒ Object

Some parameter documentations has been truncated, see Privy::Models::ConditionSet for more details.

A condition set for grouping related condition values.

Parameters:

  • id (String)

    Unique ID of the created condition set. This will be the primary identifier when

  • created_at (Float)

    Unix timestamp of when the condition set was created in milliseconds.

  • name (String)

    Name of the condition set.

  • owner_id (String)

    A unique identifier for a key quorum.



# File 'lib/privy/models/condition_set.rb', line 31

Instance Attribute Details

#created_atFloat

Unix timestamp of when the condition set was created in milliseconds.

Returns:

  • (Float)


17
# File 'lib/privy/models/condition_set.rb', line 17

required :created_at, Float

#idString

Unique ID of the created condition set. This will be the primary identifier when using the condition set in the future.

Returns:

  • (String)


11
# File 'lib/privy/models/condition_set.rb', line 11

required :id, String

#nameString

Name of the condition set.

Returns:

  • (String)


23
# File 'lib/privy/models/condition_set.rb', line 23

required :name, String

#owner_idString

A unique identifier for a key quorum.

Returns:

  • (String)


29
# File 'lib/privy/models/condition_set.rb', line 29

required :owner_id, String