Class: Privy::Models::ConditionSet
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::ConditionSet
- Defined in:
- lib/privy/models/condition_set.rb
Instance Attribute Summary collapse
-
#created_at ⇒ Float
Unix timestamp of when the condition set was created in milliseconds.
-
#id ⇒ String
Unique ID of the created condition set.
-
#name ⇒ String
Name of the condition set.
-
#owner_id ⇒ String
A unique identifier for a key quorum.
Instance Method Summary collapse
-
#initialize(id:, created_at:, name:, owner_id:) ⇒ Object
constructor
Some parameter documentations has been truncated, see ConditionSet for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, created_at:, name:, owner_id:) ⇒ Object
Some parameter documentations has been truncated, see Privy::Models::ConditionSet for more details.
A condition set for grouping related condition values.
|
|
# File 'lib/privy/models/condition_set.rb', line 31
|
Instance Attribute Details
#created_at ⇒ Float
Unix timestamp of when the condition set was created in milliseconds.
17 |
# File 'lib/privy/models/condition_set.rb', line 17 required :created_at, Float |
#id ⇒ String
Unique ID of the created condition set. This will be the primary identifier when using the condition set in the future.
11 |
# File 'lib/privy/models/condition_set.rb', line 11 required :id, String |
#name ⇒ String
Name of the condition set.
23 |
# File 'lib/privy/models/condition_set.rb', line 23 required :name, String |
#owner_id ⇒ String
A unique identifier for a key quorum.
29 |
# File 'lib/privy/models/condition_set.rb', line 29 required :owner_id, String |