Class: Privy::Models::CustodialWalletCreateInput
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::CustodialWalletCreateInput
- Defined in:
- lib/privy/models/custodial_wallet_create_input.rb
Instance Attribute Summary collapse
-
#additional_signers ⇒ Array<Privy::Models::AdditionalSignerItemInput>?
Additional signers for the wallet.
-
#chain_type ⇒ Symbol, Privy::Models::CustodialWalletChainType
The chain type of the custodial wallet.
-
#owner ⇒ Privy::Models::OwnerInputUser, ...
The owner of the resource, specified as a Privy user ID, a P-256 public key, or null to remove the current owner.
-
#policy_ids ⇒ Array<String>?
An optional list of up to one policy ID to enforce on the wallet.
-
#provider ⇒ Symbol, Privy::Models::CustodialWalletProvider
The provider of the custodial wallet.
-
#provider_user_id ⇒ String
The resource ID of the beneficiary of the custodial wallet, given by the licensing provider.
Instance Method Summary collapse
-
#initialize(chain_type:, provider:, provider_user_id:, additional_signers: nil, owner: nil, policy_ids: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see CustodialWalletCreateInput for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(chain_type:, provider:, provider_user_id:, additional_signers: nil, owner: nil, policy_ids: nil) ⇒ Object
Some parameter documentations has been truncated, see Privy::Models::CustodialWalletCreateInput for more details.
The input for creating a custodial wallet.
|
|
# File 'lib/privy/models/custodial_wallet_create_input.rb', line 44
|
Instance Attribute Details
#additional_signers ⇒ Array<Privy::Models::AdditionalSignerItemInput>?
Additional signers for the wallet.
29 |
# File 'lib/privy/models/custodial_wallet_create_input.rb', line 29 optional :additional_signers, -> { Privy::Internal::Type::ArrayOf[Privy::AdditionalSignerItemInput] } |
#chain_type ⇒ Symbol, Privy::Models::CustodialWalletChainType
The chain type of the custodial wallet.
10 |
# File 'lib/privy/models/custodial_wallet_create_input.rb', line 10 required :chain_type, enum: -> { Privy::CustodialWalletChainType } |
#owner ⇒ Privy::Models::OwnerInputUser, ...
The owner of the resource, specified as a Privy user ID, a P-256 public key, or null to remove the current owner.
36 |
# File 'lib/privy/models/custodial_wallet_create_input.rb', line 36 optional :owner, union: -> { Privy::OwnerInput }, nil?: true |
#policy_ids ⇒ Array<String>?
An optional list of up to one policy ID to enforce on the wallet.
42 |
# File 'lib/privy/models/custodial_wallet_create_input.rb', line 42 optional :policy_ids, Privy::Internal::Type::ArrayOf[String] |
#provider ⇒ Symbol, Privy::Models::CustodialWalletProvider
The provider of the custodial wallet.
16 |
# File 'lib/privy/models/custodial_wallet_create_input.rb', line 16 required :provider, enum: -> { Privy::CustodialWalletProvider } |
#provider_user_id ⇒ String
The resource ID of the beneficiary of the custodial wallet, given by the licensing provider.
23 |
# File 'lib/privy/models/custodial_wallet_create_input.rb', line 23 required :provider_user_id, String |