Class: Privy::Models::EarnDepositActionResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::EarnDepositActionResponse
- Defined in:
- lib/privy/models/earn_deposit_action_response.rb
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#amount ⇒ String?
Human-readable decimal amount of asset deposited (e.g. “1.5”).
-
#asset ⇒ String?
Asset identifier (e.g. “usdc”, “eth”).
-
#asset_address ⇒ String
Underlying asset token address.
-
#caip2 ⇒ String
CAIP-2 chain identifier.
-
#created_at ⇒ Time
ISO 8601 timestamp of when the wallet action was created.
-
#decimals ⇒ Integer?
Number of decimals for the underlying asset (e.g. 6 for USDC, 18 for ETH).
-
#failure_reason ⇒ Privy::Models::FailureReason?
A description of why a wallet action (or a step within a wallet action) failed.
-
#id ⇒ String
The ID of the wallet action.
-
#raw_amount ⇒ String
Base-unit amount of asset deposited (e.g. “1500000”).
-
#share_amount ⇒ String?
Vault shares received in base units.
-
#status ⇒ Symbol, Privy::Models::WalletActionStatus
Status of a wallet action.
-
#steps ⇒ Array<Privy::Models::EvmTransactionWalletActionStep, Privy::Models::EvmUserOperationWalletActionStep, Privy::Models::SvmTransactionWalletActionStep, Privy::Models::ExternalTransactionWalletActionStep>?
The steps of the wallet action.
- #type ⇒ Symbol, Privy::Models::EarnDepositActionResponse::Type
-
#vault_address ⇒ String
ERC-4626 vault contract address.
-
#vault_id ⇒ String
The vault ID.
-
#wallet_id ⇒ String
The ID of the wallet involved in the action.
Instance Method Summary collapse
-
#initialize(id:, asset_address:, caip2:, created_at:, raw_amount:, share_amount:, status:, type:, vault_address:, vault_id:, wallet_id:, amount: nil, asset: nil, decimals: nil, failure_reason: nil, steps: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see EarnDepositActionResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, asset_address:, caip2:, created_at:, raw_amount:, share_amount:, status:, type:, vault_address:, vault_id:, wallet_id:, amount: nil, asset: nil, decimals: nil, failure_reason: nil, steps: nil) ⇒ Object
Some parameter documentations has been truncated, see Privy::Models::EarnDepositActionResponse for more details.
Response for an earn deposit action.
|
|
# File 'lib/privy/models/earn_deposit_action_response.rb', line 104
|
Instance Attribute Details
#amount ⇒ String?
Human-readable decimal amount of asset deposited (e.g. “1.5”). Only present when the token is known in the asset registry.
76 |
# File 'lib/privy/models/earn_deposit_action_response.rb', line 76 optional :amount, String |
#asset ⇒ String?
Asset identifier (e.g. “usdc”, “eth”). Only present when the token is known in the asset registry.
83 |
# File 'lib/privy/models/earn_deposit_action_response.rb', line 83 optional :asset, String |
#asset_address ⇒ String
Underlying asset token address.
16 |
# File 'lib/privy/models/earn_deposit_action_response.rb', line 16 required :asset_address, String |
#caip2 ⇒ String
CAIP-2 chain identifier.
22 |
# File 'lib/privy/models/earn_deposit_action_response.rb', line 22 required :caip2, String |
#created_at ⇒ Time
ISO 8601 timestamp of when the wallet action was created.
28 |
# File 'lib/privy/models/earn_deposit_action_response.rb', line 28 required :created_at, Time |
#decimals ⇒ Integer?
Number of decimals for the underlying asset (e.g. 6 for USDC, 18 for ETH). Only present when the token is known in the asset registry.
90 |
# File 'lib/privy/models/earn_deposit_action_response.rb', line 90 optional :decimals, Integer |
#failure_reason ⇒ Privy::Models::FailureReason?
A description of why a wallet action (or a step within a wallet action) failed.
96 |
# File 'lib/privy/models/earn_deposit_action_response.rb', line 96 optional :failure_reason, -> { Privy::FailureReason } |
#id ⇒ String
The ID of the wallet action.
10 |
# File 'lib/privy/models/earn_deposit_action_response.rb', line 10 required :id, String |
#raw_amount ⇒ String
Base-unit amount of asset deposited (e.g. “1500000”).
34 |
# File 'lib/privy/models/earn_deposit_action_response.rb', line 34 required :raw_amount, String |
#share_amount ⇒ String?
Vault shares received in base units. Populated after on-chain confirmation.
40 |
# File 'lib/privy/models/earn_deposit_action_response.rb', line 40 required :share_amount, String, nil?: true |
#status ⇒ Symbol, Privy::Models::WalletActionStatus
Status of a wallet action.
46 |
# File 'lib/privy/models/earn_deposit_action_response.rb', line 46 required :status, enum: -> { Privy::WalletActionStatus } |
#steps ⇒ Array<Privy::Models::EvmTransactionWalletActionStep, Privy::Models::EvmUserOperationWalletActionStep, Privy::Models::SvmTransactionWalletActionStep, Privy::Models::ExternalTransactionWalletActionStep>?
The steps of the wallet action. Only returned if ‘?include=steps` is provided.
102 |
# File 'lib/privy/models/earn_deposit_action_response.rb', line 102 optional :steps, -> { Privy::Internal::Type::ArrayOf[union: Privy::WalletActionStep] } |
#type ⇒ Symbol, Privy::Models::EarnDepositActionResponse::Type
51 |
# File 'lib/privy/models/earn_deposit_action_response.rb', line 51 required :type, enum: -> { Privy::EarnDepositActionResponse::Type } |
#vault_address ⇒ String
ERC-4626 vault contract address.
57 |
# File 'lib/privy/models/earn_deposit_action_response.rb', line 57 required :vault_address, String |
#vault_id ⇒ String
The vault ID.
63 |
# File 'lib/privy/models/earn_deposit_action_response.rb', line 63 required :vault_id, String |
#wallet_id ⇒ String
The ID of the wallet involved in the action.
69 |
# File 'lib/privy/models/earn_deposit_action_response.rb', line 69 required :wallet_id, String |