Class: Privy::Models::EthereumEarnPositionResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::EthereumEarnPositionResponse
- Defined in:
- lib/privy/models/ethereum_earn_position_response.rb
Instance Attribute Summary collapse
-
#asset ⇒ Privy::Models::EarnAsset
Asset metadata for an earn vault position.
-
#assets_in_vault ⇒ String
Current asset value in the vault (realtime from ERC-4626), in smallest unit.
-
#shares_in_vault ⇒ String
Current vault shares held (realtime from ERC-4626).
-
#total_deposited ⇒ String
Total amount deposited into the vault, in smallest unit.
-
#total_withdrawn ⇒ String
Total amount withdrawn from the vault, in smallest unit.
Instance Method Summary collapse
-
#initialize(asset:, assets_in_vault:, shares_in_vault:, total_deposited:, total_withdrawn:) ⇒ Object
constructor
A wallet’s position in an earn vault.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(asset:, assets_in_vault:, shares_in_vault:, total_deposited:, total_withdrawn:) ⇒ Object
A wallet’s position in an earn vault.
|
|
# File 'lib/privy/models/ethereum_earn_position_response.rb', line 36
|
Instance Attribute Details
#asset ⇒ Privy::Models::EarnAsset
Asset metadata for an earn vault position.
10 |
# File 'lib/privy/models/ethereum_earn_position_response.rb', line 10 required :asset, -> { Privy::EarnAsset } |
#assets_in_vault ⇒ String
Current asset value in the vault (realtime from ERC-4626), in smallest unit.
16 |
# File 'lib/privy/models/ethereum_earn_position_response.rb', line 16 required :assets_in_vault, String |
#shares_in_vault ⇒ String
Current vault shares held (realtime from ERC-4626).
22 |
# File 'lib/privy/models/ethereum_earn_position_response.rb', line 22 required :shares_in_vault, String |
#total_deposited ⇒ String
Total amount deposited into the vault, in smallest unit.
28 |
# File 'lib/privy/models/ethereum_earn_position_response.rb', line 28 required :total_deposited, String |
#total_withdrawn ⇒ String
Total amount withdrawn from the vault, in smallest unit.
34 |
# File 'lib/privy/models/ethereum_earn_position_response.rb', line 34 required :total_withdrawn, String |