Class: Privy::Models::EthereumSign7702Authorization
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::EthereumSign7702Authorization
- Defined in:
- lib/privy/models/ethereum_sign_7702_authorization.rb
Instance Attribute Summary collapse
-
#chain_id ⇒ String, Integer
A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.
- #contract ⇒ String
-
#nonce ⇒ String, Integer
A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.
-
#r ⇒ String
A hex-encoded string prefixed with ‘0x’, capped at 100002 characters (50,000 bytes).
-
#s ⇒ String
A hex-encoded string prefixed with ‘0x’, capped at 100002 characters (50,000 bytes).
- #y_parity ⇒ Float
Instance Method Summary collapse
-
#initialize(chain_id:, contract:, nonce:, r:, s:, y_parity:) ⇒ Object
constructor
Some parameter documentations has been truncated, see EthereumSign7702Authorization for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(chain_id:, contract:, nonce:, r:, s:, y_parity:) ⇒ Object
Some parameter documentations has been truncated, see Privy::Models::EthereumSign7702Authorization for more details.
A signed EIP-7702 authorization that delegates code execution to a contract address.
|
|
# File 'lib/privy/models/ethereum_sign_7702_authorization.rb', line 44
|
Instance Attribute Details
#chain_id ⇒ String, Integer
A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.
11 |
# File 'lib/privy/models/ethereum_sign_7702_authorization.rb', line 11 required :chain_id, union: -> { Privy::Quantity } |
#contract ⇒ String
16 |
# File 'lib/privy/models/ethereum_sign_7702_authorization.rb', line 16 required :contract, String |
#nonce ⇒ String, Integer
A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.
23 |
# File 'lib/privy/models/ethereum_sign_7702_authorization.rb', line 23 required :nonce, union: -> { Privy::Quantity } |
#r ⇒ String
A hex-encoded string prefixed with ‘0x’, capped at 100002 characters (50,000 bytes).
30 |
# File 'lib/privy/models/ethereum_sign_7702_authorization.rb', line 30 required :r, String |
#s ⇒ String
A hex-encoded string prefixed with ‘0x’, capped at 100002 characters (50,000 bytes).
37 |
# File 'lib/privy/models/ethereum_sign_7702_authorization.rb', line 37 required :s, String |
#y_parity ⇒ Float
42 |
# File 'lib/privy/models/ethereum_sign_7702_authorization.rb', line 42 required :y_parity, Float |