Class: Privy::Models::EthereumVaultResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::EthereumVaultResponse
- Defined in:
- lib/privy/models/ethereum_vault_response.rb
Instance Attribute Summary collapse
-
#asset_address ⇒ String
The address of the underlying asset token (e.g., USDC).
-
#caip2 ⇒ String
The CAIP-2 chain identifier.
-
#created_at ⇒ Float
Unix timestamp of when the vault was created, in milliseconds.
-
#id ⇒ String
Unique identifier for the vault.
-
#provider ⇒ Symbol, Privy::Models::EthereumYieldProvider
Supported yield/lending protocol providers.
-
#underlying_vault_address ⇒ String
The address of the underlying vault that the fee vault wraps.
-
#vault_address ⇒ String
The on-chain address of the ERC-4626 vault contract.
Instance Method Summary collapse
-
#initialize(id:, asset_address:, caip2:, created_at:, provider:, underlying_vault_address:, vault_address:) ⇒ Object
constructor
Some parameter documentations has been truncated, see EthereumVaultResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, asset_address:, caip2:, created_at:, provider:, underlying_vault_address:, vault_address:) ⇒ Object
Some parameter documentations has been truncated, see Privy::Models::EthereumVaultResponse for more details.
A vault configuration for yield features.
|
|
# File 'lib/privy/models/ethereum_vault_response.rb', line 49
|
Instance Attribute Details
#asset_address ⇒ String
The address of the underlying asset token (e.g., USDC).
16 |
# File 'lib/privy/models/ethereum_vault_response.rb', line 16 required :asset_address, String |
#caip2 ⇒ String
The CAIP-2 chain identifier.
22 |
# File 'lib/privy/models/ethereum_vault_response.rb', line 22 required :caip2, String |
#created_at ⇒ Float
Unix timestamp of when the vault was created, in milliseconds.
28 |
# File 'lib/privy/models/ethereum_vault_response.rb', line 28 required :created_at, Float |
#id ⇒ String
Unique identifier for the vault.
10 |
# File 'lib/privy/models/ethereum_vault_response.rb', line 10 required :id, String |
#provider ⇒ Symbol, Privy::Models::EthereumYieldProvider
Supported yield/lending protocol providers.
34 |
# File 'lib/privy/models/ethereum_vault_response.rb', line 34 required :provider, enum: -> { Privy::EthereumYieldProvider } |
#underlying_vault_address ⇒ String
The address of the underlying vault that the fee vault wraps. If this is not a fee vault, this equals vault_address.
41 |
# File 'lib/privy/models/ethereum_vault_response.rb', line 41 required :underlying_vault_address, String |
#vault_address ⇒ String
The on-chain address of the ERC-4626 vault contract.
47 |
# File 'lib/privy/models/ethereum_vault_response.rb', line 47 required :vault_address, String |