Class: Privy::Models::EthereumYieldClaimResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::EthereumYieldClaimResponse
- Defined in:
- lib/privy/models/ethereum_yield_claim_response.rb
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#caip2 ⇒ String
An EVM CAIP-2 chain identifier (e.g., “eip155:8453” for Base).
-
#created_at ⇒ Float
Unix timestamp of when the claim was created, in milliseconds.
-
#id ⇒ String
Privy transaction record ID for the claim operation.
-
#rewards ⇒ Array<Privy::Models::EthereumYieldClaimReward>
List of reward tokens claimed.
-
#status ⇒ Symbol, Privy::Models::EthereumYieldClaimResponse::Status
The current status of the claim transaction.
-
#updated_at ⇒ Float
Unix timestamp of when the claim was last updated, in milliseconds.
Instance Method Summary collapse
-
#initialize(id:, caip2:, created_at:, rewards:, status:, updated_at:) ⇒ Object
constructor
Response from a yield reward claim operation.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, caip2:, created_at:, rewards:, status:, updated_at:) ⇒ Object
Response from a yield reward claim operation.
|
|
# File 'lib/privy/models/ethereum_yield_claim_response.rb', line 42
|
Instance Attribute Details
#caip2 ⇒ String
An EVM CAIP-2 chain identifier (e.g., “eip155:8453” for Base).
16 |
# File 'lib/privy/models/ethereum_yield_claim_response.rb', line 16 required :caip2, String |
#created_at ⇒ Float
Unix timestamp of when the claim was created, in milliseconds.
22 |
# File 'lib/privy/models/ethereum_yield_claim_response.rb', line 22 required :created_at, Float |
#id ⇒ String
Privy transaction record ID for the claim operation.
10 |
# File 'lib/privy/models/ethereum_yield_claim_response.rb', line 10 required :id, String |
#rewards ⇒ Array<Privy::Models::EthereumYieldClaimReward>
List of reward tokens claimed.
28 |
# File 'lib/privy/models/ethereum_yield_claim_response.rb', line 28 required :rewards, -> { Privy::Internal::Type::ArrayOf[Privy::EthereumYieldClaimReward] } |
#status ⇒ Symbol, Privy::Models::EthereumYieldClaimResponse::Status
The current status of the claim transaction.
34 |
# File 'lib/privy/models/ethereum_yield_claim_response.rb', line 34 required :status, enum: -> { Privy::EthereumYieldClaimResponse::Status } |
#updated_at ⇒ Float
Unix timestamp of when the claim was last updated, in milliseconds.
40 |
# File 'lib/privy/models/ethereum_yield_claim_response.rb', line 40 required :updated_at, Float |