Class: Privy::Models::FundsDepositedWebhookPayload
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::FundsDepositedWebhookPayload
- Defined in:
- lib/privy/models/funds_deposited_webhook_payload.rb,
sig/privy/models/funds_deposited_webhook_payload.rbs
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#amount ⇒ String
The amount transferred, as a stringified bigint.
-
#asset ⇒ Privy::Models::WalletFundsNativeTokenAsset, ...
An asset involved in a wallet transfer.
-
#block ⇒ Privy::Models::BlockInfo
Block metadata for a wallet transfer event.
-
#bridge_metadata ⇒ Privy::Models::BridgeCryptoDepositMetadata, ...
Metadata about a Bridge transaction associated with a wallet event.
-
#caip2 ⇒ String
The CAIP-2 chain identifier.
-
#idempotency_key ⇒ String
A unique key for this event.
-
#recipient ⇒ String
The recipient address.
-
#sender ⇒ String
The sender address.
-
#transaction_fee ⇒ String?
The transaction fee paid, as a stringified bigint in the chain's native token.
-
#transaction_hash ⇒ String
The blockchain transaction hash.
-
#type ⇒ Symbol, Privy::Models::FundsDepositedWebhookPayload::Type
The type of webhook event.
-
#wallet_id ⇒ String
The ID of the wallet.
Instance Method Summary collapse
-
#initialize(amount:, asset:, block:, caip2:, idempotency_key:, recipient:, sender:, transaction_hash:, type:, wallet_id:, bridge_metadata: nil, transaction_fee: nil) ⇒ Object
constructor
Payload for the wallet.funds_deposited webhook event.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, asset:, block:, caip2:, idempotency_key:, recipient:, sender:, transaction_hash:, type:, wallet_id:, bridge_metadata: nil, transaction_fee: nil) ⇒ Object
Payload for the wallet.funds_deposited webhook event.
|
|
# File 'lib/privy/models/funds_deposited_webhook_payload.rb', line 78
|
Instance Attribute Details
#amount ⇒ String
The amount transferred, as a stringified bigint.
10 |
# File 'lib/privy/models/funds_deposited_webhook_payload.rb', line 10 required :amount, String |
#asset ⇒ Privy::Models::WalletFundsNativeTokenAsset, ...
An asset involved in a wallet transfer.
16 |
# File 'lib/privy/models/funds_deposited_webhook_payload.rb', line 16 required :asset, union: -> { Privy::WalletFundsAsset } |
#block ⇒ Privy::Models::BlockInfo
Block metadata for a wallet transfer event.
22 |
# File 'lib/privy/models/funds_deposited_webhook_payload.rb', line 22 required :block, -> { Privy::BlockInfo } |
#bridge_metadata ⇒ Privy::Models::BridgeCryptoDepositMetadata, ...
Metadata about a Bridge transaction associated with a wallet event.
70 |
# File 'lib/privy/models/funds_deposited_webhook_payload.rb', line 70 optional :bridge_metadata, union: -> { Privy::BridgeMetadata } |
#caip2 ⇒ String
The CAIP-2 chain identifier.
28 |
# File 'lib/privy/models/funds_deposited_webhook_payload.rb', line 28 required :caip2, String |
#idempotency_key ⇒ String
A unique key for this event.
34 |
# File 'lib/privy/models/funds_deposited_webhook_payload.rb', line 34 required :idempotency_key, String |
#recipient ⇒ String
The recipient address.
40 |
# File 'lib/privy/models/funds_deposited_webhook_payload.rb', line 40 required :recipient, String |
#sender ⇒ String
The sender address.
46 |
# File 'lib/privy/models/funds_deposited_webhook_payload.rb', line 46 required :sender, String |
#transaction_fee ⇒ String?
The transaction fee paid, as a stringified bigint in the chain's native token.
76 |
# File 'lib/privy/models/funds_deposited_webhook_payload.rb', line 76 optional :transaction_fee, String |
#transaction_hash ⇒ String
The blockchain transaction hash.
52 |
# File 'lib/privy/models/funds_deposited_webhook_payload.rb', line 52 required :transaction_hash, String |
#type ⇒ Symbol, Privy::Models::FundsDepositedWebhookPayload::Type
The type of webhook event.
58 |
# File 'lib/privy/models/funds_deposited_webhook_payload.rb', line 58 required :type, enum: -> { Privy::FundsDepositedWebhookPayload::Type } |
#wallet_id ⇒ String
The ID of the wallet.
64 |
# File 'lib/privy/models/funds_deposited_webhook_payload.rb', line 64 required :wallet_id, String |
Instance Method Details
#to_hash ⇒ {
65 |
# File 'sig/privy/models/funds_deposited_webhook_payload.rbs', line 65
def to_hash: -> {
|