Class: Privy::Models::FundsDepositedWebhookPayload
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::FundsDepositedWebhookPayload
- Defined in:
- lib/privy/models/funds_deposited_webhook_payload.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#amount ⇒ String
The amount transferred, as a stringified bigint.
-
#asset ⇒ Privy::Models::WalletFundsNativeTokenAsset, ...
An asset involved in a wallet transfer.
- #block ⇒ Privy::Models::FundsDepositedWebhookPayload::Block
-
#bridge_metadata ⇒ Privy::Models::BridgeCryptoDepositMetadata, ...
Metadata about a Bridge transaction associated with a wallet event.
-
#caip2 ⇒ String
The CAIP-2 chain identifier.
-
#idempotency_key ⇒ String
A unique key for this event.
-
#recipient ⇒ String
The recipient address.
-
#sender ⇒ String
The sender address.
-
#transaction_fee ⇒ String?
The transaction fee paid, as a stringified bigint in the chain’s native token.
-
#transaction_hash ⇒ String
The blockchain transaction hash.
-
#type ⇒ Symbol, Privy::Models::FundsDepositedWebhookPayload::Type
The type of webhook event.
-
#wallet_id ⇒ String
The ID of the wallet.
Instance Method Summary collapse
- #initialize(number:, timestamp:) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(number:, timestamp:) ⇒ Object
|
|
# File 'lib/privy/models/funds_deposited_webhook_payload.rb', line 77
|
Instance Attribute Details
#amount ⇒ String
The amount transferred, as a stringified bigint.
10 |
# File 'lib/privy/models/funds_deposited_webhook_payload.rb', line 10 required :amount, String |
#asset ⇒ Privy::Models::WalletFundsNativeTokenAsset, ...
An asset involved in a wallet transfer.
16 |
# File 'lib/privy/models/funds_deposited_webhook_payload.rb', line 16 required :asset, union: -> { Privy::WalletFundsAsset } |
#block ⇒ Privy::Models::FundsDepositedWebhookPayload::Block
21 |
# File 'lib/privy/models/funds_deposited_webhook_payload.rb', line 21 required :block, -> { Privy::FundsDepositedWebhookPayload::Block } |
#bridge_metadata ⇒ Privy::Models::BridgeCryptoDepositMetadata, ...
Metadata about a Bridge transaction associated with a wallet event.
69 |
# File 'lib/privy/models/funds_deposited_webhook_payload.rb', line 69 optional :bridge_metadata, union: -> { Privy::BridgeMetadata } |
#caip2 ⇒ String
The CAIP-2 chain identifier.
27 |
# File 'lib/privy/models/funds_deposited_webhook_payload.rb', line 27 required :caip2, String |
#idempotency_key ⇒ String
A unique key for this event.
33 |
# File 'lib/privy/models/funds_deposited_webhook_payload.rb', line 33 required :idempotency_key, String |
#recipient ⇒ String
The recipient address.
39 |
# File 'lib/privy/models/funds_deposited_webhook_payload.rb', line 39 required :recipient, String |
#sender ⇒ String
The sender address.
45 |
# File 'lib/privy/models/funds_deposited_webhook_payload.rb', line 45 required :sender, String |
#transaction_fee ⇒ String?
The transaction fee paid, as a stringified bigint in the chain’s native token.
75 |
# File 'lib/privy/models/funds_deposited_webhook_payload.rb', line 75 optional :transaction_fee, String |
#transaction_hash ⇒ String
The blockchain transaction hash.
51 |
# File 'lib/privy/models/funds_deposited_webhook_payload.rb', line 51 required :transaction_hash, String |
#type ⇒ Symbol, Privy::Models::FundsDepositedWebhookPayload::Type
The type of webhook event.
57 |
# File 'lib/privy/models/funds_deposited_webhook_payload.rb', line 57 required :type, enum: -> { Privy::FundsDepositedWebhookPayload::Type } |
#wallet_id ⇒ String
The ID of the wallet.
63 |
# File 'lib/privy/models/funds_deposited_webhook_payload.rb', line 63 required :wallet_id, String |