Class: Privy::Models::IntentAuthorizedWebhookPayload
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::IntentAuthorizedWebhookPayload
- Defined in:
- lib/privy/models/intent_authorized_webhook_payload.rb
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#authorized_at ⇒ Float
Unix timestamp when the authorization was recorded.
-
#created_at ⇒ Float
Unix timestamp when the intent was created.
-
#created_by_display_name ⇒ String?
Display name of the user who created the intent.
-
#created_by_id ⇒ String?
The ID of the user who created the intent.
-
#expires_at ⇒ Float
Unix timestamp when the intent expires.
-
#intent_id ⇒ String
The unique ID of the intent.
-
#intent_type ⇒ Symbol, Privy::Models::IntentType
Type of intent.
-
#member ⇒ Privy::Models::IntentAuthorizationKeyQuorumMember::UserMember, Privy::Models::IntentAuthorizationKeyQuorumMember::KeyMember
A leaf member (user or key) of a nested key quorum in an intent authorization.
-
#status ⇒ String
The current status of the intent.
-
#type ⇒ Symbol, Privy::Models::IntentAuthorizedWebhookPayload::Type
The type of webhook event.
Instance Method Summary collapse
-
#initialize(authorized_at:, created_at:, expires_at:, intent_id:, intent_type:, member:, status:, type:, created_by_display_name: nil, created_by_id: nil) ⇒ Object
constructor
Payload for the intent.authorized webhook event.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(authorized_at:, created_at:, expires_at:, intent_id:, intent_type:, member:, status:, type:, created_by_display_name: nil, created_by_id: nil) ⇒ Object
Payload for the intent.authorized webhook event.
|
|
# File 'lib/privy/models/intent_authorized_webhook_payload.rb', line 66
|
Instance Attribute Details
#authorized_at ⇒ Float
Unix timestamp when the authorization was recorded.
10 |
# File 'lib/privy/models/intent_authorized_webhook_payload.rb', line 10 required :authorized_at, Float |
#created_at ⇒ Float
Unix timestamp when the intent was created.
16 |
# File 'lib/privy/models/intent_authorized_webhook_payload.rb', line 16 required :created_at, Float |
#created_by_display_name ⇒ String?
Display name of the user who created the intent.
58 |
# File 'lib/privy/models/intent_authorized_webhook_payload.rb', line 58 optional :created_by_display_name, String |
#created_by_id ⇒ String?
The ID of the user who created the intent.
64 |
# File 'lib/privy/models/intent_authorized_webhook_payload.rb', line 64 optional :created_by_id, String |
#expires_at ⇒ Float
Unix timestamp when the intent expires.
22 |
# File 'lib/privy/models/intent_authorized_webhook_payload.rb', line 22 required :expires_at, Float |
#intent_id ⇒ String
The unique ID of the intent.
28 |
# File 'lib/privy/models/intent_authorized_webhook_payload.rb', line 28 required :intent_id, String |
#intent_type ⇒ Symbol, Privy::Models::IntentType
Type of intent.
34 |
# File 'lib/privy/models/intent_authorized_webhook_payload.rb', line 34 required :intent_type, enum: -> { Privy::IntentType } |
#member ⇒ Privy::Models::IntentAuthorizationKeyQuorumMember::UserMember, Privy::Models::IntentAuthorizationKeyQuorumMember::KeyMember
A leaf member (user or key) of a nested key quorum in an intent authorization.
40 |
# File 'lib/privy/models/intent_authorized_webhook_payload.rb', line 40 required :member, union: -> { Privy::IntentAuthorizationKeyQuorumMember } |
#status ⇒ String
The current status of the intent.
46 |
# File 'lib/privy/models/intent_authorized_webhook_payload.rb', line 46 required :status, String |
#type ⇒ Symbol, Privy::Models::IntentAuthorizedWebhookPayload::Type
The type of webhook event.
52 |
# File 'lib/privy/models/intent_authorized_webhook_payload.rb', line 52 required :type, enum: -> { Privy::IntentAuthorizedWebhookPayload::Type } |