Class: Privy::Models::KrakenEmbedCustomOrderAction
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::KrakenEmbedCustomOrderAction
- Defined in:
- lib/privy/models/kraken_embed_custom_order_action.rb
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#amount ⇒ Privy::Models::KrakenEmbedCustomOrderAmount
Asset amount for custom order actions.
- #fee_bps ⇒ String
-
#quote ⇒ Privy::Models::KrakenEmbedCustomOrderQuoteAsset
Target asset for the other side of the custom order trade.
- #spread_bps ⇒ String
- #type ⇒ Symbol, Privy::Models::KrakenEmbedCustomOrderAction::Type
Instance Method Summary collapse
-
#initialize(amount:, fee_bps:, quote:, spread_bps:, type:) ⇒ Object
constructor
Trade action for a custom order.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, fee_bps:, quote:, spread_bps:, type:) ⇒ Object
Trade action for a custom order.
|
|
# File 'lib/privy/models/kraken_embed_custom_order_action.rb', line 33
|
Instance Attribute Details
#amount ⇒ Privy::Models::KrakenEmbedCustomOrderAmount
Asset amount for custom order actions.
10 |
# File 'lib/privy/models/kraken_embed_custom_order_action.rb', line 10 required :amount, -> { Privy::KrakenEmbedCustomOrderAmount } |
#fee_bps ⇒ String
15 |
# File 'lib/privy/models/kraken_embed_custom_order_action.rb', line 15 required :fee_bps, String |
#quote ⇒ Privy::Models::KrakenEmbedCustomOrderQuoteAsset
Target asset for the other side of the custom order trade.
21 |
# File 'lib/privy/models/kraken_embed_custom_order_action.rb', line 21 required :quote, -> { Privy::KrakenEmbedCustomOrderQuoteAsset } |
#spread_bps ⇒ String
26 |
# File 'lib/privy/models/kraken_embed_custom_order_action.rb', line 26 required :spread_bps, String |
#type ⇒ Symbol, Privy::Models::KrakenEmbedCustomOrderAction::Type
31 |
# File 'lib/privy/models/kraken_embed_custom_order_action.rb', line 31 required :type, enum: -> { Privy::KrakenEmbedCustomOrderAction::Type } |