Class: Privy::Models::KrakenEmbedEarnAsset
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::KrakenEmbedEarnAsset
- Defined in:
- lib/privy/models/kraken_embed_earn_asset.rb
Defined Under Namespace
Classes: AprEstimate, UserAllocation
Instance Attribute Summary collapse
-
#apr_estimate ⇒ Privy::Models::KrakenEmbedEarnAsset::AprEstimate
Low and high estimate of the yield of an earn asset.
-
#user_allocation ⇒ Privy::Models::KrakenEmbedEarnAsset::UserAllocation?
User allocation for an earn asset.
Instance Method Summary collapse
-
#initialize ⇒ Object
constructor
User allocation for an earn asset.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
User allocation for an earn asset.
|
|
# File 'lib/privy/models/kraken_embed_earn_asset.rb', line 18
|
Instance Attribute Details
#apr_estimate ⇒ Privy::Models::KrakenEmbedEarnAsset::AprEstimate
Low and high estimate of the yield of an earn asset.
10 |
# File 'lib/privy/models/kraken_embed_earn_asset.rb', line 10 required :apr_estimate, -> { Privy::KrakenEmbedEarnAsset::AprEstimate } |
#user_allocation ⇒ Privy::Models::KrakenEmbedEarnAsset::UserAllocation?
User allocation for an earn asset.
16 |
# File 'lib/privy/models/kraken_embed_earn_asset.rb', line 16 optional :user_allocation, -> { Privy::KrakenEmbedEarnAsset::UserAllocation } |