Class: Privy::Models::KrakenEmbedStartIdentityInfo
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::KrakenEmbedStartIdentityInfo
- Defined in:
- lib/privy/models/kraken_embed_start_identity_info.rb
Direct Known Subclasses
Defined Under Namespace
Classes: FullName
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(date_of_birth: nil, full_name: nil) ⇒ Object
constructor
Identity information hints including full name and date of birth for proof of identity verification.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(date_of_birth: nil, full_name: nil) ⇒ Object
Identity information hints including full name and date of birth for proof of identity verification.
|
|
# File 'lib/privy/models/kraken_embed_start_identity_info.rb', line 16
|
Instance Attribute Details
#date_of_birth ⇒ Date?
9 |
# File 'lib/privy/models/kraken_embed_start_identity_info.rb', line 9 optional :date_of_birth, Date, nil?: true |
#full_name ⇒ Privy::Models::KrakenEmbedStartIdentityInfo::FullName?
14 |
# File 'lib/privy/models/kraken_embed_start_identity_info.rb', line 14 optional :full_name, -> { Privy::KrakenEmbedStartIdentityInfo::FullName }, nil?: true |