Class: Privy::Models::KrakenEmbedStartIdentityMetadata
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::KrakenEmbedStartIdentityMetadata
- Defined in:
- lib/privy/models/kraken_embed_start_identity_metadata.rb
Direct Known Subclasses
Privy::Models::KrakenEmbedStartIdentityVerificationURLInput::Metadata
Defined Under Namespace
Modules: DocumentType, IssuingCountry, Nationality Classes: Identity
Instance Attribute Summary collapse
- #document_number ⇒ String?
- #document_type ⇒ Symbol, ...
- #expiration_date ⇒ Date?
-
#identity ⇒ Privy::Models::KrakenEmbedStartIdentityMetadata::Identity?
Identity information hints including full name and date of birth for proof of identity verification.
- #issuing_country ⇒ Symbol, ...
- #nationality ⇒ Symbol, ...
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize ⇒ Object
constructor
Identity information hints including full name and date of birth for proof of identity verification.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
Identity information hints including full name and date of birth for proof of identity verification.
|
|
# File 'lib/privy/models/kraken_embed_start_identity_metadata.rb', line 40
|
Instance Attribute Details
#document_number ⇒ String?
9 |
# File 'lib/privy/models/kraken_embed_start_identity_metadata.rb', line 9 optional :document_number, String, nil?: true |
#document_type ⇒ Symbol, ...
14 |
# File 'lib/privy/models/kraken_embed_start_identity_metadata.rb', line 14 optional :document_type, enum: -> { Privy::KrakenEmbedStartIdentityMetadata::DocumentType }, nil?: true |
#expiration_date ⇒ Date?
19 |
# File 'lib/privy/models/kraken_embed_start_identity_metadata.rb', line 19 optional :expiration_date, Date, nil?: true |
#identity ⇒ Privy::Models::KrakenEmbedStartIdentityMetadata::Identity?
Identity information hints including full name and date of birth for proof of identity verification.
26 |
# File 'lib/privy/models/kraken_embed_start_identity_metadata.rb', line 26 optional :identity, -> { Privy::KrakenEmbedStartIdentityMetadata::Identity } |
#issuing_country ⇒ Symbol, ...
31 32 33 |
# File 'lib/privy/models/kraken_embed_start_identity_metadata.rb', line 31 optional :issuing_country, enum: -> { Privy::KrakenEmbedStartIdentityMetadata::IssuingCountry }, nil?: true |
#nationality ⇒ Symbol, ...
38 |
# File 'lib/privy/models/kraken_embed_start_identity_metadata.rb', line 38 optional :nationality, enum: -> { Privy::KrakenEmbedStartIdentityMetadata::Nationality }, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/privy/models/kraken_embed_start_identity_metadata.rb', line 68
|