Class: Privy::Models::NamedTokenTransferSource

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/privy/models/named_token_transfer_source.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount:, asset:, chain:) ⇒ Object

Some parameter documentations has been truncated, see Privy::Models::NamedTokenTransferSource for more details.

Source for a transfer identified by a named asset (e.g. “usdc”, “eth”). Use this variant for first-class assets maintained by Privy.

Parameters:

  • amount (String)

    Amount as a decimal string in the token’s standard unit (e.g. “1.5” for 1.5 USDC

  • asset (String)

    The asset to transfer. Supported: ‘usdc’, ‘usdb’, ‘usdt’ (stablecoins), ‘eth’ (n

  • chain (String)

    The blockchain network on which to perform the transfer. Supported chains includ



# File 'lib/privy/models/named_token_transfer_source.rb', line 29

Instance Attribute Details

#amountString

Amount as a decimal string in the token’s standard unit (e.g. “1.5” for 1.5 USDC, “0.01” for 0.01 ETH). Not in the smallest on-chain unit (wei, lamports, etc.). Maximum 100 characters.

Returns:

  • (String)


12
# File 'lib/privy/models/named_token_transfer_source.rb', line 12

required :amount, String

#assetString

The asset to transfer. Supported: ‘usdc’, ‘usdb’, ‘usdt’ (stablecoins), ‘eth’ (native Ethereum), ‘sol’ (native Solana).

Returns:

  • (String)


19
# File 'lib/privy/models/named_token_transfer_source.rb', line 19

required :asset, String

#chainString

The blockchain network on which to perform the transfer. Supported chains include: ‘ethereum’, ‘base’, ‘arbitrum’, ‘polygon’, ‘solana’, and their respective testnets.

Returns:

  • (String)


27
# File 'lib/privy/models/named_token_transfer_source.rb', line 27

required :chain, String