Class: Privy::Models::PolicyCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::PolicyCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/privy/models/policy_create_params.rb
Overview
Defined Under Namespace
Modules: Version Classes: Rule
Instance Attribute Summary collapse
-
#chain_type ⇒ Symbol, Privy::Models::WalletChainType
The wallet chain types.
-
#name ⇒ String
Name to assign to policy.
-
#owner ⇒ Privy::Models::OwnerInputUser, ...
The owner of the resource, specified as a Privy user ID, a P-256 public key, or null to remove the current owner.
-
#owner_id ⇒ String?
The key quorum ID to set as the owner of the resource.
-
#privy_idempotency_key ⇒ String?
Idempotency keys ensure API requests are executed only once within a 24-hour window.
- #rules ⇒ Array<Privy::Models::PolicyCreateParams::Rule>
-
#version ⇒ Symbol, Privy::Models::PolicyCreateParams::Version
Version of the policy.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(action:, conditions:, method_:, name:, id: nil) ⇒ Object
|
|
# File 'lib/privy/models/policy_create_params.rb', line 102
|
Instance Attribute Details
#chain_type ⇒ Symbol, Privy::Models::WalletChainType
The wallet chain types.
14 |
# File 'lib/privy/models/policy_create_params.rb', line 14 required :chain_type, enum: -> { Privy::WalletChainType } |
#name ⇒ String
Name to assign to policy.
20 |
# File 'lib/privy/models/policy_create_params.rb', line 20 required :name, String |
#owner ⇒ Privy::Models::OwnerInputUser, ...
The owner of the resource, specified as a Privy user ID, a P-256 public key, or null to remove the current owner.
38 |
# File 'lib/privy/models/policy_create_params.rb', line 38 optional :owner, union: -> { Privy::OwnerInput }, nil?: true |
#owner_id ⇒ String?
The key quorum ID to set as the owner of the resource. If you provide this, do not specify an owner.
45 |
# File 'lib/privy/models/policy_create_params.rb', line 45 optional :owner_id, String, nil?: true |
#privy_idempotency_key ⇒ String?
Idempotency keys ensure API requests are executed only once within a 24-hour window.
52 |
# File 'lib/privy/models/policy_create_params.rb', line 52 optional :privy_idempotency_key, String |
#rules ⇒ Array<Privy::Models::PolicyCreateParams::Rule>
25 |
# File 'lib/privy/models/policy_create_params.rb', line 25 required :rules, -> { Privy::Internal::Type::ArrayOf[Privy::PolicyCreateParams::Rule] } |
#version ⇒ Symbol, Privy::Models::PolicyCreateParams::Version
Version of the policy. Currently, 1.0 is the only version.
31 |
# File 'lib/privy/models/policy_create_params.rb', line 31 required :version, enum: -> { Privy::PolicyCreateParams::Version } |