Class: Privy::Models::PolicyIntentRequestDetails::Body

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/privy/models/policy_intent_request_details.rb

Overview

See Also:

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Privy::Internal::Type::BaseModel

Instance Attribute Details

#nameString?

Name to assign to policy.

Returns:

  • (String, nil)


34
# File 'lib/privy/models/policy_intent_request_details.rb', line 34

optional :name, String

#ownerPrivy::Models::OwnerInputUser, ...

The owner of the resource, specified as a Privy user ID, a P-256 public key, or null to remove the current owner.



41
# File 'lib/privy/models/policy_intent_request_details.rb', line 41

optional :owner, union: -> { Privy::OwnerInput }, nil?: true

#owner_idString?

The key quorum ID to set as the owner of the resource. If you provide this, do not specify an owner.

Returns:

  • (String, nil)


48
# File 'lib/privy/models/policy_intent_request_details.rb', line 48

optional :owner_id, String, nil?: true

#rulesArray<Privy::Models::PolicyRuleRequestBody>?

Returns:



53
# File 'lib/privy/models/policy_intent_request_details.rb', line 53

optional :rules, -> { Privy::Internal::Type::ArrayOf[Privy::PolicyRuleRequestBody] }