Class: Privy::Models::TransferIntentResponse::RequestDetails
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::TransferIntentResponse::RequestDetails
- Defined in:
- lib/privy/models/transfer_intent_response.rb
Defined Under Namespace
Modules: Method
Instance Attribute Summary collapse
-
#body ⇒ Privy::Models::TransferRequestBody
Request body for initiating a sponsored token transfer from an embedded wallet.
- #method_ ⇒ Symbol, Privy::Models::TransferIntentResponse::RequestDetails::Method
- #url ⇒ String
Instance Method Summary collapse
-
#initialize(body:, method_:, url:) ⇒ Object
constructor
The original transfer request that would be sent to the wallet transfer endpoint.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(body:, method_:, url:) ⇒ Object
The original transfer request that would be sent to the wallet transfer endpoint
|
|
# File 'lib/privy/models/transfer_intent_response.rb', line 75
|
Instance Attribute Details
#body ⇒ Privy::Models::TransferRequestBody
Request body for initiating a sponsored token transfer from an embedded wallet.
59 |
# File 'lib/privy/models/transfer_intent_response.rb', line 59 required :body, -> { Privy::TransferRequestBody } |
#method_ ⇒ Symbol, Privy::Models::TransferIntentResponse::RequestDetails::Method
64 65 66 67 68 |
# File 'lib/privy/models/transfer_intent_response.rb', line 64 required :method_, enum: -> { Privy::TransferIntentResponse::RequestDetails::Method }, api_name: :method |
#url ⇒ String
73 |
# File 'lib/privy/models/transfer_intent_response.rb', line 73 required :url, String |