Class: Privy::Models::TransferQuoteRequestBody
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::TransferQuoteRequestBody
- Defined in:
- lib/privy/models/transfer_quote_request_body.rb
Instance Attribute Summary collapse
-
#amount_type ⇒ Symbol, ...
Whether the amount refers to the input token or output token.
-
#destination ⇒ Privy::Models::TokenTransferDestination
The destination address for a token transfer.
-
#fee_configuration ⇒ Privy::Models::FeeConfiguration?
Total fees assessed on a transfer, in BPS.
-
#slippage_bps ⇒ Integer?
Maximum allowed slippage in basis points (1 bps = 0.01%).
-
#source ⇒ Privy::Models::NamedTokenTransferSource, Privy::Models::CustomTokenTransferSource
The source asset, amount, and chain for a token transfer.
Instance Method Summary collapse
-
#initialize(destination:, source:, amount_type: nil, fee_configuration: nil, slippage_bps: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see TransferQuoteRequestBody for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(destination:, source:, amount_type: nil, fee_configuration: nil, slippage_bps: nil) ⇒ Object
Some parameter documentations has been truncated, see Privy::Models::TransferQuoteRequestBody for more details.
Request body for requesting a quote for a cross-asset or cross-chain (DADC) transfer.
|
|
# File 'lib/privy/models/transfer_quote_request_body.rb', line 38
|
Instance Attribute Details
#amount_type ⇒ Symbol, ...
Whether the amount refers to the input token or output token.
24 |
# File 'lib/privy/models/transfer_quote_request_body.rb', line 24 optional :amount_type, enum: -> { Privy::AmountType } |
#destination ⇒ Privy::Models::TokenTransferDestination
The destination address for a token transfer. Optionally specify a different asset or chain for cross-asset or cross-chain transfers.
11 |
# File 'lib/privy/models/transfer_quote_request_body.rb', line 11 required :destination, -> { Privy::TokenTransferDestination } |
#fee_configuration ⇒ Privy::Models::FeeConfiguration?
Total fees assessed on a transfer, in BPS
30 |
# File 'lib/privy/models/transfer_quote_request_body.rb', line 30 optional :fee_configuration, -> { Privy::FeeConfiguration } |
#slippage_bps ⇒ Integer?
Maximum allowed slippage in basis points (1 bps = 0.01%).
36 |
# File 'lib/privy/models/transfer_quote_request_body.rb', line 36 optional :slippage_bps, Integer |
#source ⇒ Privy::Models::NamedTokenTransferSource, Privy::Models::CustomTokenTransferSource
The source asset, amount, and chain for a token transfer. Specify either ‘asset` (named) or `asset_address` (custom), not both.
18 |
# File 'lib/privy/models/transfer_quote_request_body.rb', line 18 required :source, union: -> { Privy::TokenTransferSource } |