Class: Privy::Models::TransferQuoteResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/privy/models/transfer_quote_response.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(destination:, estimated_fees:, estimated_output_amount:, expires_at:, source:, amount_type: nil) ⇒ Object

Some parameter documentations has been truncated, see Privy::Models::TransferQuoteResponse for more details.

Response containing a quote for a cross-asset or cross-chain (DADC) transfer.

Parameters:



# File 'lib/privy/models/transfer_quote_response.rb', line 44

Instance Attribute Details

#amount_typeSymbol, ...

Whether the amount refers to the input token or output token.

Returns:



42
# File 'lib/privy/models/transfer_quote_response.rb', line 42

optional :amount_type, enum: -> { Privy::AmountType }

#destinationPrivy::Models::TokenTransferDestination

The destination address for a token transfer. Optionally specify a different asset or chain for cross-asset or cross-chain transfers.



11
# File 'lib/privy/models/transfer_quote_response.rb', line 11

required :destination, -> { Privy::TokenTransferDestination }

#estimated_feesArray<Privy::Models::RelayerFee, Privy::Models::PrivyFee, Privy::Models::DeveloperFee>

Estimated fees in USD



17
# File 'lib/privy/models/transfer_quote_response.rb', line 17

required :estimated_fees, -> { Privy::Internal::Type::ArrayOf[union: Privy::FeeLineItem] }

#estimated_output_amountString

Estimated output amount in decimals

Returns:

  • (String)


23
# File 'lib/privy/models/transfer_quote_response.rb', line 23

required :estimated_output_amount, String

#expires_atFloat

Quote expiry as unix timestamp (seconds)

Returns:

  • (Float)


29
# File 'lib/privy/models/transfer_quote_response.rb', line 29

required :expires_at, Float

#sourcePrivy::Models::NamedTokenTransferSource, Privy::Models::CustomTokenTransferSource

The source asset, amount, and chain for a token transfer. Specify either ‘asset` (named) or `asset_address` (custom), not both.



36
# File 'lib/privy/models/transfer_quote_response.rb', line 36

required :source, union: -> { Privy::TokenTransferSource }