Class: Privy::Models::UnsignedStandardEthereumTransaction
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::UnsignedStandardEthereumTransaction
- Defined in:
- lib/privy/models/unsigned_standard_ethereum_transaction.rb
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
- #authorization_list ⇒ Array<Privy::Models::EthereumSign7702Authorization>?
-
#chain_id ⇒ String, ...
A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.
-
#data ⇒ String?
A hex-encoded string prefixed with ‘0x’, capped at 100002 characters (50,000 bytes).
- #from ⇒ String?
-
#gas_limit ⇒ String, ...
A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.
-
#gas_price ⇒ String, ...
A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.
-
#max_fee_per_gas ⇒ String, ...
A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.
-
#max_priority_fee_per_gas ⇒ String, ...
A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.
-
#nonce ⇒ String, ...
A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.
- #to ⇒ String?
- #type ⇒ Float, ...
-
#value ⇒ String, ...
A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.
Instance Method Summary collapse
-
#initialize(authorization_list: nil, chain_id: nil, data: nil, from: nil, gas_limit: nil, gas_price: nil, max_fee_per_gas: nil, max_priority_fee_per_gas: nil, nonce: nil, to: nil, type: nil, value: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see UnsignedStandardEthereumTransaction for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(authorization_list: nil, chain_id: nil, data: nil, from: nil, gas_limit: nil, gas_price: nil, max_fee_per_gas: nil, max_priority_fee_per_gas: nil, nonce: nil, to: nil, type: nil, value: nil) ⇒ Object
Some parameter documentations has been truncated, see Privy::Models::UnsignedStandardEthereumTransaction for more details.
An unsigned standard Ethereum transaction object. Supports EVM transaction types 0, 1, 2, and 4.
|
|
# File 'lib/privy/models/unsigned_standard_ethereum_transaction.rb', line 82
|
Instance Attribute Details
#authorization_list ⇒ Array<Privy::Models::EthereumSign7702Authorization>?
9 |
# File 'lib/privy/models/unsigned_standard_ethereum_transaction.rb', line 9 optional :authorization_list, -> { Privy::Internal::Type::ArrayOf[Privy::EthereumSign7702Authorization] } |
#chain_id ⇒ String, ...
A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.
16 |
# File 'lib/privy/models/unsigned_standard_ethereum_transaction.rb', line 16 optional :chain_id, union: -> { Privy::Quantity } |
#data ⇒ String?
A hex-encoded string prefixed with ‘0x’, capped at 100002 characters (50,000 bytes).
23 |
# File 'lib/privy/models/unsigned_standard_ethereum_transaction.rb', line 23 optional :data, String |
#from ⇒ String?
28 |
# File 'lib/privy/models/unsigned_standard_ethereum_transaction.rb', line 28 optional :from, String |
#gas_limit ⇒ String, ...
A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.
35 |
# File 'lib/privy/models/unsigned_standard_ethereum_transaction.rb', line 35 optional :gas_limit, union: -> { Privy::Quantity } |
#gas_price ⇒ String, ...
A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.
42 |
# File 'lib/privy/models/unsigned_standard_ethereum_transaction.rb', line 42 optional :gas_price, union: -> { Privy::Quantity } |
#max_fee_per_gas ⇒ String, ...
A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.
49 |
# File 'lib/privy/models/unsigned_standard_ethereum_transaction.rb', line 49 optional :max_fee_per_gas, union: -> { Privy::Quantity } |
#max_priority_fee_per_gas ⇒ String, ...
A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.
56 |
# File 'lib/privy/models/unsigned_standard_ethereum_transaction.rb', line 56 optional :max_priority_fee_per_gas, union: -> { Privy::Quantity } |
#nonce ⇒ String, ...
A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.
63 |
# File 'lib/privy/models/unsigned_standard_ethereum_transaction.rb', line 63 optional :nonce, union: -> { Privy::Quantity } |
#to ⇒ String?
68 |
# File 'lib/privy/models/unsigned_standard_ethereum_transaction.rb', line 68 optional :to, String |
#type ⇒ Float, ...
73 |
# File 'lib/privy/models/unsigned_standard_ethereum_transaction.rb', line 73 optional :type, enum: -> { Privy::UnsignedStandardEthereumTransaction::Type } |