Class: Privy::Models::UnsignedTempoTransaction
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::UnsignedTempoTransaction
- Defined in:
- lib/privy/models/unsigned_tempo_transaction.rb
Defined Under Namespace
Modules: Type Classes: AccessList
Instance Attribute Summary collapse
- #aa_authorization_list ⇒ Array<Privy::Models::TempoAaAuthorization>?
- #access_list ⇒ Array<Privy::Models::UnsignedTempoTransaction::AccessList>?
- #calls ⇒ Array<Privy::Models::TempoCall>
-
#chain_id ⇒ String, ...
A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.
-
#fee_payer_signature ⇒ Privy::Models::TempoFeePayerSignature?
A fee payer signature for sponsored Tempo transactions (secp256k1 only).
- #fee_token ⇒ String?
- #from ⇒ String?
-
#gas_limit ⇒ String, ...
A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.
-
#max_fee_per_gas ⇒ String, ...
A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.
-
#max_priority_fee_per_gas ⇒ String, ...
A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.
-
#nonce ⇒ String, ...
A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.
-
#nonce_key ⇒ String, ...
A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.
- #type ⇒ Float, Privy::Models::UnsignedTempoTransaction::Type
-
#valid_after ⇒ String, ...
A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.
-
#valid_before ⇒ String, ...
A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(calls:, type:, aa_authorization_list: nil, access_list: nil, chain_id: nil, fee_payer_signature: nil, fee_token: nil, from: nil, gas_limit: nil, max_fee_per_gas: nil, max_priority_fee_per_gas: nil, nonce: nil, nonce_key: nil, valid_after: nil, valid_before: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see UnsignedTempoTransaction for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(calls:, type:, aa_authorization_list: nil, access_list: nil, chain_id: nil, fee_payer_signature: nil, fee_token: nil, from: nil, gas_limit: nil, max_fee_per_gas: nil, max_priority_fee_per_gas: nil, nonce: nil, nonce_key: nil, valid_after: nil, valid_before: nil) ⇒ Object
Some parameter documentations has been truncated, see Privy::Models::UnsignedTempoTransaction for more details.
An unsigned Tempo transaction (type 118) with batched calls.
|
|
# File 'lib/privy/models/unsigned_tempo_transaction.rb', line 98
|
Instance Attribute Details
#aa_authorization_list ⇒ Array<Privy::Models::TempoAaAuthorization>?
19 |
# File 'lib/privy/models/unsigned_tempo_transaction.rb', line 19 optional :aa_authorization_list, -> { Privy::Internal::Type::ArrayOf[Privy::TempoAaAuthorization] } |
#access_list ⇒ Array<Privy::Models::UnsignedTempoTransaction::AccessList>?
24 |
# File 'lib/privy/models/unsigned_tempo_transaction.rb', line 24 optional :access_list, -> { Privy::Internal::Type::ArrayOf[Privy::UnsignedTempoTransaction::AccessList] } |
#calls ⇒ Array<Privy::Models::TempoCall>
9 |
# File 'lib/privy/models/unsigned_tempo_transaction.rb', line 9 required :calls, -> { Privy::Internal::Type::ArrayOf[Privy::TempoCall] } |
#chain_id ⇒ String, ...
A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.
31 |
# File 'lib/privy/models/unsigned_tempo_transaction.rb', line 31 optional :chain_id, union: -> { Privy::Quantity } |
#fee_payer_signature ⇒ Privy::Models::TempoFeePayerSignature?
A fee payer signature for sponsored Tempo transactions (secp256k1 only).
37 |
# File 'lib/privy/models/unsigned_tempo_transaction.rb', line 37 optional :fee_payer_signature, -> { Privy::TempoFeePayerSignature } |
#fee_token ⇒ String?
42 |
# File 'lib/privy/models/unsigned_tempo_transaction.rb', line 42 optional :fee_token, String |
#from ⇒ String?
47 |
# File 'lib/privy/models/unsigned_tempo_transaction.rb', line 47 optional :from, String |
#gas_limit ⇒ String, ...
A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.
54 |
# File 'lib/privy/models/unsigned_tempo_transaction.rb', line 54 optional :gas_limit, union: -> { Privy::Quantity } |
#max_fee_per_gas ⇒ String, ...
A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.
61 |
# File 'lib/privy/models/unsigned_tempo_transaction.rb', line 61 optional :max_fee_per_gas, union: -> { Privy::Quantity } |
#max_priority_fee_per_gas ⇒ String, ...
A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.
68 |
# File 'lib/privy/models/unsigned_tempo_transaction.rb', line 68 optional :max_priority_fee_per_gas, union: -> { Privy::Quantity } |
#nonce ⇒ String, ...
A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.
75 |
# File 'lib/privy/models/unsigned_tempo_transaction.rb', line 75 optional :nonce, union: -> { Privy::Quantity } |
#nonce_key ⇒ String, ...
A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.
82 |
# File 'lib/privy/models/unsigned_tempo_transaction.rb', line 82 optional :nonce_key, union: -> { Privy::Quantity } |
#type ⇒ Float, Privy::Models::UnsignedTempoTransaction::Type
14 |
# File 'lib/privy/models/unsigned_tempo_transaction.rb', line 14 required :type, enum: -> { Privy::UnsignedTempoTransaction::Type } |
Class Method Details
.values ⇒ Array<Float>
|
|
# File 'lib/privy/models/unsigned_tempo_transaction.rb', line 140
|