Class: Privy::Models::UpdateConditionSetRequestBody
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::UpdateConditionSetRequestBody
- Defined in:
- lib/privy/models/update_condition_set_request_body.rb
Instance Attribute Summary collapse
-
#name ⇒ String?
Name to assign to condition set.
-
#owner ⇒ Privy::Models::OwnerInputUser, ...
The owner of the resource, specified as a Privy user ID, a P-256 public key, or null to remove the current owner.
-
#owner_id ⇒ String?
The key quorum ID to set as the owner of the resource.
Instance Method Summary collapse
-
#initialize(name: nil, owner: nil, owner_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see UpdateConditionSetRequestBody for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(name: nil, owner: nil, owner_id: nil) ⇒ Object
Some parameter documentations has been truncated, see Privy::Models::UpdateConditionSetRequestBody for more details.
Request body for updating a condition set. At least one field must be provided. ‘owner` and `owner_id` are mutually exclusive.
|
|
# File 'lib/privy/models/update_condition_set_request_body.rb', line 26
|
Instance Attribute Details
#name ⇒ String?
Name to assign to condition set.
10 |
# File 'lib/privy/models/update_condition_set_request_body.rb', line 10 optional :name, String |
#owner ⇒ Privy::Models::OwnerInputUser, ...
The owner of the resource, specified as a Privy user ID, a P-256 public key, or null to remove the current owner.
17 |
# File 'lib/privy/models/update_condition_set_request_body.rb', line 17 optional :owner, union: -> { Privy::OwnerInput }, nil?: true |
#owner_id ⇒ String?
The key quorum ID to set as the owner of the resource. If you provide this, do not specify an owner.
24 |
# File 'lib/privy/models/update_condition_set_request_body.rb', line 24 optional :owner_id, String, nil?: true |