Class: Privy::Models::UserCreateParams::Wallet
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::UserCreateParams::Wallet
- Defined in:
- lib/privy/models/user_create_params.rb
Defined Under Namespace
Classes: AdditionalSigner
Instance Attribute Summary collapse
-
#additional_signers ⇒ Array<Privy::Models::UserCreateParams::Wallet::AdditionalSigner>?
Additional signers for the wallet.
-
#chain_type ⇒ Symbol, Privy::Models::WalletChainType
The wallet chain types.
-
#create_smart_wallet ⇒ Boolean?
Create a smart wallet with this wallet as the signer.
-
#policy_ids ⇒ Array<String>?
Policy IDs to enforce on the wallet.
Instance Method Summary collapse
- #initialize(linked_accounts:, custom_metadata: nil, wallets: nil, request_options: {}) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(linked_accounts:, custom_metadata: nil, wallets: nil, request_options: {}) ⇒ Object
36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/privy/models/user_create_params.rb', line 36 class Wallet < Privy::Internal::Type::BaseModel # @!attribute chain_type # The wallet chain types. # # @return [Symbol, Privy::Models::WalletChainType] required :chain_type, enum: -> { Privy::WalletChainType } # @!attribute additional_signers # Additional signers for the wallet. # # @return [Array<Privy::Models::UserCreateParams::Wallet::AdditionalSigner>, nil] optional :additional_signers, -> { Privy::Internal::Type::ArrayOf[Privy::UserCreateParams::Wallet::AdditionalSigner] } # @!attribute create_smart_wallet # Create a smart wallet with this wallet as the signer. Only supported for wallets # with `chain_type: "ethereum"`. # # @return [Boolean, nil] optional :create_smart_wallet, Privy::Internal::Type::Boolean # @!attribute policy_ids # Policy IDs to enforce on the wallet. Currently, only one policy is supported per # wallet. # # @return [Array<String>, nil] optional :policy_ids, Privy::Internal::Type::ArrayOf[String] # @!method initialize(chain_type:, additional_signers: nil, create_smart_wallet: nil, policy_ids: nil) # Some parameter documentations has been truncated, see # {Privy::Models::UserCreateParams::Wallet} for more details. # # @param chain_type [Symbol, Privy::Models::WalletChainType] The wallet chain types. # # @param additional_signers [Array<Privy::Models::UserCreateParams::Wallet::AdditionalSigner>] Additional signers for the wallet. # # @param create_smart_wallet [Boolean] Create a smart wallet with this wallet as the signer. Only supported for wallets # # @param policy_ids [Array<String>] Policy IDs to enforce on the wallet. Currently, only one policy is supported per class AdditionalSigner < Privy::Internal::Type::BaseModel # @!attribute signer_id # A unique identifier for a key quorum. # # @return [String] required :signer_id, String # @!attribute override_policy_ids # The array of policy IDs that will be applied to wallet requests. If specified, # this will override the base policy IDs set on the wallet. Currently, only one # policy is supported per signer. # # @return [Array<String>, nil] optional :override_policy_ids, Privy::Internal::Type::ArrayOf[String] # @!method initialize(signer_id:, override_policy_ids: nil) # Some parameter documentations has been truncated, see # {Privy::Models::UserCreateParams::Wallet::AdditionalSigner} for more details. # # @param signer_id [String] A unique identifier for a key quorum. # # @param override_policy_ids [Array<String>] The array of policy IDs that will be applied to wallet requests. If specified, t end end |
Instance Attribute Details
#additional_signers ⇒ Array<Privy::Models::UserCreateParams::Wallet::AdditionalSigner>?
Additional signers for the wallet.
47 48 |
# File 'lib/privy/models/user_create_params.rb', line 47 optional :additional_signers, -> { Privy::Internal::Type::ArrayOf[Privy::UserCreateParams::Wallet::AdditionalSigner] } |
#chain_type ⇒ Symbol, Privy::Models::WalletChainType
The wallet chain types.
41 |
# File 'lib/privy/models/user_create_params.rb', line 41 required :chain_type, enum: -> { Privy::WalletChainType } |