Class: Privy::Models::Wallet
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::Wallet
- Defined in:
- lib/privy/models/wallet.rb
Overview
Instance Attribute Summary collapse
-
#additional_signers ⇒ Array<Privy::Models::WalletAdditionalSignerItem>
Additional signers for the wallet.
-
#address ⇒ String
Address of the wallet.
-
#authorization_threshold ⇒ Float?
The number of keys that must sign for an action to be valid.
-
#chain_type ⇒ Symbol, Privy::Models::WalletChainType
The wallet chain types.
-
#created_at ⇒ Float
Unix timestamp of when the wallet was created in milliseconds.
-
#custody ⇒ Privy::Models::WalletCustodian?
Information about the custodian managing this wallet.
-
#display_name ⇒ String?
A human-readable label for the wallet.
-
#exported_at ⇒ Float?
Unix timestamp of when the wallet was exported in milliseconds, if the wallet was exported.
-
#external_id ⇒ String?
A customer-provided identifier for mapping to external systems.
-
#id ⇒ String
Unique ID of the wallet.
-
#imported_at ⇒ Float?
Unix timestamp of when the wallet was imported in milliseconds, if the wallet was imported.
-
#owner_id ⇒ String?
The key quorum ID of the owner of the wallet.
-
#policy_ids ⇒ Array<String>
List of policy IDs for policies that are enforced on the wallet.
-
#public_key ⇒ String?
The compressed, raw public key for the wallet along the chain cryptographic curve.
Instance Method Summary collapse
-
#initialize(id:, additional_signers:, address:, chain_type:, created_at:, exported_at:, imported_at:, owner_id:, policy_ids:, authorization_threshold: nil, custody: nil, display_name: nil, external_id: nil, public_key: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Wallet for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, additional_signers:, address:, chain_type:, created_at:, exported_at:, imported_at:, owner_id:, policy_ids:, authorization_threshold: nil, custody: nil, display_name: nil, external_id: nil, public_key: nil) ⇒ Object
Some parameter documentations has been truncated, see Privy::Models::Wallet for more details.
A wallet managed by Privy’s wallet infrastructure.
|
|
# File 'lib/privy/models/wallet.rb', line 96
|
Instance Attribute Details
#additional_signers ⇒ Array<Privy::Models::WalletAdditionalSignerItem>
Additional signers for the wallet.
18 |
# File 'lib/privy/models/wallet.rb', line 18 required :additional_signers, -> { Privy::Internal::Type::ArrayOf[Privy::WalletAdditionalSignerItem] } |
#address ⇒ String
Address of the wallet.
24 |
# File 'lib/privy/models/wallet.rb', line 24 required :address, String |
#authorization_threshold ⇒ Float?
The number of keys that must sign for an action to be valid.
68 |
# File 'lib/privy/models/wallet.rb', line 68 optional :authorization_threshold, Float |
#chain_type ⇒ Symbol, Privy::Models::WalletChainType
The wallet chain types.
30 |
# File 'lib/privy/models/wallet.rb', line 30 required :chain_type, enum: -> { Privy::WalletChainType } |
#created_at ⇒ Float
Unix timestamp of when the wallet was created in milliseconds.
36 |
# File 'lib/privy/models/wallet.rb', line 36 required :created_at, Float |
#custody ⇒ Privy::Models::WalletCustodian?
Information about the custodian managing this wallet.
74 |
# File 'lib/privy/models/wallet.rb', line 74 optional :custody, -> { Privy::WalletCustodian } |
#display_name ⇒ String?
A human-readable label for the wallet.
80 |
# File 'lib/privy/models/wallet.rb', line 80 optional :display_name, String |
#exported_at ⇒ Float?
Unix timestamp of when the wallet was exported in milliseconds, if the wallet was exported.
43 |
# File 'lib/privy/models/wallet.rb', line 43 required :exported_at, Float, nil?: true |
#external_id ⇒ String?
A customer-provided identifier for mapping to external systems. Write-once, set only at creation.
87 |
# File 'lib/privy/models/wallet.rb', line 87 optional :external_id, String |
#id ⇒ String
Unique ID of the wallet. This will be the primary identifier when using the wallet in the future.
12 |
# File 'lib/privy/models/wallet.rb', line 12 required :id, String |
#imported_at ⇒ Float?
Unix timestamp of when the wallet was imported in milliseconds, if the wallet was imported.
50 |
# File 'lib/privy/models/wallet.rb', line 50 required :imported_at, Float, nil?: true |
#owner_id ⇒ String?
The key quorum ID of the owner of the wallet.
56 |
# File 'lib/privy/models/wallet.rb', line 56 required :owner_id, String, nil?: true |
#policy_ids ⇒ Array<String>
List of policy IDs for policies that are enforced on the wallet.
62 |
# File 'lib/privy/models/wallet.rb', line 62 required :policy_ids, Privy::Internal::Type::ArrayOf[String] |
#public_key ⇒ String?
The compressed, raw public key for the wallet along the chain cryptographic curve.
94 |
# File 'lib/privy/models/wallet.rb', line 94 optional :public_key, String |