Class: Privy::Models::WalletActionEarnWithdrawRejectedWebhookPayload

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/privy/models/wallet_action_earn_withdraw_rejected_webhook_payload.rb

Defined Under Namespace

Modules: Status, Type

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(action_type:, asset_address:, caip2:, failure_reason:, raw_amount:, status:, steps:, type:, vault_address:, vault_id:, wallet_action_id:, wallet_id:, amount: nil, asset: nil, decimals: nil) ⇒ Object

Some parameter documentations has been truncated, see Privy::Models::WalletActionEarnWithdrawRejectedWebhookPayload for more details.

Payload for the wallet_action.earn_withdraw.rejected webhook event.

Parameters:



# File 'lib/privy/models/wallet_action_earn_withdraw_rejected_webhook_payload.rb', line 99

Instance Attribute Details

#action_typeSymbol, Privy::Models::WalletActionType

Type of wallet action

Returns:



10
# File 'lib/privy/models/wallet_action_earn_withdraw_rejected_webhook_payload.rb', line 10

required :action_type, enum: -> { Privy::WalletActionType }

#amountString?

Human-readable decimal amount of asset withdrawn (e.g. “1.5”). Only present when the token is known in the asset registry.

Returns:

  • (String, nil)


83
# File 'lib/privy/models/wallet_action_earn_withdraw_rejected_webhook_payload.rb', line 83

optional :amount, String

#assetString?

Asset identifier (e.g. “usdc”, “eth”). Only present when the token is known in the asset registry.

Returns:

  • (String, nil)


90
# File 'lib/privy/models/wallet_action_earn_withdraw_rejected_webhook_payload.rb', line 90

optional :asset, String

#asset_addressString

Underlying asset token address.

Returns:

  • (String)


16
# File 'lib/privy/models/wallet_action_earn_withdraw_rejected_webhook_payload.rb', line 16

required :asset_address, String

#caip2String

CAIP-2 chain identifier.

Returns:

  • (String)


22
# File 'lib/privy/models/wallet_action_earn_withdraw_rejected_webhook_payload.rb', line 22

required :caip2, String

#decimalsInteger?

Number of decimals for the underlying asset (e.g. 6 for USDC, 18 for ETH). Only present when the token is known in the asset registry.

Returns:

  • (Integer, nil)


97
# File 'lib/privy/models/wallet_action_earn_withdraw_rejected_webhook_payload.rb', line 97

optional :decimals, Integer

#failure_reasonPrivy::Models::FailureReason

A description of why a wallet action (or a step within a wallet action) failed.



28
# File 'lib/privy/models/wallet_action_earn_withdraw_rejected_webhook_payload.rb', line 28

required :failure_reason, -> { Privy::FailureReason }

#raw_amountString

Base-unit amount of asset withdrawn (e.g. “1500000”).

Returns:

  • (String)


34
# File 'lib/privy/models/wallet_action_earn_withdraw_rejected_webhook_payload.rb', line 34

required :raw_amount, String

#statusSymbol, Privy::Models::WalletActionEarnWithdrawRejectedWebhookPayload::Status

The status of the wallet action.



40
# File 'lib/privy/models/wallet_action_earn_withdraw_rejected_webhook_payload.rb', line 40

required :status, enum: -> { Privy::WalletActionEarnWithdrawRejectedWebhookPayload::Status }

#typeSymbol, Privy::Models::WalletActionEarnWithdrawRejectedWebhookPayload::Type

The type of webhook event.



52
# File 'lib/privy/models/wallet_action_earn_withdraw_rejected_webhook_payload.rb', line 52

required :type, enum: -> { Privy::WalletActionEarnWithdrawRejectedWebhookPayload::Type }

#vault_addressString

ERC-4626 vault contract address.

Returns:

  • (String)


58
# File 'lib/privy/models/wallet_action_earn_withdraw_rejected_webhook_payload.rb', line 58

required :vault_address, String

#vault_idString

The vault ID.

Returns:

  • (String)


64
# File 'lib/privy/models/wallet_action_earn_withdraw_rejected_webhook_payload.rb', line 64

required :vault_id, String

#wallet_action_idString

The ID of the wallet action.

Returns:

  • (String)


70
# File 'lib/privy/models/wallet_action_earn_withdraw_rejected_webhook_payload.rb', line 70

required :wallet_action_id, String

#wallet_idString

The ID of the wallet involved in the action.

Returns:

  • (String)


76
# File 'lib/privy/models/wallet_action_earn_withdraw_rejected_webhook_payload.rb', line 76

required :wallet_id, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/privy/models/wallet_action_earn_withdraw_rejected_webhook_payload.rb', line 144