Module: Privy::Models::WalletAuthenticateBoundRequestBody
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/privy/models/wallet_authenticate_bound_request_body.rb,
sig/privy/models/wallet_authenticate_bound_request_body.rbs
Overview
Request body for creating a user signing key scoped to specific bindings. The returned USK can only authorize the bound values and cannot sign other RPC requests.
Class Method Summary collapse
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.variants ⇒ Array(Privy::Models::WalletAuthenticateBoundEncryptedRequestBody, Privy::Models::WalletAuthenticateBoundUnencryptedRequestBody)
|
|
# File 'lib/privy/models/wallet_authenticate_bound_request_body.rb', line 17
|
Instance Method Details
#self?.variants ⇒ ::Array[Privy::Models::wallet_authenticate_bound_request_body]
10 |
# File 'sig/privy/models/wallet_authenticate_bound_request_body.rbs', line 10
def self?.variants: -> ::Array[Privy::Models::wallet_authenticate_bound_request_body]
|