Class: Privy::Models::WalletBatchCreateResult::WalletBatchCreateFailure
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::WalletBatchCreateResult::WalletBatchCreateFailure
- Defined in:
- lib/privy/models/wallet_batch_create_result.rb
Defined Under Namespace
Modules: Success
Instance Attribute Summary collapse
-
#code ⇒ String
A PrivyErrorCode string identifying the error type (e.g., “invalid_data”, “resource_conflict”).
-
#error ⇒ String
A human-readable error message with details about what went wrong.
-
#index ⇒ Float
The index of the wallet in the original request array.
- #success ⇒ Boolean, Privy::Models::WalletBatchCreateResult::WalletBatchCreateFailure::Success
Instance Method Summary collapse
-
#initialize(code:, error:, index:, success:) ⇒ Object
constructor
Some parameter documentations has been truncated, see WalletBatchCreateFailure for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(code:, error:, index:, success:) ⇒ Object
Some parameter documentations has been truncated, see Privy::Models::WalletBatchCreateResult::WalletBatchCreateFailure for more details.
A failed wallet creation result within a batch operation.
|
|
# File 'lib/privy/models/wallet_batch_create_result.rb', line 78
|
Instance Attribute Details
#code ⇒ String
A PrivyErrorCode string identifying the error type (e.g., “invalid_data”, “resource_conflict”).
59 |
# File 'lib/privy/models/wallet_batch_create_result.rb', line 59 required :code, String |
#error ⇒ String
A human-readable error message with details about what went wrong.
65 |
# File 'lib/privy/models/wallet_batch_create_result.rb', line 65 required :error, String |
#index ⇒ Float
The index of the wallet in the original request array.
71 |
# File 'lib/privy/models/wallet_batch_create_result.rb', line 71 required :index, Float |
#success ⇒ Boolean, Privy::Models::WalletBatchCreateResult::WalletBatchCreateFailure::Success
76 |
# File 'lib/privy/models/wallet_batch_create_result.rb', line 76 required :success, enum: -> { Privy::WalletBatchCreateResult::WalletBatchCreateFailure::Success } |