Class: Privy::Models::WalletBatchCreateResult::WalletBatchCreateSuccess
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::WalletBatchCreateResult::WalletBatchCreateSuccess
- Defined in:
- lib/privy/models/wallet_batch_create_result.rb
Defined Under Namespace
Modules: Success
Instance Attribute Summary collapse
-
#index ⇒ Float
The index of the wallet in the original request array.
- #success ⇒ Boolean, Privy::Models::WalletBatchCreateResult::WalletBatchCreateSuccess::Success
-
#wallet ⇒ Privy::Models::Wallet
A wallet managed by Privy’s wallet infrastructure.
Instance Method Summary collapse
-
#initialize(index:, success:, wallet:) ⇒ Object
constructor
A successful wallet creation result within a batch operation.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(index:, success:, wallet:) ⇒ Object
A successful wallet creation result within a batch operation.
|
|
# File 'lib/privy/models/wallet_batch_create_result.rb', line 33
|
Instance Attribute Details
#index ⇒ Float
The index of the wallet in the original request array.
20 |
# File 'lib/privy/models/wallet_batch_create_result.rb', line 20 required :index, Float |
#success ⇒ Boolean, Privy::Models::WalletBatchCreateResult::WalletBatchCreateSuccess::Success
25 |
# File 'lib/privy/models/wallet_batch_create_result.rb', line 25 required :success, enum: -> { Privy::WalletBatchCreateResult::WalletBatchCreateSuccess::Success } |
#wallet ⇒ Privy::Models::Wallet
A wallet managed by Privy’s wallet infrastructure.
31 |
# File 'lib/privy/models/wallet_batch_create_result.rb', line 31 required :wallet, -> { Privy::Wallet } |