Class: Privy::Models::WalletBatchItemInput
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::WalletBatchItemInput
- Defined in:
- lib/privy/models/wallet_batch_item_input.rb
Instance Attribute Summary collapse
-
#additional_signers ⇒ Array<Privy::Models::AdditionalSignerItemInput>?
Additional signers for the wallet.
-
#chain_type ⇒ Symbol, Privy::Models::WalletChainType
The wallet chain types.
-
#display_name ⇒ String?
A human-readable label for the wallet.
-
#external_id ⇒ String?
A customer-provided identifier for mapping to external systems.
-
#owner ⇒ Privy::Models::OwnerInputUser, ...
The owner of the resource, specified as a Privy user ID, a P-256 public key, or null to remove the current owner.
-
#owner_id ⇒ String?
The key quorum ID to set as the owner of the resource.
-
#policy_ids ⇒ Array<String>?
List of policy IDs for policies that should be enforced on the wallet.
Instance Method Summary collapse
-
#initialize(chain_type:, additional_signers: nil, display_name: nil, external_id: nil, owner: nil, owner_id: nil, policy_ids: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see WalletBatchItemInput for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(chain_type:, additional_signers: nil, display_name: nil, external_id: nil, owner: nil, owner_id: nil, policy_ids: nil) ⇒ Object
Some parameter documentations has been truncated, see Privy::Models::WalletBatchItemInput for more details.
Input for a single wallet in a batch creation request.
|
|
# File 'lib/privy/models/wallet_batch_item_input.rb', line 53
|
Instance Attribute Details
#additional_signers ⇒ Array<Privy::Models::AdditionalSignerItemInput>?
Additional signers for the wallet.
16 |
# File 'lib/privy/models/wallet_batch_item_input.rb', line 16 optional :additional_signers, -> { Privy::Internal::Type::ArrayOf[Privy::AdditionalSignerItemInput] } |
#chain_type ⇒ Symbol, Privy::Models::WalletChainType
The wallet chain types.
10 |
# File 'lib/privy/models/wallet_batch_item_input.rb', line 10 required :chain_type, enum: -> { Privy::WalletChainType } |
#display_name ⇒ String?
A human-readable label for the wallet.
22 |
# File 'lib/privy/models/wallet_batch_item_input.rb', line 22 optional :display_name, String |
#external_id ⇒ String?
A customer-provided identifier for mapping to external systems. URL-safe characters only ([a-zA-Z0-9_-]), max 64 chars. Write-once: cannot be changed after creation.
30 |
# File 'lib/privy/models/wallet_batch_item_input.rb', line 30 optional :external_id, String |
#owner ⇒ Privy::Models::OwnerInputUser, ...
The owner of the resource, specified as a Privy user ID, a P-256 public key, or null to remove the current owner.
37 |
# File 'lib/privy/models/wallet_batch_item_input.rb', line 37 optional :owner, union: -> { Privy::OwnerInput }, nil?: true |
#owner_id ⇒ String?
The key quorum ID to set as the owner of the resource. If you provide this, do not specify an owner.
44 |
# File 'lib/privy/models/wallet_batch_item_input.rb', line 44 optional :owner_id, String, nil?: true |