Class: Privy::Models::WalletCreateWalletsWithRecoveryParams::Wallet
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::WalletCreateWalletsWithRecoveryParams::Wallet
- Defined in:
- lib/privy/models/wallet_create_wallets_with_recovery_params.rb
Instance Attribute Summary collapse
-
#chain_type ⇒ Symbol, Privy::Models::WalletChainType
The wallet chain types.
-
#display_name ⇒ String?
A human-readable label for the wallet.
-
#external_id ⇒ String?
A customer-provided identifier for mapping to external systems.
-
#policy_ids ⇒ Array<String>?
An optional list of up to one policy ID to enforce on the wallet.
Instance Method Summary collapse
-
#initialize(chain_type:, display_name: nil, external_id: nil, policy_ids: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Wallet for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(chain_type:, display_name: nil, external_id: nil, policy_ids: nil) ⇒ Object
Some parameter documentations has been truncated, see Privy::Models::WalletCreateWalletsWithRecoveryParams::Wallet for more details.
|
|
# File 'lib/privy/models/wallet_create_wallets_with_recovery_params.rb', line 97
|
Instance Attribute Details
#chain_type ⇒ Symbol, Privy::Models::WalletChainType
The wallet chain types.
75 |
# File 'lib/privy/models/wallet_create_wallets_with_recovery_params.rb', line 75 required :chain_type, enum: -> { Privy::WalletChainType } |
#display_name ⇒ String?
A human-readable label for the wallet.
81 |
# File 'lib/privy/models/wallet_create_wallets_with_recovery_params.rb', line 81 optional :display_name, String |
#external_id ⇒ String?
A customer-provided identifier for mapping to external systems. URL-safe characters only ([a-zA-Z0-9_-]), max 64 chars. Write-once: cannot be changed after creation.
89 |
# File 'lib/privy/models/wallet_create_wallets_with_recovery_params.rb', line 89 optional :external_id, String |