Class: Privy::Models::WalletCreationInput
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::WalletCreationInput
- Defined in:
- lib/privy/models/wallet_creation_input.rb
Instance Attribute Summary collapse
-
#additional_signers ⇒ Array<Privy::Models::WalletCreationAdditionalSignerItem>?
Additional signers for the wallet.
-
#chain_type ⇒ Symbol, Privy::Models::WalletChainType
The wallet chain types.
-
#create_smart_wallet ⇒ Boolean?
Create a smart wallet with this wallet as the signer.
-
#policy_ids ⇒ Array<String>?
Policy IDs to enforce on the wallet.
Instance Method Summary collapse
-
#initialize(chain_type:, additional_signers: nil, create_smart_wallet: nil, policy_ids: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see WalletCreationInput for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(chain_type:, additional_signers: nil, create_smart_wallet: nil, policy_ids: nil) ⇒ Object
Some parameter documentations has been truncated, see Privy::Models::WalletCreationInput for more details.
The fields on wallet creation that can be specified when creating a user-controlled embedded server wallet.
|
|
# File 'lib/privy/models/wallet_creation_input.rb', line 33
|
Instance Attribute Details
#additional_signers ⇒ Array<Privy::Models::WalletCreationAdditionalSignerItem>?
Additional signers for the wallet.
16 17 |
# File 'lib/privy/models/wallet_creation_input.rb', line 16 optional :additional_signers, -> { Privy::Internal::Type::ArrayOf[Privy::WalletCreationAdditionalSignerItem] } |
#chain_type ⇒ Symbol, Privy::Models::WalletChainType
The wallet chain types.
10 |
# File 'lib/privy/models/wallet_creation_input.rb', line 10 required :chain_type, enum: -> { Privy::WalletChainType } |