Class: Privy::Models::WalletSubmitImportParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::WalletSubmitImportParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/privy/models/wallet_submit_import_params.rb
Overview
Defined Under Namespace
Modules: Wallet
Instance Attribute Summary collapse
-
#additional_signers ⇒ Array<Privy::Models::AdditionalSignerItemInput>?
Additional signers for the wallet.
-
#display_name ⇒ String?
A human-readable label for the wallet.
-
#external_id ⇒ String?
A customer-provided identifier for mapping to external systems.
-
#owner ⇒ Privy::Models::OwnerInputUser, ...
The owner of the resource, specified as a Privy user ID, a P-256 public key, or null to remove the current owner.
-
#owner_id ⇒ String?
The key quorum ID to set as the owner of the resource.
-
#policy_ids ⇒ Array<String>?
An optional list of up to one policy ID to enforce on the wallet.
-
#wallet ⇒ Privy::Models::HDSubmitInput, Privy::Models::PrivateKeySubmitInput
The submission input for importing an HD wallet.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(wallet:, additional_signers: nil, display_name: nil, external_id: nil, owner: nil, owner_id: nil, policy_ids: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see WalletSubmitImportParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(wallet:, additional_signers: nil, display_name: nil, external_id: nil, owner: nil, owner_id: nil, policy_ids: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Privy::Models::WalletSubmitImportParams for more details.
|
|
# File 'lib/privy/models/wallet_submit_import_params.rb', line 56
|
Instance Attribute Details
#additional_signers ⇒ Array<Privy::Models::AdditionalSignerItemInput>?
Additional signers for the wallet.
20 |
# File 'lib/privy/models/wallet_submit_import_params.rb', line 20 optional :additional_signers, -> { Privy::Internal::Type::ArrayOf[Privy::AdditionalSignerItemInput] } |
#display_name ⇒ String?
A human-readable label for the wallet.
26 |
# File 'lib/privy/models/wallet_submit_import_params.rb', line 26 optional :display_name, String |
#external_id ⇒ String?
A customer-provided identifier for mapping to external systems. URL-safe characters only ([a-zA-Z0-9_-]), max 64 chars. Write-once: cannot be changed after creation.
34 |
# File 'lib/privy/models/wallet_submit_import_params.rb', line 34 optional :external_id, String |
#owner ⇒ Privy::Models::OwnerInputUser, ...
The owner of the resource, specified as a Privy user ID, a P-256 public key, or null to remove the current owner.
41 |
# File 'lib/privy/models/wallet_submit_import_params.rb', line 41 optional :owner, union: -> { Privy::OwnerInput }, nil?: true |
#owner_id ⇒ String?
The key quorum ID to set as the owner of the resource. If you provide this, do not specify an owner.
48 |
# File 'lib/privy/models/wallet_submit_import_params.rb', line 48 optional :owner_id, String, nil?: true |
#policy_ids ⇒ Array<String>?
An optional list of up to one policy ID to enforce on the wallet.
54 |
# File 'lib/privy/models/wallet_submit_import_params.rb', line 54 optional :policy_ids, Privy::Internal::Type::ArrayOf[String] |
#wallet ⇒ Privy::Models::HDSubmitInput, Privy::Models::PrivateKeySubmitInput
The submission input for importing an HD wallet.
14 |
# File 'lib/privy/models/wallet_submit_import_params.rb', line 14 required :wallet, union: -> { Privy::WalletSubmitImportParams::Wallet } |