Class: Privy::Models::WalletUpdateRequestBody
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::WalletUpdateRequestBody
- Defined in:
- lib/privy/models/wallet_update_request_body.rb
Direct Known Subclasses
Instance Attribute Summary collapse
-
#additional_signers ⇒ Array<Privy::Models::AdditionalSignerItemInput>?
Additional signers for the wallet.
-
#display_name ⇒ String?
A human-readable label for the wallet.
-
#owner ⇒ Privy::Models::OwnerInputUser, ...
The owner of the resource, specified as a Privy user ID, a P-256 public key, or null to remove the current owner.
-
#owner_id ⇒ String?
The key quorum ID to set as the owner of the resource.
-
#policy_ids ⇒ Array<String>?
New policy IDs to enforce on the wallet.
Instance Method Summary collapse
-
#initialize(additional_signers: nil, display_name: nil, owner: nil, owner_id: nil, policy_ids: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see WalletUpdateRequestBody for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(additional_signers: nil, display_name: nil, owner: nil, owner_id: nil, policy_ids: nil) ⇒ Object
Some parameter documentations has been truncated, see Privy::Models::WalletUpdateRequestBody for more details.
Request body for updating a wallet. ‘owner` and `owner_id` are mutually exclusive.
|
|
# File 'lib/privy/models/wallet_update_request_body.rb', line 39
|
Instance Attribute Details
#additional_signers ⇒ Array<Privy::Models::AdditionalSignerItemInput>?
Additional signers for the wallet.
10 |
# File 'lib/privy/models/wallet_update_request_body.rb', line 10 optional :additional_signers, -> { Privy::Internal::Type::ArrayOf[Privy::AdditionalSignerItemInput] } |
#display_name ⇒ String?
A human-readable label for the wallet. Set to null to clear.
16 |
# File 'lib/privy/models/wallet_update_request_body.rb', line 16 optional :display_name, String, nil?: true |
#owner ⇒ Privy::Models::OwnerInputUser, ...
The owner of the resource, specified as a Privy user ID, a P-256 public key, or null to remove the current owner.
23 |
# File 'lib/privy/models/wallet_update_request_body.rb', line 23 optional :owner, union: -> { Privy::OwnerInput }, nil?: true |
#owner_id ⇒ String?
The key quorum ID to set as the owner of the resource. If you provide this, do not specify an owner.
30 |
# File 'lib/privy/models/wallet_update_request_body.rb', line 30 optional :owner_id, String, nil?: true |