Class: Privy::Models::Wallets::CustodianTransactionWalletActionStep
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::Wallets::CustodianTransactionWalletActionStep
- Defined in:
- lib/privy/models/wallets/custodian_transaction_wallet_action_step.rb,
sig/privy/models/wallets/custodian_transaction_wallet_action_step.rbs
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#custodian ⇒ String
Identifier of the custodian executing this transaction (e.g. "bridge").
-
#failure_reason ⇒ Privy::Models::Wallets::FailureReason?
A description of why a wallet action (or a step within a wallet action) failed.
-
#status ⇒ Symbol, Privy::Models::Wallets::CustodianTransactionWalletActionStepStatus
Status of a custodian transaction step in a wallet action.
- #type ⇒ Symbol, Privy::Models::Wallets::CustodianTransactionWalletActionStep::Type
Instance Method Summary collapse
-
#initialize(custodian:, status:, type:, failure_reason: nil) ⇒ Object
constructor
A wallet action step representing a transaction executed by a custodian (e.g. Bridge).
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(custodian:, status:, type:, failure_reason: nil) ⇒ Object
A wallet action step representing a transaction executed by a custodian (e.g. Bridge).
|
|
# File 'lib/privy/models/wallets/custodian_transaction_wallet_action_step.rb', line 30
|
Instance Attribute Details
#custodian ⇒ String
Identifier of the custodian executing this transaction (e.g. "bridge").
11 |
# File 'lib/privy/models/wallets/custodian_transaction_wallet_action_step.rb', line 11 required :custodian, String |
#failure_reason ⇒ Privy::Models::Wallets::FailureReason?
A description of why a wallet action (or a step within a wallet action) failed.
28 |
# File 'lib/privy/models/wallets/custodian_transaction_wallet_action_step.rb', line 28 optional :failure_reason, -> { Privy::Wallets::FailureReason } |
#status ⇒ Symbol, Privy::Models::Wallets::CustodianTransactionWalletActionStepStatus
Status of a custodian transaction step in a wallet action.
17 |
# File 'lib/privy/models/wallets/custodian_transaction_wallet_action_step.rb', line 17 required :status, enum: -> { Privy::Wallets::CustodianTransactionWalletActionStepStatus } |
#type ⇒ Symbol, Privy::Models::Wallets::CustodianTransactionWalletActionStep::Type
22 |
# File 'lib/privy/models/wallets/custodian_transaction_wallet_action_step.rb', line 22 required :type, enum: -> { Privy::Wallets::CustodianTransactionWalletActionStep::Type } |
Instance Method Details
#to_hash ⇒ {
32 |
# File 'sig/privy/models/wallets/custodian_transaction_wallet_action_step.rbs', line 32
def to_hash: -> {
|