Class: Privy::Models::Wallets::EarnDepositActionResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::Wallets::EarnDepositActionResponse
- Defined in:
- lib/privy/models/wallets/earn_deposit_action_response.rb,
sig/privy/models/wallets/earn_deposit_action_response.rbs
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#amount ⇒ String?
Human-readable decimal amount of asset deposited (e.g. "1.5").
-
#asset ⇒ String?
Asset identifier (e.g. "usdc", "eth").
-
#asset_address ⇒ String
Underlying asset token address.
-
#caip2 ⇒ String
CAIP-2 chain identifier.
-
#created_at ⇒ Time
ISO 8601 timestamp of when the wallet action was created.
-
#decimals ⇒ Integer?
Number of decimals for the underlying asset (e.g. 6 for USDC, 18 for ETH).
-
#failure_reason ⇒ Privy::Models::Wallets::FailureReason?
A description of why a wallet action (or a step within a wallet action) failed.
-
#id ⇒ String
The ID of the wallet action.
-
#raw_amount ⇒ String
Base-unit amount of asset deposited (e.g. "1500000").
-
#share_amount ⇒ String?
Vault shares received in base units.
-
#status ⇒ Symbol, Privy::Models::Wallets::WalletActionStatus
Status of a wallet action.
-
#steps ⇒ Array<Privy::Models::Wallets::EvmTransactionWalletActionStep, Privy::Models::Wallets::EvmUserOperationWalletActionStep, Privy::Models::Wallets::SvmTransactionWalletActionStep, Privy::Models::Wallets::TvmTransactionWalletActionStep, Privy::Models::Wallets::ExternalTransactionWalletActionStep, Privy::Models::Wallets::CustodianTransactionWalletActionStep>?
The steps of the wallet action.
- #type ⇒ Symbol, Privy::Models::Wallets::EarnDepositActionResponse::Type
-
#vault_address ⇒ String
ERC-4626 vault contract address.
-
#vault_id ⇒ String
The vault ID.
-
#wallet_id ⇒ String
The ID of the wallet involved in the action.
Instance Method Summary collapse
-
#initialize(id:, asset_address:, caip2:, created_at:, raw_amount:, share_amount:, status:, type:, vault_address:, vault_id:, wallet_id:, amount: nil, asset: nil, decimals: nil, failure_reason: nil, steps: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see EarnDepositActionResponse for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, asset_address:, caip2:, created_at:, raw_amount:, share_amount:, status:, type:, vault_address:, vault_id:, wallet_id:, amount: nil, asset: nil, decimals: nil, failure_reason: nil, steps: nil) ⇒ Object
Some parameter documentations has been truncated, see Privy::Models::Wallets::EarnDepositActionResponse for more details.
Response for an earn deposit action.
|
|
# File 'lib/privy/models/wallets/earn_deposit_action_response.rb', line 105
|
Instance Attribute Details
#amount ⇒ String?
Human-readable decimal amount of asset deposited (e.g. "1.5"). Only present when the token is known in the asset registry.
77 |
# File 'lib/privy/models/wallets/earn_deposit_action_response.rb', line 77 optional :amount, String |
#asset ⇒ String?
Asset identifier (e.g. "usdc", "eth"). Only present when the token is known in the asset registry.
84 |
# File 'lib/privy/models/wallets/earn_deposit_action_response.rb', line 84 optional :asset, String |
#asset_address ⇒ String
Underlying asset token address.
17 |
# File 'lib/privy/models/wallets/earn_deposit_action_response.rb', line 17 required :asset_address, String |
#caip2 ⇒ String
CAIP-2 chain identifier.
23 |
# File 'lib/privy/models/wallets/earn_deposit_action_response.rb', line 23 required :caip2, String |
#created_at ⇒ Time
ISO 8601 timestamp of when the wallet action was created.
29 |
# File 'lib/privy/models/wallets/earn_deposit_action_response.rb', line 29 required :created_at, Time |
#decimals ⇒ Integer?
Number of decimals for the underlying asset (e.g. 6 for USDC, 18 for ETH). Only present when the token is known in the asset registry.
91 |
# File 'lib/privy/models/wallets/earn_deposit_action_response.rb', line 91 optional :decimals, Integer |
#failure_reason ⇒ Privy::Models::Wallets::FailureReason?
A description of why a wallet action (or a step within a wallet action) failed.
97 |
# File 'lib/privy/models/wallets/earn_deposit_action_response.rb', line 97 optional :failure_reason, -> { Privy::Wallets::FailureReason } |
#id ⇒ String
The ID of the wallet action.
11 |
# File 'lib/privy/models/wallets/earn_deposit_action_response.rb', line 11 required :id, String |
#raw_amount ⇒ String
Base-unit amount of asset deposited (e.g. "1500000").
35 |
# File 'lib/privy/models/wallets/earn_deposit_action_response.rb', line 35 required :raw_amount, String |
#share_amount ⇒ String?
Vault shares received in base units. Populated after on-chain confirmation.
41 |
# File 'lib/privy/models/wallets/earn_deposit_action_response.rb', line 41 required :share_amount, String, nil?: true |
#status ⇒ Symbol, Privy::Models::Wallets::WalletActionStatus
Status of a wallet action.
47 |
# File 'lib/privy/models/wallets/earn_deposit_action_response.rb', line 47 required :status, enum: -> { Privy::Wallets::WalletActionStatus } |
#steps ⇒ Array<Privy::Models::Wallets::EvmTransactionWalletActionStep, Privy::Models::Wallets::EvmUserOperationWalletActionStep, Privy::Models::Wallets::SvmTransactionWalletActionStep, Privy::Models::Wallets::TvmTransactionWalletActionStep, Privy::Models::Wallets::ExternalTransactionWalletActionStep, Privy::Models::Wallets::CustodianTransactionWalletActionStep>?
The steps of the wallet action. Only returned if ?include=steps is provided.
103 |
# File 'lib/privy/models/wallets/earn_deposit_action_response.rb', line 103 optional :steps, -> { Privy::Internal::Type::ArrayOf[union: Privy::Wallets::WalletActionStep] } |
#type ⇒ Symbol, Privy::Models::Wallets::EarnDepositActionResponse::Type
52 |
# File 'lib/privy/models/wallets/earn_deposit_action_response.rb', line 52 required :type, enum: -> { Privy::Wallets::EarnDepositActionResponse::Type } |
#vault_address ⇒ String
ERC-4626 vault contract address.
58 |
# File 'lib/privy/models/wallets/earn_deposit_action_response.rb', line 58 required :vault_address, String |
#vault_id ⇒ String
The vault ID.
64 |
# File 'lib/privy/models/wallets/earn_deposit_action_response.rb', line 64 required :vault_id, String |
#wallet_id ⇒ String
The ID of the wallet involved in the action.
70 |
# File 'lib/privy/models/wallets/earn_deposit_action_response.rb', line 70 required :wallet_id, String |
Instance Method Details
#to_hash ⇒ {
90 |
# File 'sig/privy/models/wallets/earn_deposit_action_response.rbs', line 90
def to_hash: -> {
|