Class: Privy::Models::Wallets::EthereumEarnPositionResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::Wallets::EthereumEarnPositionResponse
- Defined in:
- lib/privy/models/wallets/ethereum_earn_position_response.rb,
sig/privy/models/wallets/ethereum_earn_position_response.rbs
Instance Attribute Summary collapse
-
#asset ⇒ Privy::Models::Wallets::EarnAsset
Asset metadata for an earn vault position.
-
#assets_in_vault ⇒ String
Current asset value in the vault (realtime from ERC-4626), in smallest unit.
-
#shares_in_vault ⇒ String
Current vault shares held (realtime from ERC-4626).
-
#total_deposited ⇒ String
Total amount deposited into the vault, in smallest unit.
-
#total_withdrawn ⇒ String
Total amount withdrawn from the vault, in smallest unit.
Instance Method Summary collapse
-
#initialize(asset:, assets_in_vault:, shares_in_vault:, total_deposited:, total_withdrawn:) ⇒ Object
constructor
A wallet's position in an earn vault.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(asset:, assets_in_vault:, shares_in_vault:, total_deposited:, total_withdrawn:) ⇒ Object
A wallet's position in an earn vault.
|
|
# File 'lib/privy/models/wallets/ethereum_earn_position_response.rb', line 37
|
Instance Attribute Details
#asset ⇒ Privy::Models::Wallets::EarnAsset
Asset metadata for an earn vault position.
11 |
# File 'lib/privy/models/wallets/ethereum_earn_position_response.rb', line 11 required :asset, -> { Privy::Wallets::EarnAsset } |
#assets_in_vault ⇒ String
Current asset value in the vault (realtime from ERC-4626), in smallest unit.
17 |
# File 'lib/privy/models/wallets/ethereum_earn_position_response.rb', line 17 required :assets_in_vault, String |
#shares_in_vault ⇒ String
Current vault shares held (realtime from ERC-4626).
23 |
# File 'lib/privy/models/wallets/ethereum_earn_position_response.rb', line 23 required :shares_in_vault, String |
#total_deposited ⇒ String
Total amount deposited into the vault, in smallest unit.
29 |
# File 'lib/privy/models/wallets/ethereum_earn_position_response.rb', line 29 required :total_deposited, String |
#total_withdrawn ⇒ String
Total amount withdrawn from the vault, in smallest unit.
35 |
# File 'lib/privy/models/wallets/ethereum_earn_position_response.rb', line 35 required :total_withdrawn, String |
Instance Method Details
#to_hash ⇒ {
32 |
# File 'sig/privy/models/wallets/ethereum_earn_position_response.rbs', line 32
def to_hash: -> {
|