Class: Privy::Models::Wallets::EvmUserOperationWalletActionStep
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Privy::Models::Wallets::EvmUserOperationWalletActionStep
- Defined in:
- lib/privy/models/wallets/evm_user_operation_wallet_action_step.rb,
sig/privy/models/wallets/evm_user_operation_wallet_action_step.rbs
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#bundle_transaction_hash ⇒ String?
Transaction hash of the bundle in which this user operation was included.
-
#caip2 ⇒ String
CAIP-2 network identifier, containing the chain ID of the user operation.
-
#entrypoint_version ⇒ Symbol, Privy::Models::Wallets::EvmUserOperationEntrypointVersion
The ERC-4337 entrypoint contract version used by the user operation.
-
#failure_reason ⇒ Privy::Models::Wallets::FailureReason?
A description of why a wallet action (or a step within a wallet action) failed.
-
#finalized ⇒ Boolean?
Whether this step has reached on-chain finality.
-
#gas_credits_charged_usd ⇒ String?
Amount charged in USD for gas sponsorship on this step.
-
#status ⇒ Symbol, Privy::Models::Wallets::EvmWalletActionStepStatus
Status of an EVM step in a wallet action.
- #type ⇒ Symbol, Privy::Models::Wallets::EvmUserOperationWalletActionStep::Type
-
#user_operation_hash ⇒ String?
The user operation hash for this step.
Instance Method Summary collapse
-
#initialize(bundle_transaction_hash:, caip2:, entrypoint_version:, status:, type:, user_operation_hash:, failure_reason: nil, finalized: nil, gas_credits_charged_usd: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see EvmUserOperationWalletActionStep for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(bundle_transaction_hash:, caip2:, entrypoint_version:, status:, type:, user_operation_hash:, failure_reason: nil, finalized: nil, gas_credits_charged_usd: nil) ⇒ Object
Some parameter documentations has been truncated, see Privy::Models::Wallets::EvmUserOperationWalletActionStep for more details.
A wallet action step consisting of an EVM user operation.
|
|
# File 'lib/privy/models/wallets/evm_user_operation_wallet_action_step.rb', line 63
|
Instance Attribute Details
#bundle_transaction_hash ⇒ String?
Transaction hash of the bundle in which this user operation was included. Null until included by a bundler.
12 |
# File 'lib/privy/models/wallets/evm_user_operation_wallet_action_step.rb', line 12 required :bundle_transaction_hash, String, nil?: true |
#caip2 ⇒ String
CAIP-2 network identifier, containing the chain ID of the user operation.
18 |
# File 'lib/privy/models/wallets/evm_user_operation_wallet_action_step.rb', line 18 required :caip2, String |
#entrypoint_version ⇒ Symbol, Privy::Models::Wallets::EvmUserOperationEntrypointVersion
The ERC-4337 entrypoint contract version used by the user operation.
24 |
# File 'lib/privy/models/wallets/evm_user_operation_wallet_action_step.rb', line 24 required :entrypoint_version, enum: -> { Privy::Wallets::EvmUserOperationEntrypointVersion } |
#failure_reason ⇒ Privy::Models::Wallets::FailureReason?
A description of why a wallet action (or a step within a wallet action) failed.
48 |
# File 'lib/privy/models/wallets/evm_user_operation_wallet_action_step.rb', line 48 optional :failure_reason, -> { Privy::Wallets::FailureReason } |
#finalized ⇒ Boolean?
Whether this step has reached on-chain finality. Absent until finality is confirmed.
55 |
# File 'lib/privy/models/wallets/evm_user_operation_wallet_action_step.rb', line 55 optional :finalized, Privy::Internal::Type::Boolean |
#gas_credits_charged_usd ⇒ String?
Amount charged in USD for gas sponsorship on this step.
61 |
# File 'lib/privy/models/wallets/evm_user_operation_wallet_action_step.rb', line 61 optional :gas_credits_charged_usd, String |
#status ⇒ Symbol, Privy::Models::Wallets::EvmWalletActionStepStatus
Status of an EVM step in a wallet action.
30 |
# File 'lib/privy/models/wallets/evm_user_operation_wallet_action_step.rb', line 30 required :status, enum: -> { Privy::Wallets::EvmWalletActionStepStatus } |
#type ⇒ Symbol, Privy::Models::Wallets::EvmUserOperationWalletActionStep::Type
35 |
# File 'lib/privy/models/wallets/evm_user_operation_wallet_action_step.rb', line 35 required :type, enum: -> { Privy::Wallets::EvmUserOperationWalletActionStep::Type } |
#user_operation_hash ⇒ String?
The user operation hash for this step. May change while the step status is non-terminal.
42 |
# File 'lib/privy/models/wallets/evm_user_operation_wallet_action_step.rb', line 42 required :user_operation_hash, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
56 |
# File 'sig/privy/models/wallets/evm_user_operation_wallet_action_step.rbs', line 56
def to_hash: -> {
|